---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2004-01-22;42
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20040224&codiceRedaz=004G0066&dataVigenza=20251104
dataGU: 20040224
codiceRedaz: 004G0066
dataVigenza: 20251104
---

# Codice dei beni culturali e del paesaggio, ai sensi dell'articolo 10
della legge 6 luglio 2002, n. 137.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87, 117 e 118 della Costituzione;

Visto l'articolo 14 della legge 23 agosto 1988, n. 400;

Visto il decreto legislativo 20 ottobre 1998, n. 368, recante istituzione del Ministero per i beni e le attivita' culturali, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59, e successive modifiche e integrazioni;

Visto il decreto legislativo 29 ottobre 1999, n. 490, recante testo unico delle disposizioni legislative in materia di beni culturali e ambientali, a norma dell'articolo 1 della legge 8 ottobre 1997, n. 352;

Visto l'articolo 10 della legge 6 luglio 2002, n. 137;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 29 settembre 2003;

Acquisito il parere della Conferenza unificata, istituita ai sensi del decreto legislativo 28 agosto 1997, n. 281;

Acquisiti i pareri delle competenti commissioni del Senato della Repubblica e della Camera dei deputati;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 16 gennaio 2004;

Sulla proposta del Ministro per i beni e le attivita' culturali, di concerto con il Ministro per gli affari regionali;

Emana

il seguente decreto legislativo:

Art. 1.

1. E' approvato l'unito codice dei beni culturali e del paesaggio, composto di 184 articoli e dell'allegato A, vistato dal Ministro proponente.

Il presente decreto, munito del sigillo dello Stato, sara' inserito nella Raccolta ufficiale degli atti normativi della Repubblica italiana. E' fatto obbligo a chiunque spetti di osservarlo e di farlo osservare.

Dato a Roma, addi' 22 gennaio 2004

CIAMPI

Berlusconi, Presidente del Consiglio

dei Ministri

Urbani, Ministro per i beni e le

attivita' culturali

La Loggia, Ministro per gli affari

regionali Visto, il Guardasigilli: Castelli

## Art. 01.

1. E' approvato l'unito codice dei beni culturali e del paesaggio, composto di 184 articoli e dell'allegato A, vistato dal Ministro proponente. Il presente decreto, munito del sigillo dello Stato, sara' inserito nella Raccolta ufficiale degli atti normativi della Repubblica italiana. E' fatto obbligo a chiunque spetti di osservarlo e di farlo osservare. Dato a Roma, addi' 22 gennaio 2004 CIAMPI Berlusconi, Presidente del Consiglio dei Ministri Urbani, Ministro per i beni e le attivita' culturali La Loggia, Ministro per gli affari regionali Visto, il Guardasigilli: Castelli

## Disposizioni generali - - - -

### Articolo 1 - Principi

1. In attuazione dell'articolo 9 della Costituzione, la Repubblica tutela e valorizza il patrimonio culturale in coerenza con le attribuzioni di cui all'articolo 117 della Costituzione e secondo le disposizioni del presente codice.

2. La tutela e la valorizzazione del patrimonio culturale concorrono a preservare la memoria della comunita' nazionale e del suo territorio e a promuovere lo sviluppo della cultura.

3. Lo Stato, le regioni, le citta' metropolitane, le province e i comuni assicurano e sostengono la conservazione del patrimonio culturale e ne favoriscono la pubblica fruizione e la valorizzazione.

4. Gli altri soggetti pubblici, nello svolgimento della loro attivita', assicurano la conservazione e la pubblica fruizione del loro patrimonio culturale.

5. I privati proprietari, possessori o detentori di beni appartenenti al patrimonio culturale ((, ivi compresi gli enti ecclesiastici civilmente riconosciuti, )) sono tenuti a garantirne la conservazione.

6. Le attivita' concernenti la conservazione, la fruizione e la valorizzazione del patrimonio culturale indicate ai commi 3, 4 e 5 sono svolte in conformita' alla normativa di tutela.

### Articolo 2 - Patrimonio culturale

1. Il patrimonio culturale e' costituito dai beni culturali e dai beni paesaggistici.

2. Sono beni culturali le cose immobili e mobili che, ai sensi degli articoli 10 e 11, presentano interesse artistico, storico, archeologico, etnoantropologico, archivistico e bibliografico e le altre cose individuate dalla legge o in base alla legge quali testimonianze aventi valore di civilta'.

3. Sono beni paesaggistici gli immobili e le aree indicati all'articolo 134, costituenti espressione dei valori storici, culturali, naturali, morfologici ed estetici del territorio, e gli altri beni individuati dalla legge o in base alla legge.

4. I beni del patrimonio culturale di appartenenza pubblica sono destinati alla fruizione della collettivita', compatibilmente con le esigenze di uso istituzionale e sempre che non vi ostino ragioni di tutela.

### Articolo 3 - Tutela del patrimonio culturale

1. La tutela consiste nell'esercizio delle funzioni e nella disciplina delle attivita' dirette, sulla base di un'adeguata attivita' conoscitiva, ad individuare i beni costituenti il patrimonio culturale ed a garantirne la protezione e la conservazione per fini di pubblica fruizione.

2. L'esercizio delle funzioni di tutela si esplica anche attraverso provvedimenti volti a conformare e regolare diritti e comportamenti inerenti al patrimonio culturale. Le funzioni di tutela sono esercitate conformemente a criteri omogenei e priorita' fissati dal ((Ministero della cultura)).

### Articolo 4 - Funzioni dello Stato in materia di tutela del patrimonio culturale

1. Al fine di garantire l'esercizio unitario delle funzioni di tutela, ai sensi dell'articolo 118 della Costituzione, le funzioni stesse sono attribuite al Ministero per i beni e le attivita' culturali, di seguito denominato "Ministero", che le esercita direttamente o ne puo' conferire l'esercizio alle regioni, tramite forme di intesa e coordinamento ai sensi dell'articolo 5, commi 3 e 4. Sono fatte salve le funzioni gia' conferite alle regioni ai sensi ((del comma 6)) del medesimo articolo 5.

2. Il Ministero esercita le funzioni di tutela sui beni culturali di appartenenza statale anche se in consegna o in uso ad amministrazioni o soggetti diversi dal Ministero.

### Articolo 5 - Cooperazione delle regioni e degli altri enti pubblici territoriali in materia di tutela del patrimonio culturale

1. Le regioni, nonche' i comuni, le citta' metropolitane e le province, di seguito denominati "altri enti pubblici territoriali", cooperano con il Ministero nell'esercizio delle funzioni di tutela in conformita' a quanto disposto dal Titolo I della Parte seconda del presente codice.

2. ((COMMA ABROGATO DAL D.L. 19 GIUGNO 2015, N. 78, CONVERTITO CON MODIFICAZIONI DALLA L. 6 AGOSTO 2015, N. 125)).

3. Sulla base di specifici accordi od intese e previo parere della Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e Bolzano, di seguito denominata "Conferenza Stato-regioni", le regioni possono esercitare le funzioni di tutela su ((manoscritti, autografi, carteggi, incunaboli, raccolte librarie, libri, stampe e incisioni,)) carte geografiche, spartiti musicali, fotografie, pellicole o altro materiale audiovisivo, con relativi negativi e matrici, non appartenenti allo Stato.

4. Nelle forme previste dal comma 3 e sulla base dei principi di differenziazione ed adeguatezza, possono essere individuate ulteriori forme di coordinamento in materia di tutela con le regioni che ne facciano richiesta.

5. Gli accordi o le intese possono prevedere particolari forme di cooperazione con gli altri enti pubblici territoriali.

6. Le funzioni amministrative di tutela dei beni paesaggistici sono esercitate dallo Stato e dalle regioni secondo le disposizioni di cui alla Parte terza del presente codice, in modo che sia sempre assicurato un livello di governo unitario ed adeguato alle diverse finalita' perseguite.

7. Relativamente alle funzioni esercitate dalle regioni ai sensi dei ((commi 3, 4, 5 e 6)), il Ministero esercita le potesta' di indirizzo e di vigilanza e il potere sostitutivo in caso di perdurante inerzia o inadempienza.

### Articolo 6 - Valorizzazione del patrimonio culturale

1. La valorizzazione consiste nell'esercizio delle funzioni e nella disciplina delle attivita' dirette a promuovere la conoscenza del patrimonio culturale e ad assicurare le migliori condizioni di utilizzazione e fruizione pubblica del patrimonio stesso , (( anche da parte delle persone diversamente abili, ))al fine di promuovere lo sviluppo della cultura . Essa comprende anche la promozione ed il sostegno degli interventi di conservazione del patrimonio culturale. (( In riferimento al paesaggio, ))la valorizzazione comprende altresila riqualificazione degli immobili e delle aree sottoposti a tutela compromessi o degradati, ovvero la realizzazione di nuovi valori paesaggistici coerenti ed integrati.

2. La valorizzazione e' attuata in forme compatibili con la tutela e tali da non pregiudicarne le esigenze.

3. La Repubblica favorisce e sostiene la partecipazione dei soggetti privati, singoli o associati, alla valorizzazione del patrimonio culturale.

### Articolo 7 - Funzioni e compiti in materia di valorizzazione del patrimonio culturale

1. Il presente codice fissa i principi fondamentali in materia di valorizzazione del patrimonio culturale. Nel rispetto di tali principi le regioni esercitano la propria potesta' legislativa.

2. Il Ministero, le regioni e gli altri enti pubblici territoriali perseguono il coordinamento, l'armonizzazione e l'integrazione delle attivita' di valorizzazione dei beni pubblici.

### Articolo 7-bis - (( (Espressioni di identita' culturale collettiva) ))

((

1. Le espressioni di identita' culturale collettiva contemplate dalle Convenzioni UNESCO per la salvaguardia del patrimonio culturale immateriale e per la protezione e la promozione delle diversita' culturali, adottate a Parigi, rispettivamente, il 3 novembre 2003 ed il 20 ottobre 2005, sono assoggettabili alle disposizioni del presente codice qualora siano rappresentate da testimonianze materiali e sussistano i presupposti e le condizioni per l'applicabilita' dell'articolo 10.

))

### Articolo 8 - Regioni e province ad autonomia speciale

1. Nelle materie disciplinate dal presente codice restano ferme le potesta' attribuite alle regioni a statuto speciale ed alle province autonome di Trento e Bolzano dagli statuti e dalle relative norme di attuazione.

### Articolo 9 - Beni culturali di interesse religioso

1. Per i beni culturali di interesse religioso appartenenti ad enti ed istituzioni della Chiesa cattolica o di altre confessioni religiose, il Ministero e, per quanto di competenza, le regioni provvedono, relativamente alle esigenze di culto, d'accordo con le rispettive autorita'.

2. Si osservano, altresi', le disposizioni stabilite dalle intese concluse ai sensi dell'articolo 12 dell'Accordo di modificazione del Concordato lateranense firmato il 18 febbraio 1984, ratificato e reso esecutivo con legge 25 marzo 1985, n. 121, ovvero dalle leggi emanate sulla base delle intese sottoscritte con le confessioni religiose diverse dalla cattolica, ai sensi dell'articolo 8, comma 3, della Costituzione.

### Articolo 9-bis. - (( (Professionisti competenti ad eseguire interventi sui beni culturali). ))

## Beni culturali - - TITOLO I Tutela Capo I Oggetto della tutela

### Articolo 10 - Beni culturali

1. Sono beni culturali le cose immobili e mobili appartenenti allo Stato, alle regioni, agli altri enti pubblici territoriali, nonche' ad ogni altro ente ed istituto pubblico e a persone giuridiche private senza fine di lucro , ivi compresi gli enti ecclesiastici civilmente riconosciuti, che presentano interesse artistico, storico, archeologico o etnoantropologico.

2. Sono inoltre beni culturali:

- a) le raccolte di musei, pinacoteche, gallerie e altri luoghi espositivi dello Stato, delle regioni, degli altri enti pubblici territoriali, nonche' di ogni altro ente ed istituto pubblico;
- b) gli archivi e i singoli documenti dello Stato, delle regioni, degli altri enti pubblici territoriali, nonche' di ogni altro ente ed istituto pubblico;
- c) le raccolte librarie delle biblioteche dello Stato, delle regioni, degli altri enti pubblici territoriali, nonche' di ogni altro ente e istituto pubblico , ad eccezione delle raccolte che assolvono alle funzioni delle biblioteche indicate all'articolo 47, comma 2, del decreto del Presidente della Repubblica 24 luglio 1977, n. 616 .

3. Sono altresi' beni culturali, quando sia intervenuta la dichiarazione prevista dall'articolo 13:

- a) le cose immobili e mobili che presentano interesse artistico, storico, archeologico o etnoantropologico particolarmente importante, appartenenti a soggetti diversi da quelli indicati al comma 1;
- b) gli archivi e i singoli documenti, appartenenti a privati, che rivestono interesse storico particolarmente importante;
- c) le raccolte librarie, appartenenti a privati, di eccezionale interesse culturale;
- d) le cose immobili e mobili, a chiunque appartenenti, che rivestono un interesse particolarmente importante a causa del loro riferimento con la storia politica, militare, della letteratura, dell'arte, della scienza, della tecnica, dell'industria e della cultura in genere, ovvero quali testimonianze dell'identita' e della storia delle istituzioni pubbliche, collettive o religiose ((. Se le cose rivestono altresi' un valore testimoniale o esprimono un collegamento identitario o civico di significato distintivo eccezionale, il provvedimento di cui all'articolo 13 puo' comprendere, anche su istanza di uno o piu' comuni o della regione, la dichiarazione di monumento nazionale));
- d-bis) le cose, a chiunque appartenenti, che presentano un interesse artistico, storico, archeologico o etnoantropologico eccezionale per l'integrita' e la completezza del patrimonio culturale della Nazione;
- e) le collezioni o serie di oggetti, a chiunque appartenenti, che non siano ricomprese fra quelle indicate al comma 2 e che, per tradizione, fama e particolari caratteristiche ambientali, ovvero per rilevanza artistica, storica, archeologica, numismatica o etnoantropologica, rivestano come complesso un eccezionale interesse.

4. Sono comprese tra le cose indicate al comma 1 e al comma 3, lettera a):

- a) le cose che interessano la paleontologia, la preistoria e le primitive civilta';
- b) le cose di interesse numismatico che, in rapporto all'epoca, alle tecniche e ai materiali di produzione, nonche' al contesto di riferimento, abbiano carattere di rarita' o di pregio;
- c) i manoscritti, gli autografi, i carteggi, gli incunaboli, nonche' i libri, le stampe e le incisioni, con relative matrici, aventi carattere di rarita' e di pregio;
- d) le carte geografiche e gli spartiti musicali aventi carattere di rarita' e di pregio;
- e) le fotografie, con relativi negativi e matrici, le pellicole cinematografiche ed i supporti audiovisivi in genere, aventi carattere di rarita' e di pregio;
- f) le ville, i parchi e i giardini che abbiano interesse artistico o storico;
- g) le pubbliche piazze, vie, strade e altri spazi aperti urbani di interesse artistico o storico;
- h) i siti minerari di interesse storico od etnoantropologico;
- i) le navi e i galleggianti aventi interesse artistico, storico od etnoantropologico;
- l) le architetture rurali aventi interesse storico od etnoantropologico quali testimonianze dell'economia rurale tradizionale.

5. Salvo quanto disposto dagli articoli 64 e 178, non sono soggette alla disciplina del presente titolo le cose indicate al comma 1 e al comma 3, lettere a) ed e), che siano opera di autore vivente o la cui esecuzione non risalga ad oltre settanta anni, nonche' le cose indicate al comma 3, lettera d-bis), che siano opera di autore vivente o la cui esecuzione non risalga ad oltre cinquanta anni.

### Articolo 11 - Cose oggetto di specifiche disposizioni di tutela

1. Sono assoggettate alle disposizioni espressamente richiamate le seguenti tipologie di cose:

- a) gli affreschi, gli stemmi, i graffiti, le lapidi, le iscrizioni, i tabernacoli ed altri elementi decorativi di edifici, esposti o non alla pubblica vista, di cui all'articolo 50, comma 1;
- b) gli studi d'artista, di cui all'articolo 51;
- c) le aree pubbliche di cui all'articolo 52;
- d) le opere di pittura, di scultura, di grafica e qualsiasi oggetto d'arte di autore vivente o la cui esecuzione non risalga ad oltre ((settanta)) anni, a termini degli articoli 64 e 65, comma 4;
- e) le opere dell'architettura contemporanea di particolare valore artistico, a termini dell'articolo 37;
- f) le fotografie, con relativi negativi e matrici, gli esemplari di opere cinematografiche, audiovisive o di sequenze di immagini in movimento, le documentazioni di manifestazioni, sonore o verbali, comunque realizzate, la cui produzione risalga ad oltre venticinque anni, a termini dell'articolo 65, comma 3, lettera c);
- g) i mezzi di trasporto aventi piu' di settantacinque anni, a termini degli articoli 65, comma 3, lettera c), e 67, comma 2;
- h) i beni e gli strumenti di interesse per la storia della scienza e della tecnica aventi piu' di cinquanta anni, a termini dell'articolo 65, comma 3, lettera c);
- i) le vestigia individuate dalla vigente normativa in materia di tutela del patrimonio storico della Prima guerra mondiale, di cui all'articolo 50, comma 2.

1-bis. Per le cose di cui al comma 1, resta ferma l'applicabilita' delle disposizioni di cui agli articoli 12 e 13, qualora sussistano i presupposti e le condizioni stabiliti dall'articolo 10.

### Articolo 12 - Verifica dell'interesse culturale

1. Le cose indicate all'articolo 10, comma 1, che siano opera di autore non piu' vivente e la cui esecuzione risalga ad oltre settanta anni, sono sottoposte alle disposizioni della presente Parte fino a quando non sia stata effettuata la verifica di cui al comma 2.

2. I competenti organi del Ministero, d'ufficio o su richiesta formulata dai soggetti cui le cose appartengono e corredata dai relativi dati conoscitivi, verificano la sussistenza dell'interesse artistico, storico, archeologico o etnoantropologico nelle cose di cui al comma 1, sulla base di indirizzi di carattere generale stabiliti dal Ministero medesimo al fine di assicurare uniformita' di valutazione.

3. Per i beni immobili dello Stato, la richiesta di cui al comma 2 e' corredata da elenchi dei beni e dalle relative schede descrittive. I criteri per la predisposizione degli elenchi, le modalita' di redazione delle schede descrittive e di trasmissione di elenchi e schede sono stabiliti con decreto del Ministero adottato di concerto con l'Agenzia del demanio e, per i beni immobili in uso all'amministrazione della difesa, anche con il concerto della competente direzione generale dei lavori e del demanio. Il Ministero fissa, con propri decreti, i criteri e le modalita' per la predisposizione e la presentazione delle richieste di verifica, e della relativa documentazione conoscitiva, da parte degli altri soggetti di cui al comma 1.

4. Qualora nelle cose sottoposte a verifica non sia stato riscontrato l'interesse di cui al comma 2, le cose medesime sono escluse dall'applicazione delle disposizioni del presente Titolo.

5. Nel caso di verifica con esito negativo su cose appartenenti al demanio dello Stato, delle regioni e degli altri enti pubblici territoriali, la scheda contenente i relativi dati e' trasmessa ai competenti uffici affinche' ne dispongano la sdemanializzazione qualora, secondo le valutazioni dell'amministrazione interessata, non vi ostino altre ragioni di pubblico interesse.

6. Le cose di cui al comma 4 e quelle di cui al comma 5 per le quali si sia proceduto alla sdemanializzazione sono liberamente alienabili, ai fini del presente codice.

7. L'accertamento dell'interesse artistico, storico, archeologico o etnoantropologico, effettuato in conformita' agli indirizzi generali di cui al comma 2, costituisce dichiarazione ai sensi dell'articolo 13 ed il relativo provvedimento e' trascritto nei modi previsti dall'articolo 15, comma 2. I beni restano definitivamente sottoposti alle disposizioni del presente Titolo.

8. Le schede descrittive degli immobili di proprieta' dello Stato oggetto di verifica con esito positivo, integrate con il provvedimento di cui al comma 7, confluiscono in un archivio informatico , conservato presso il Ministero e accessibile al Ministero e all'Agenzia del demanio, per finalita' di monitoraggio del patrimonio immobiliare e di programmazione degli interventi in funzione delle rispettive competenze istituzionali.

9. Le disposizioni del presente articolo si applicano alle cose di cui al comma 1 anche qualora i soggetti cui esse appartengono mutino in qualunque modo la loro natura giuridica.

10. Il procedimento di verifica si conclude entro novanta giorni dal ricevimento della richiesta.

10-bis. In caso di inerzia, il potere di adottare il provvedimento e' attribuito al Direttore generale competente per materia del Ministero della cultura, che provvede entro i successivi trenta giorni.

((10-ter. Il mancato rispetto dei termini di cui ai commi 10 e 10-bis e' valutabile ai fini della responsabilita' disciplinare e dirigenziale, ai sensi dell'articolo 2, comma 9, della legge 7 agosto 1990, n. 241))

### Articolo 13 - Dichiarazione dell'interesse culturale

1. La dichiarazione accerta la sussistenza, nella cosa che ne forma oggetto, dell'interesse richiesto dall'articolo 10, comma 3.

2. La dichiarazione non e' richiesta per i beni di cui all'articolo 10, comma 2. Tali beni rimangono sottoposti a tutela anche qualora i soggetti cui essi appartengono mutino in qualunque modo la loro natura giuridica.

### Articolo 14 - Procedimento di dichiarazione

1. Il soprintendente avvia il procedimento per la dichiarazione dell'interesse culturale, anche su motivata richiesta della regione e di ogni altro ente territoriale interessato, dandone comunicazione al proprietario, possessore o detentore a qualsiasi titolo della cosa che ne forma oggetto.

2. La comunicazione contiene gli elementi di identificazione e di valutazione della cosa risultanti dalle prime indagini, l'indicazione degli effetti previsti dal comma 4, nonche' l'indicazione del termine, comunque non inferiore a trenta giorni, per la presentazione di eventuali osservazioni.

3. Se il procedimento riguarda complessi immobiliari, la comunicazione e' inviata anche al comune e alla citta' metropolitana.

4. La comunicazione comporta l'applicazione, in via cautelare, delle disposizioni previste dal Capo II, dalla sezione I del Capo III e dalla sezione I del Capo IV del presente Titolo.

5. Gli effetti indicati al comma 4 cessano alla scadenza del termine del procedimento di dichiarazione, che il Ministero stabilisce ai sensi delle vigenti disposizioni di legge in materia di procedimento amministrativo.

6. La dichiarazione dell'interesse culturale e' adottata dal Ministero. ((Per le cose di cui all'articolo 10, comma 3, lettera d-bis), la dichiarazione e' adottata dal competente organo centrale del Ministero.))

### Articolo 15 - Notifica della dichiarazione

1. La dichiarazione prevista dall'articolo 13 e' notificata al proprietario, possessore o detentore a qualsiasi titolo della cosa che ne forma oggetto, tramite messo comunale o a mezzo posta raccomandata con avviso di ricevimento.

2. Ove si tratti di cose soggette a pubblicita' immobiliare o mobiliare, il provvedimento di dichiarazione e' trascritto, su richiesta del soprintendente, nei relativi registri ed ha efficacia nei confronti di ogni successivo proprietario, possessore o detentore a qualsiasi titolo.

((

2-bis. Dei beni dichiarati il Ministero forma e conserva un apposito elenco, anche su supporto informatico.

))

### Articolo 16 - Ricorso amministrativo avverso la dichiarazione

1. Avverso (( il provvedimento conclusivo della verifica di cui all'articolo 12 o )) la dichiarazione di cui all'articolo 13 e' ammesso ricorso al Ministero, per motivi di legittimita' e di merito, entro trenta giorni dalla notifica della dichiarazione.

2. La proposizione del ricorso comporta la sospensione degli effetti del provvedimento impugnato. Rimane ferma l'applicazione, in via cautelare, delle disposizioni previste dal Capo II, dalla sezione I del Capo III e dalla sezione I del Capo IV del presente Titolo.

3. Il Ministero, sentito il competente organo consultivo, decide sul ricorso entro il termine di novanta giorni dalla presentazione dello stesso.

4. Il Ministero, qualora accolga il ricorso, annulla o riforma l'atto impugnato.

5. Si applicano le disposizioni del decreto del Presidente della Repubblica 24 novembre 1971, n. 1199.

### Articolo 17 - Catalogazione

1. Il Ministero, con il concorso delle regioni e degli altri enti pubblici territoriali, assicura la catalogazione dei beni culturali e coordina le relative attivita'.

2. Le procedure e le modalita' di catalogazione sono stabilite con decreto ministeriale. A tal fine il Ministero, con il concorso delle regioni, individua e definisce metodologie comuni di raccolta, scambio, accesso ed elaborazione dei dati a livello nazionale e di integrazione in rete delle banche dati dello Stato, delle regioni e degli altri enti pubblici territoriali.

3. Il Ministero e le regioni, anche con la collaborazione delle universita', concorrono alla definizione di programmi concernenti studi, ricerche ed iniziative scientifiche in tema di metodologie di catalogazione e inventariazione.

4. Il Ministero, le regioni e gli altri enti pubblici territoriali, con le modalita' di cui al decreto ministeriale previsto al comma 2, curano la catalogazione dei beni culturali loro appartenenti e, previe intese con gli enti proprietari, degli altri beni culturali.

5. I dati di cui al presente articolo affluiscono al catalogo nazionale dei beni culturali (( in ogni sua articolazione )).

6. La consultazione dei dati concernenti le dichiarazioni emesse ai sensi dell'articolo 13 e' disciplinata in modo da garantire la sicurezza dei beni e la tutela della riservatezza.

## Capo II - Vigilanza e ispezione

### Articolo 18 - Vigilanza

1. La vigilanza sui beni culturali (( , sulle cose di cui all'articolo 12, comma 1, nonche' sulle aree interessate da prescrizioni di tutela indiretta, ai sensi dell'articolo 45, )) compete al Ministero.

((

2. Sulle cose di cui all'articolo 12, comma 1, che appartengano alle regioni e agli altri enti pubblici territoriali, il Ministero provvede alla vigilanza anche mediante forme di intesa e di coordinamento con le regioni medesime.

))

### Articolo 19 - Ispezione

1. I soprintendenti possono procedere in ogni tempo, con preavviso non inferiore a cinque giorni, fatti salvi i casi di estrema urgenza, ad ispezioni volte ad accertare l'esistenza e lo stato (( di conservazione o di custodia )) dei beni culturali.

((

1-bis. Con le modalita' di cui al comma 1 i soprintendenti possono altresi' accertare l'ottemperanza alle prescrizioni di tutela indiretta date ai sensi dell'articolo 45.

))

## Capo III - Protezione e conservazione

### Sezione I - Misure di protezione

#### Articolo 20 - Interventi vietati

1. I beni culturali non possono essere distrutti, (( deteriorati, )) danneggiati o adibiti ad usi non compatibili con il loro carattere storico o artistico oppure tali da recare pregiudizio alla loro conservazione.

2. Gli archivi pubblici e gli archivi privati per i quali sia intervenuta la dichiarazione ai sensi dell'articolo 13 non possono essere smembrati.

#### Articolo 21 - Interventi soggetti ad autorizzazione

1. Sono subordinati ad autorizzazione del Ministero: (( a) la rimozione o la demolizione, anche con successiva ricostituzione, dei beni culturali; )) b) lo spostamento, anche temporaneo, dei beni culturali (( mobili )), salvo quanto previsto ai commi 2 e 3; e) lo smembramento di collezioni, serie e raccolte; d) lo scarto dei documenti degli archivi pubblici e degli archivi privati per i quali sia intervenuta la dichiarazione ai sensi dell'articolo 13 , nonche' lo scarto di materiale bibliografico delle biblioteche pubbliche, con l'eccezione prevista all'articolo 10, comma 2, lettera c), e delle biblioteche private per le quali sia intervenuta la dichiarazione ai sensi dell'articolo 13 ; e) il trasferimento ad altre persone giuridiche di complessi organici di documentazione di archivi pubblici, nonche' di archivi privati per i quali sia intervenuta la dichiarazione ai sensi dell'articolo 13 .

2. Lo spostamento di beni culturali, dipendente dal mutamento di dimora o di sede del detentore, e' preventivamente denunciato al soprintendente, che, entro trenta giorni dal ricevimento della denuncia, puo' prescrivere le misure necessarie perche' i beni non subiscano danno dal trasporto.

3. Lo spostamento degli archivi correnti dello Stato e degli enti ed istituti pubblici non e' soggetto ad autorizzazione ((, ma comporta l'obbligo di comunicazione al Ministero per le finalita' di cui all'articolo 18 )).

4. Fuori dei casi di cui ai commi precedenti, l'esecuzione di opere e lavori di qualunque genere su beni culturali e' subordinata ad autorizzazione del soprintendente. Il mutamento di destinazione d'uso dei beni medesimi e' comunicato al soprintendente per le finalita' di cui all'articolo 20, comma 1.

5. L'autorizzazione e' resa su progetto o, qualora sufficiente, su descrizione tecnica dell'intervento, presentati dal richiedente, e puo' contenere prescrizioni. Se i lavori non iniziano entro cinque anni dal rilascio dell'autorizzazione, il soprintendente puo' dettare prescrizioni ovvero integrare o variare quelle gia' date in relazione al mutare delle tecniche di conservazione.

#### Articolo 22 - Procedimento di autorizzazione per interventi di edilizia

1. Fuori dei casi previsti dagli articoli 25 e 26, l'autorizzazione prevista dall'articolo 21, comma 4, relativa ad interventi in materia di edilizia pubblica e privata e' rilasciata entro il termine di centoventi giorni dalla ricezione della richiesta da parte della soprintendenza.

2. Qualora la soprintendenza chieda chiarimenti o elementi integrativi di giudizio, il termine indicato al comma 1 e' sospeso fino al ricevimento della documentazione richiesta.

3. (( Ove sorga l'esigenza di procedere ad accertamenti di natura tecnica, la soprintendenza ne da' preventiva comunicazione al richiedente ed )) il termine indicato al comma 1 e' sospeso fino all'acquisizione delle risultanze degli accertamenti d'ufficio e comunque per non piu' di trenta giorni.

((

4. Decorso inutilmente il termine stabilito, il richiedente puo' diffidare l'amministrazione a provvedere. Se l'amministrazione non provvede nei trenta giorni successivi al ricevimento della diffida, il richiedente puo' agire ai sensi dell'articolo 21-bis della legge 6 dicembre 1971, n. 1034, e successive modificazioni.

))

#### Articolo 23 - Procedure edilizie semplificate

1. Qualora gli interventi autorizzati ai sensi dell'articolo 21 necessitino anche di titolo abilitativo in materia edilizia, e' possibile il ricorso alla denuncia di inizio attivita', nei casi previsti dalla legge. A tal fine l'interessato, all'atto della denuncia, trasmette al comune l'autorizzazione conseguita, corredata dal relativo progetto.

#### Articolo 24 - Interventi su beni pubblici

1. Per gli interventi su beni culturali pubblici da eseguirsi da parte di amministrazioni dello Stato, delle regioni, di altri enti pubblici territoriali, nonche' di ogni altro ente ed istituto pubblico, l'autorizzazione necessaria ai sensi dell'articolo 21 puo' essere espressa nell'ambito di accordi tra il Ministero ed il soggetto pubblico interessato.

#### Articolo 25 - Conferenza di servizi

1. Nei procedimenti relativi ad opere o lavori incidenti su beni culturali, ove si ricorra alla conferenza di servizi, (( l'assenso espresso ))in quella sede dal competente organo del Ministero con dichiarazione motivata, acquisita al verbale della conferenza e contenente le eventuali prescrizioni impartite per la realizzazione del progetto ((, sostituisce, a tutti gli effetti, l'autorizzazione di cui all'articolo 21 )).

((

2. Qualora l'organo ministeriale esprima motivato dissenso, la decisione conclusiva e' assunta ai sensi delle vigenti disposizioni di legge in materia di procedimento amministrativo.

))

3. Il destinatario della determinazione conclusiva favorevole adottata in conferenza di servizi informa il Ministero dell'avvenuto adempimento delle prescrizioni da quest'ultimo impartite.

#### Articolo 26 - (( (Valutazione di impatto ambientale). ))

((

1. Per i progetti da sottoporre a valutazione di impatto ambientale, il Ministero si esprime ai sensi della disciplina di cui agli articoli da 23 a 27-bis del decreto legislativo 3 aprile 2006, n. 152.

2. Qualora prima dell'adozione del provvedimento di valutazione di impatto ambientale risulti che il progetto non e' in alcun modo compatibile con le esigenze di protezione dei beni culturali sui quali esso e' destinato ad incidere, il Ministero si pronuncia negativamente e, in tal caso, il procedimento di valutazione di impatto ambientale si conclude negativamente.

3. Qualora nel corso dei lavori di realizzazione del progetto risultino comportamenti contrastanti con l'autorizzazione di cui all'articolo 21 espressa nelle forme del provvedimento unico ambientale di cui all'articolo 27 del decreto legislativo 3 aprile 2006, n. 152, ovvero della conclusione motivata della conferenza di servizi di cui all'articolo 27-bis del decreto legislativo 3 aprile 2006, n. 152, tali da porre in pericolo l'integrita' dei beni culturali soggetti a tutela, il soprintendente ordina la sospensione dei lavori.))

((31))

---------------- AGGIORNAMENTO (31) Il D.Lgs. 16 giugno 2017, n. 104 ha disposto (con l'art. 23, comma 1) che "Le disposizioni del presente decreto si applicano ai procedimenti di verifica di assoggettabilita' a VIA e ai procedimenti di VIA avviati dal 16 maggio 2017". Ha inoltre disposto (con l'art. 23, comma 2) che "I procedimenti di verifica di assoggettabilita' a VIA pendenti alla data del 16 maggio 2017, nonche' i procedimenti di VIA per i progetti per i quali alla medesima data risulti avviata la fase di consultazione di cui all'articolo 21 del decreto legislativo 3 aprile 2006, n. 152, ovvero sia stata presentata l'istanza di cui all'articolo 23 del medesimo decreto legislativo, restano disciplinati dalla normativa previgente".

#### Articolo 27 - Situazioni di urgenza

1. Nel caso di assoluta urgenza possono essere effettuati gli interventi provvisori indispensabili per evitare danni al bene tutelato, purche' ne sia data immediata comunicazione alla soprintendenza, alla quale sono tempestivamente inviati i progetti degli interventi definitivi per la necessaria autorizzazione.

#### Articolo 28 - Misure cautelari e preventive

1. Il soprintendente puo' ordinare la sospensione di interventi iniziati contro il disposto degli articoli 20, 21, 25, 26 e 27 ovvero condotti in difformita' dall'autorizzazione.

2. Al soprintendente spetta altresi' la facolta' di ordinare l'inibizione o la sospensione di interventi relativi alle cose indicate nell'articolo 10, anche quando per esse non siano ancora intervenute la verifica di cui all'articolo 12, comma 2, o la dichiarazione di cui all'articolo 13.

3. L'ordine di cui al comma 2 si intende revocato se, entro trenta giorni dalla ricezione del medesimo, non e' comunicato, a cura del soprintendente, l'avvio del procedimento di verifica o di dichiarazione.

4. In caso di realizzazione (( di lavori pubblici )) ricadenti in aree di interesse archeologico, anche quando per esse non siano intervenute la verifica di cui all'articolo 12, comma 2, o la dichiarazione di cui all'articolo 13, il soprintendente puo' richiedere l'esecuzione di saggi archeologici preventivi sulle aree medesime a spese del committente (( . . . )).

### Sezione II - Misure di conservazione

#### Articolo 29 - Conservazione

1. La conservazione del patrimonio culturale e' assicurata mediante una coerente, coordinata e programmata attivita' di studio, prevenzione, manutenzione e restauro.

2. Per prevenzione si intende il complesso delle attivita' idonee a limitare le situazioni di rischio connesse al bene culturale nel suo contesto.

3. Per manutenzione si intende il complesso delle attivita' e degli interventi destinati al controllo delle condizioni del bene culturale e al mantenimento dell'integrita', dell'efficienza funzionale e dell'identita' del bene e delle sue parti.

4. Per restauro si intende l'intervento diretto sul bene attraverso un complesso di operazioni finalizzate all'integrita' materiale ed al recupero del bene medesimo, alla protezione ed alla trasmissione dei suoi valori culturali. Nel caso di beni immobili situati nelle zone dichiarate a rischio sismico in base alla normativa vigente, il restauro comprende l'intervento di miglioramento strutturale.

5. Il Ministero definisce, anche con il concorso delle regioni e con la collaborazione delle universita' e degli istituti di ricerca competenti, linee di indirizzo, norme tecniche, criteri e modelli di intervento in materia di conservazione dei beni culturali.

6. Fermo quanto disposto dalla normativa in materia di progettazione ed esecuzione di opere su beni architettonici, gli interventi di manutenzione e restauro su beni culturali mobili e superfici decorate di beni architettonici sono eseguiti in via esclusiva da coloro che sono restauratori di beni culturali ai sensi della normativa in materia.

7. I profili di competenza dei restauratori e degli altri operatori che svolgono attivita' complementari al restauro o altre attivita' di conservazione dei beni culturali mobili e delle superfici decorate di beni architettonici sono definiti con decreto del Ministro adottato ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, d'intesa con la Conferenza Stato-regioni.

8. Con decreto del Ministro adottato ai sensi dell'articolo 17, comma 3, della legge n. 400 del 1988 di concerto con il (( Ministro dell'universita' e della ricerca )), sono definiti i criteri ed i livelli di qualita' cui si adegua l' insegnamento del restauro.

9. L'insegnamento del restauro e' impartito dalle scuole di alta formazione e di studio istituite ai sensi dell'articolo 9 del decreto legislativo 20 ottobre 1998, n. 368, nonche' dai centri di cui al comma 11 e dagli altri soggetti pubblici e privati accreditati presso lo Stato. Con decreto del Ministro adottato ai sensi dell'articolo 17, comma 3, della legge n. 400 del 1988 di concerto con il (( Ministro dell'universita' e della ricerca )), sono individuati le modalita' di accreditamento, i requisiti minimi organizzativi e di funzionamento dei soggetti di cui al presente comma, le modalita' della vigilanza sullo svolgimento delle attivita' didattiche e dell'esame finale, abilitante alle attivita' di cui al comma 6 e avente valore di esame di Stato, cui partecipa almeno un rappresentante del Ministero, il titolo accademico rilasciato a seguito del superamento di detto esame, che e' equiparato al diploma di laurea specialistica o magistrale, nonche' le caratteristiche del corpo docente. Il procedimento di accreditamento si conclude con provvedimento adottato entro novanta giorni dalla presentazione della domanda corredata dalla prescritta documentazione.

9-bis. Dalla data di entrata in vigore dei decreti previsti dai commi 7, 8 e 9, agli effetti dell'esecuzione degli interventi di manutenzione e restauro su beni culturali mobili e superfici decorate di beni architettonici, nonche' agli effetti del possesso dei requisiti di qualificazione da parte dei soggetti esecutori di detti lavori, la qualifica di restauratore di beni culturali e' acquisita esclusivamente in applicazione delle predette disposizioni.

10. La formazione delle figure professionali che svolgono attivita' complementari al restauro o altre attivita' di conservazione e' assicurata da soggetti pubblici e privati ai sensi della normativa regionale. I relativi corsi si adeguano a criteri e livelli di qualita' definiti con accordo in sede di Conferenza Stato-regioni, ai sensi dell'articolo 4 del decreto legislativo 28 agosto 1997, n. 281.

11. Mediante appositi accordi il Ministero e le regioni, anche con il concorso delle universita' e di altri soggetti pubblici e privati, possono istituire congiuntamente centri, anche a carattere interregionale, dotati di personalita' giuridica, cui affidare attivita' di ricerca, sperimentazione, studio, documentazione ed attuazione di interventi di conservazione e restauro su beni culturali, di particolare complessita'. Presso tali centri possono essere altresi' istituite, ove accreditate, ai sensi del comma 9, scuole di alta formazione per l'insegnamento del restauro. All' attuazione del presente comma si provvede nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica.

#### Articolo 30 - Obblighi conservativi

1. Lo Stato, le regioni, gli altri enti pubblici territoriali nonche' ogni altro ente ed istituto pubblico hanno l'obbligo di garantire la sicurezza e la conservazione dei beni culturali di loro appartenenza.

2. I soggetti indicati al comma 1 e le persone giuridiche private senza fine di lucro (( , ivi compresi gli enti ecclesiastici civilmente riconosciuti, ))fissano i beni culturali di loro appartenenza, ad eccezione degli archivi correnti, nel luogo di loro destinazione nel modo indicato dal soprintendente.

3. I privati proprietari, possessori o detentori di beni culturali sono tenuti a garantirne la conservazione.

4. (( I soggetti indicati al comma 1 hanno l'obbligo di conservare i propri archivi nella loro organicita' e di ordinarli. I soggetti medesimi hanno altresi' l'obbligo di inventariare i propri archivi storici, costituiti dai documenti relativi agli affari esauriti da oltre quaranta anni ed istituiti in sezioni separate. )) ((Agli stessi obblighi di conservazione e inventariazione )) sono assoggettati i proprietari, possessori o detentori, a qualsiasi titolo, di archivi privati per i quali sia intervenuta la dichiarazione di cui all'articolo 13. Copia degli inventari e dei relativi aggiornamenti e' inviata alla soprintendenza, nonche' al Ministero dell'interno per gli accertamenti di cui all'articolo 125.

#### Articolo 31 - Interventi conservativi volontari

1. Il restauro e gli altri interventi conservativi su beni culturali ad iniziativa del proprietario, possessore o detentore a qualsiasi titolo sono autorizzati ai sensi dell'articolo 21.

2. In sede di autorizzazione, il soprintendente si pronuncia, a richiesta dell'interessato, sull'ammissibilita' dell'intervento ai contributi statali previsti dagli articoli 35 e 37 e certifica eventualmente il carattere necessario dell'intervento stesso ai fini della concessione delle agevolazioni tributarie previste dalla legge.

2-bis. L'ammissione dell'intervento autorizzato ai contributi statali previsti ((dall'articolo)) 37 e' disposta dagli organi del Ministero in base all'ammontare delle risorse disponibili, determinate annualmente con decreto ministeriale, adottato di concerto con il Ministero dell'economia e delle finanze. ((34))

--------------- AGGIORNAMENTO (34) La L. 27 dicembre 2017, n. 205 ha disposto (con l'art. 1, comma 314) che la presente modifica ha effetto a decorrere dal 1° gennaio 2019.

#### Articolo 32 - Interventi conservativi imposti

1. Il Ministero puo' imporre al proprietario, possessore o detentore a qualsiasi titolo gli interventi necessari per assicurare la conservazione dei beni culturali, ovvero provvedervi direttamente.

2. Le disposizioni del comma 1 si applicano anche agli obblighi di cui all'articolo 30, comma 4.

#### Articolo 33 - Procedura di esecuzione degli interventi conservativi imposti

1. Ai fini dell'articolo 32 il soprintendente redige una relazione tecnica e dichiara la necessita' degli interventi da eseguire.

2. La relazione tecnica e' inviata, insieme alla comunicazione di avvio del procedimento, al proprietario, possessore o detentore del bene, che puo' far pervenire le sue osservazioni entro trenta giorni dal ricevimento degli atti.

3. Il soprintendente, se non ritiene necessaria l'esecuzione diretta degli interventi, assegna al proprietario, possessore o detentore un termine per la presentazione del progetto esecutivo delle opere da effettuarsi, conformemente alla relazione tecnica.

4. Il progetto presentato e' approvato dal soprintendente con le eventuali prescrizioni e con la fissazione del termine per l'inizio dei lavori. Per i beni immobili il progetto presentato e' trasmesso dalla soprintendenza (( al comune e alla citta' metropolitana )), che possono esprimere parere motivato entro trenta giorni dalla ricezione della comunicazione.

5. Se il proprietario, possessore o detentore del bene non adempie all'obbligo di presentazione del progetto, o non provvede a modificarlo secondo le indicazioni del soprintendente nel termine da esso fissato, ovvero se il progetto e' respinto, si procede con l'esecuzione diretta.

6. In caso di urgenza, il soprintendente puo' adottare immediatamente le misure conservative necessarie.

#### Articolo 34 - Oneri per gli interventi conservativi imposti

1. Gli oneri per gli interventi su beni culturali, imposti o eseguiti direttamente dal Ministero ai sensi dell'articolo 32, sono a carico del proprietario, possessore o detentore. Tuttavia, se gli interventi sono di particolare rilevanza ovvero sono eseguiti su beni in uso o godimento pubblico, il Ministero puo' concorrere in tutto o in parte alla relativa spesa. In tal caso, determina l'ammontare dell'onere che intende sostenere e ne da' comunicazione all'interessato.

2. Se le spese degli interventi sono sostenute dal proprietario, possessore o detentore, il Ministero provvede al loro rimborso, anche mediante l'erogazione di acconti ai sensi dell'articolo 36, commi 2 e 3, nei limiti dell'ammontare determinato ai sensi del comma 1.

3. Per le spese degli interventi sostenute direttamente, il Ministero determina la somma da porre a carico del proprietario, possessore o detentore, e ne cura il recupero nelle forme previste dalla normativa in materia di riscossione coattiva delle entrate patrimoniali dello Stato.

#### Articolo 35 - Intervento finanziario del Ministero

1. Il Ministero ha facolta' di concorrere alla spesa sostenuta dal proprietario, possessore o detentore del bene culturale per l'esecuzione degli interventi previsti dall'articolo 31, comma 1, per un ammontare non superiore alla meta' della stessa. Se gli interventi sono di particolare rilevanza o riguardano beni in uso o godimento pubblico, il Ministero puo' concorrere alla spesa fino al suo intero ammontare.

2. La disposizione del comma 1 si applica anche agli interventi sugli archivi storici previsti dall'articolo 30, comma 4.

3. Per la determinazione della percentuale del contributo di cui al comma 1 si tiene conto di altri contributi pubblici e di eventuali contributi privati relativamente ai quali siano stati ottenuti benefici fiscali. (16) ((17))

--------------- AGGIORNAMENTO (16) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 1, comma 26-ter) che "A decorrere dalla data di entrata in vigore della legge di conversione del presente decreto e fino al 31 dicembre 2015 e' sospesa la concessione dei contributi di cui agli articoli 35 e 37 del decreto legislativo 22 gennaio 2004, n. 42, e successive modificazioni". --------------- AGGIORNAMENTO (17) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dalla L. 24 dicembre 2012, n. 228, ha disposto (con l'art. 1, comma 26-ter) che "A decorrere dalla data di entrata in vigore della legge di conversione del presente decreto e fino al pagamento dei contributi gia' concessi alla medesima data e non ancora erogati ai beneficiari e' sospesa la concessione dei contributi di cui agli articoli 35 e 37 del decreto legislativo 22 gennaio 2004, n. 42, e successive modificazioni".

#### Articolo 36 - Erogazione del contributo

1. Il contributo e' concesso dal Ministero a lavori ultimati e collaudati sulla spesa effettivamente sostenuta dal beneficiario.

2. Possono essere erogati acconti sulla base degli stati di avanzamento dei lavori regolarmente certificati.

3. Il beneficiario e' tenuto alla restituzione degli acconti percepiti se gli interventi non sono stati, in tutto o in parte, regolarmente eseguiti. Per il recupero delle relative somme si provvede nelle forme previste dalla normativa in materia di riscossione coattiva delle entrate patrimoniali dello Stato.

#### Articolo 37 - Contributo in conto interessi

1. Il Ministero puo' concedere contributi in conto interessi sui mutui o altre forme di finanziamento accordati da istituti di credito ai proprietari, possessori o detentori a qualsiasi titolo di beni culturali per la realizzazione degli interventi conservativi autorizzati.

2. Il contributo e' concesso nella misura massima corrispondente agli interessi calcolati ad un tasso annuo di sei punti percentuali sul capitale erogato.

3. Il contributo e' corrisposto direttamente dal Ministero all'istituto di credito secondo modalita' da stabilire con convenzioni.

4. Il contributo di cui al comma 1 puo' essere concesso anche per interventi conservativi su opere di architettura contemporanea di cui il Ministero abbia riconosciuto, su richiesta del proprietario, il particolare valore artistico. (16) ((17))

--------------- AGGIORNAMENTO (16) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, ha disposto (con l'art. 1, comma 26-ter) che "A decorrere dalla data di entrata in vigore della legge di conversione del presente decreto e fino al 31 dicembre 2015 e' sospesa la concessione dei contributi di cui agli articoli 35 e 37 del decreto legislativo 22 gennaio 2004, n. 42, e successive modificazioni". --------------- AGGIORNAMENTO (17) Il D.L. 6 luglio 2012, n. 95, convertito con modificazioni dalla L. 7 agosto 2012, n. 135, come modificato dalla L. 24 dicembre 2012, n. 228, ha disposto (con l'art. 1, comma 26-ter) che "A decorrere dalla data di entrata in vigore della legge di conversione del presente decreto e fino al pagamento dei contributi gia' concessi alla medesima data e non ancora erogati ai beneficiari e' sospesa la concessione dei contributi di cui agli articoli 35 e 37 del decreto legislativo 22 gennaio 2004, n. 42, e successive modificazioni".

#### Articolo 38

(( Accessibilita' al pubblico dei beni culturali )) oggetto di interventi conservativi

1. I beni culturali restaurati o sottoposti ad altri interventi conservativi con il concorso totale o parziale dello Stato nella spesa, o per i quali siano stati concessi contributi in conto interessi, sono resi accessibili al pubblico secondo modalita' fissate, caso per caso, da appositi accordi o convenzioni da stipularsi fra il Ministero ed i singoli proprietari all'atto della assunzione dell'onere della spesa ai sensi dell'articolo 34 o della concessione del contributo ai sensi (( degli articoli 35 e 37 )).

2. Gli accordi e le convenzioni stabiliscono i limiti temporali dell'obbligo di apertura al pubblico, tenendo conto della tipologia degli interventi, del valore artistico e storico degli immobili e dei beni in essi esistenti. Accordi e convenzioni sono trasmessi, a cura del soprintendente, (( al comune e alla citta' metropolitana )) nel cui territorio si trovano gli immobili.

#### Articolo 39 - Interventi conservativi su beni dello Stato

1. Il Ministero provvede alle esigenze di conservazione dei beni culturali di appartenenza statale, anche se in consegna o in uso ad amministrazioni diverse o ad altri soggetti, sentiti i medesimi.

2. Salvo che non sia diversamente concordato, la progettazione e l'esecuzione degli interventi di cui al comma 1((. . .)) sono assunte dall'amministrazione o dal soggetto medesimi, ferma restando la competenza del Ministero al rilascio dell'autorizzazione sul progetto ed alla vigilanza sui lavori.

3. Per l'esecuzione degli interventi di cui al comma 1, relativi a beni immobili, il Ministero trasmette il progetto e comunica l'inizio dei lavori (( al comune e alla citta' metropolitana )).

#### Articolo 40 - Interventi conservativi su beni delle regioni e degli altri enti pubblici territoriali

1. Per i beni culturali appartenenti alle regioni e agli altri enti pubblici territoriali, le misure previste dall'articolo 32 sono disposte, salvo i casi di assoluta urgenza, in base ad accordi con l'ente interessato.

2. Gli accordi possono riguardare anche i contenuti delle prescrizioni di cui all'articolo 30, comma 2.

3. Gli interventi conservativi sui beni culturali che coinvolgono lo Stato, le regioni e gli altri enti pubblici territoriali nonche' altri soggetti pubblici e privati, sono ordinariamente oggetto di preventivi accordi programmatici.

#### Articolo 41 - Obblighi di versamento agli Archivi di Stato dei documenti conservati dalle amministrazioni statali

1. Gli organi giudiziari e amministrativi dello Stato versano all'archivio centrale dello Stato e agli archivi di Stato i documenti relativi agli affari esauriti da oltre trent'anni, unitamente agli strumenti che ne garantiscono la consultazione. Le liste di leva e di estrazione sono versate settant'anni dopo l'anno di nascita della classe cui si riferiscono. Gli archivi notarili versano gli atti notarili ricevuti dai notai che cessarono l'esercizio professionale anteriormente all'ultimo centennio.

2. Il soprintendente all'archivio centrale dello Stato e i direttori degli archivi di Stato possono accettare versamenti di documenti piu' recenti, quando vi sia pericolo di dispersione o di danneggiamento, ovvero siano stati definiti appositi accordi con i responsabili delle amministrazioni versanti.

3. Nessun versamento puo' essere ricevuto se non sono state effettuate le operazioni di scarto. Le spese per il versamento sono a carico delle amministrazioni versanti.

4. Gli archivi degli uffici statali soppressi e degli enti pubblici estinti sono versati all'archivio centrale dello Stato e agli archivi di Stato, a meno che non se ne renda necessario il trasferimento, in tutto o in parte, ad altri enti.

5. Presso gli organi indicati nel comma 1 sono istituite Commissioni di sorveglianza, delle quali fanno parte il soprintendente all'archivio centrale dello Stato e i direttori degli archivi di Stato quali rappresentanti del Ministero, e rappresentanti del Ministero dell'interno, con il compito di vigilare sulla corretta tenuta degli archivi correnti e di deposito, di collaborare alla definizione dei criteri di organizzazione, gestione e conservazione dei documenti, di proporre gli scarti di cui al comma 3, di curare i versamenti previsti al comma 1, di identificare gli atti di natura riservata. La composizione e il funzionamento delle commissioni sono disciplinati con decreto adottato dal Ministro di concerto con il Ministro dell'interno, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400. Gli scarti sono autorizzati dal Ministero.

6. Le disposizioni del presente articolo non si applicano al Ministero degli affari esteri non si applicano altresi' agli stati maggiori della difesa, dell'esercito, della marina e dell'aeronautica, nonche' al Comando generale dell'Arma dei carabinieri, per quanto attiene la documentazione di carattere militare e operativo ((, ne' all'Agenzia per la cybersicurezza nazionale, per quanto attiene alla documentazione connessa all'esercizio delle sue funzioni volte alla tutela della sicurezza nazionale e dell'interesse nazionale nello spazio cibernetico)).

#### Art. 42. - Conservazione degli archivi storici di organi costituzionali

1. La Presidenza della Repubblica conserva i suoi atti presso il proprio archivio storico, secondo le determinazioni assunte dal Presidente della Repubblica con proprio decreto, su proposta del Segretario generale della Presidenza della Repubblica. Con lo stesso decreto sono stabilite le modalita' di consultazione e di accesso agli atti conservati presso l'archivio storico della Presidenza della Repubblica.

2. La Camera dei deputati e il Senato della Repubblica conservano i loro atti presso il proprio archivio storico, secondo le determinazioni dei rispettivi uffici di presidenza.

3. La Corte Costituzionale conserva i suoi atti presso il proprio archivio storico, secondo le disposizioni stabilite con regolamento adottato ai sensi della vigente normativa in materia di costituzione e funzionamento della Corte medesima.

3-bis. (( COMMA ABROGATO DAL D.LGS. 26 MARZO 2008, N. 62 )).

#### Articolo 43 - Custodia coattiva

1. Il Ministero ha facolta' di far trasportare e temporaneamente custodire in pubblici istituti i beni culturali mobili al fine di garantirne la sicurezza o assicurarne la conservazione ai sensi dell'articolo 29.

((

1-bis. Il Ministero, su proposta del soprintendente archivistico, ha facolta' di disporre il deposito coattivo, negli archivi di Stato competenti, delle sezioni separate di archivio di cui all'articolo 30, comma 4, secondo periodo, ovvero di quella parte degli archivi degli enti pubblici che avrebbe dovuto costituirne sezione separata. In alternativa, il Ministero puo' stabilire, su proposta del soprintendente archivistico, l'istituzione della sezione separata presso l'ente inadempiente. Gli oneri derivanti dall'attuazione dei provvedimenti di cui al presente comma sono a carico dell'ente pubblico cui l'archivio pertiene. Dall'attuazione del presente comma non devono, comunque, derivare nuovi o maggiori oneri a carico della finanza pubblica.

))

#### Articolo 44 - Comodato e deposito di beni culturali

1. I direttori degli archivi e degli istituti che abbiano in amministrazione o in deposito raccolte o collezioni artistiche, archeologiche, bibliografiche e scientifiche possono ricevere in comodato da privati proprietari, previo assenso del competente organo ministeriale, beni culturali mobili al fine di consentirne la fruizione da parte della collettivita', qualora si tratti di beni di particolare pregio o che rappresentino significative integrazioni delle collezioni pubbliche e purche' la loro custodia presso i pubblici istituti non risulti particolarmente onerosa.

2. Il comodato non puo' avere durata inferiore a cinque anni e si intende prorogato tacitamente per un periodo pari a quello convenuto, qualora una delle parti contraenti non abbia comunicato all'altra la disdetta almeno due mesi prima della scadenza del termine. Anche prima della scadenza le parti possono risolvere consensualmente il comodato.

3. I direttori adottano ogni misura necessaria per la conservazione dei beni ricevuti in comodato, dandone comunicazione al comodante. Le relative spese sono a carico del Ministero.

4. I beni sono protetti da idonea copertura assicurativa a carico del Ministero. L'assicurazione puo' essere sostituita dall' assunzione dei relativi rischi da parte dello Stato, ai sensi dell' articolo 48, comma 5.

5. I direttori possono ricevere altresi' in deposito, previo assenso del competente organo ministeriale, beni culturali appartenenti ad enti pubblici. Le spese di conservazione e custodia specificamente riferite ai beni depositati sono a carico degli enti depositanti ((, salvo che le parti abbiano convenuto che le spese medesime siano, in tutto o in parte, a carico del Ministero, anche in ragione del particolare pregio dei beni e del rispetto degli obblighi di conservazione da parte dell'ente depositante. Dall'attuazione del presente comma non devono derivare nuovi o maggiori oneri a carico della finanza pubblica )).

6. Per quanto non espressamente previsto dal presente articolo, si applicano le disposizioni in materia di comodato e di deposito.

### Sezione III - Altre forme di protezione

#### Articolo 45 - Prescrizioni di tutela indiretta

1. Il Ministero ha facolta' di prescrivere le distanze, le misure e le altre norme dirette ad evitare che sia messa in pericolo l'integrita' dei beni culturali immobili, ne sia danneggiata la prospettiva o la luce o ne siano alterate le condizioni di ambiente e di decoro.

2. Le prescrizioni di cui al comma 1, adottate e notificate ai sensi degli articoli 46 e 47, sono immediatamente precettive. Gli enti pubblici territoriali interessati recepiscono le prescrizioni medesime nei regolamenti edilizi e negli strumenti urbanistici.

#### Articolo 46 - Procedimento per la tutela indiretta

1. Il soprintendente avvia il procedimento per la tutela indiretta, anche su motivata richiesta della regione o di altri enti pubblici territoriali interessati, dandone comunicazione al proprietario, possessore o detentore a qualsiasi titolo dell'immobile cui le prescrizioni si riferiscono. Se per il numero dei destinatari la comunicazione personale non e' possibile o risulta particolarmente gravosa, il soprintendente comunica 1' avvio del procedimento mediante idonee forme di pubblicita'.

2. La comunicazione di avvio del procedimento individua l'immobile in relazione al quale si intendono adottare le prescrizioni di tutela indiretta e indica i contenuti essenziali di tali prescrizioni.

3. Nel caso di complessi immobiliari, la comunicazione e' inviata anche al comune e alla citta' metropolitana.

4. La comunicazione comporta, in via cautelare, la temporanea immodificabilita' dell'immobile limitatamente agli aspetti cui si riferiscono le prescrizioni contenute nella comunicazione stessa.

5. Gli effetti indicati al comma 4 cessano alla scadenza del termine del relativo procedimento, stabilito dal Ministero (( ai sensi delle vigenti disposizioni di legge in materia di procedimento amministrativo )).

#### Articolo 47 - Notifica delle prescrizioni di tutela indiretta e ricorso amministrativo

1. Il provvedimento contenente le prescrizioni di tutela indiretta e' notificato al proprietario, possessore o detentore a qualsiasi titolo degli immobili interessati, tramite messo comunale o a mezzo posta raccomandata con avviso di ricevimento.

2. Il provvedimento e' trascritto nei registri immobiliari e ha efficacia nei confronti di ogni successivo proprietario, possessore o detentore a qualsiasi titolo degli immobili cui le prescrizioni stesse si riferiscono.

3. Avverso il provvedimento contenente le prescrizioni di tutela indiretta e' ammesso ricorso amministrativo ai sensi dell'articolo 16. La proposizione del ricorso, tuttavia, non comporta la sospensione degli effetti del provvedimento impugnato.

#### Articolo 48 - Autorizzazione per mostre ed esposizioni

1. E' soggetto ad autorizzazione il prestito per mostre ed esposizioni:

- a) delle cose mobili indicate nell'articolo 12, comma 1;
- b) dei beni mobili indicati nell'articolo 10, comma 1;
- c) dei beni mobili indicati all'articolo 10, comma 3, lettere a), ed e);
- d) delle raccolte e dei singoli beni ad esse pertinenti, di cui all'articolo 10, comma 2, lettera a), delle raccolte librarie indicate all'articolo 10, commi 2, lettera c), e 3, lettera c), nonche' degli archivi e dei singoli documenti indicati all'articolo 10, commi 2, lettera b), e 3, lettera b).

2. Qualora l'autorizzazione abbia ad oggetto beni appartenenti allo Stato o sottoposti a tutela statale, la richiesta e' presentata al Ministero almeno quattro mesi prima dell'inizio della manifestazione ed indica il responsabile della custodia delle opere in prestito.

3. L'autorizzazione e' rilasciata tenendo conto delle esigenze di conservazione dei beni e, per quelli appartenenti allo Stato, anche delle esigenze di fruizione pubblica; essa e' subordinata all'adozione delle misure necessarie per garantirne l'integrita'. I criteri, le procedure e le modalita' per il rilascio dell'autorizzazione medesima sono stabiliti con decreto ministeriale.

4. Il rilascio dell'autorizzazione e' inoltre subordinato all'assicurazione delle cose e dei beni da parte del richiedente, per il valore indicato nella domanda, previa verifica della sua congruita' da parte del Ministero.

5. Per le mostre e le manifestazioni sul territorio nazionale promosse dal Ministero o, con la partecipazione statale, da enti o istituti pubblici, l'assicurazione prevista al comma 4 puo' essere sostituita dall'assunzione dei relativi rischi da parte dello Stato. La garanzia statale e' rilasciata secondo le procedure, le modalita' e alle condizioni stabilite con decreto ministeriale, sentito il Ministero dell'economia e delle finanze. Ai corrispondenti oneri si provvede mediante utilizzazione delle risorse disponibili nell'ambito del fondo di riserva per le spese obbligatorie e d'ordine istituito nello stato di previsione della spesa del Ministero dell'economia e delle finanze.

6. Il Ministero ha facolta' di dichiarare, a richiesta dell'interessato, il rilevante interesse culturale o scientifico di mostre o esposizioni di beni culturali e di ogni altra iniziativa a carattere culturale, ai fini dell'applicazione delle agevolazioni previste dalla normativa fiscale.

#### Articolo 49 - Manifesti e cartelli pubblicitari

1. E' vietato collocare o affiggere cartelli o altri mezzi di pubblicita' sugli edifici e nelle aree tutelati come beni culturali. (( Il collocamento o l'affissione possono essere autorizzati dal soprintendente qualora non danneggino l'aspetto, il decoro o la pubblica fruizione di detti immobili. L'autorizzazione e' trasmessa, a cura degli interessati, agli altri enti competenti all'eventuale emanazione degli ulteriori atti abilitativi. ))

2. Lungo le strade site nell'ambito o in prossimita' dei beni indicati al comma 1, e' vietato collocare cartelli o altri mezzi di pubblicita', salvo autorizzazione rilasciata ai sensi della normativa in materia di circolazione stradale e di pubblicita' sulle strade e sui veicoli, previo parere favorevole della soprintendenza sulla compatibilita' della collocazione o della tipologia del mezzo di pubblicita' con l'aspetto, il decoro e la pubblica fruizione dei beni tutelati.

3. In relazione ai beni indicati al comma 1 il soprintendente, valutatane la compatibilita' con il loro carattere artistico o storico, rilascia o nega il nulla osta o l'assenso per l'utilizzo a fini pubblicitari delle coperture dei ponteggi predisposti per l'esecuzione degli interventi di conservazione, per un periodo non superiore alla durata dei lavori. A tal fine alla richiesta di nulla osta o di assenso deve essere allegato il contratto di appalto dei lavori medesimi.

#### Articolo 50 - Distacco di beni culturali

1. E' vietato, senza l'autorizzazione del soprintendente, disporre ed eseguire il distacco di affreschi, stemmi, graffiti, lapidi, iscrizioni, tabernacoli (( ed altri elementi decorativi di edifici )), esposti o non alla pubblica vista.

2. E' vietato, senza l'autorizzazione del soprintendente, disporre ed eseguire il distacco di stemmi, graffiti, lapidi, iscrizioni, tabernacoli nonche' la rimozione di cippi e monumenti, costituenti vestigia della Prima guerra mondiale ai sensi della normativa in materia.

#### Articolo 51 - Studi d'artista

1. E' vietato modificare la destinazione d'uso degli studi d'artista nonche' rimuoverne il contenuto, costituito da opere, documenti, cimeli e simili, qualora esso, considerato nel suo insieme ed in relazione al contesto in cui e' inserito, sia dichiarato di interesse particolarmente importante per il suo valore storico, ai sensi dell'articolo 13.

2. E' altresi' vietato modificare la destinazione d'uso degli studi d'artista rispondenti alla tradizionale tipologia a lucernario e adibiti a tale funzione da almeno vent'anni.

#### Articolo 52 - Esercizio del commercio in aree di valore culturale e nei locali storici tradizionali

1. Con le deliberazioni previste dalla normativa in materia di riforma della disciplina relativa al settore del commercio, i comuni, sentito il soprintendente, individuano le aree pubbliche aventi valore archeologico, storico, artistico e paesaggistico nelle quali vietare o sottoporre a condizioni particolari l'esercizio del commercio.

1-bis. Fermo restando quanto previsto dall'articolo 7-bis, i comuni, sentito il soprintendente, individuano altresi' i locali, a chiunque appartenenti, nei quali si svolgono attivita' di artigianato tradizionale e altre attivita' commerciali tradizionali, riconosciute quali espressione dell'identita' culturale collettiva ai sensi delle convenzioni UNESCO di cui al medesimo articolo 7-bis, al fine di assicurarne apposite forme di promozione e salvaguardia, nel rispetto della liberta' di iniziativa economica di cui all'articolo 41 della Costituzione. (25)

1-ter. Al fine di assicurare il decoro dei complessi monumentali e degli altri immobili del demanio culturale interessati da flussi turistici particolarmente rilevanti, nonche' delle aree a essi contermini, i competenti uffici territoriali del Ministero, d'intesa con ((la regione e)) i Comuni, adottano apposite determinazioni volte a vietare gli usi da ritenere non compatibili con le specifiche esigenze di tutela e di valorizzazione, comprese le forme di uso pubblico non soggette a concessione di uso individuale, quali le attivita' ambulanti senza posteggio, nonche', ove se ne riscontri la necessita', l'uso individuale delle aree pubbliche di pregio a seguito del rilascio di concessioni di posteggio o di occupazione di suolo pubblico. In particolare, i competenti uffici territoriali del Ministero ((, la regione)) e i Comuni avviano, d'intesa, procedimenti di riesame, ai sensi dell'articolo 21-quinquies della legge 7 agosto 1990, n. 241, delle autorizzazioni e delle concessioni di suolo pubblico, anche a rotazione, che risultino non piu' compatibili con le esigenze di cui al presente comma, anche in deroga a eventuali disposizioni regionali adottate in base all'articolo 28, commi 12, 13 e 14, del decreto legislativo 31 marzo 1998, n. 114, e successive modificazioni, nonche' in deroga ai criteri per il rilascio e il rinnovo della concessione dei posteggi per l'esercizio del commercio su aree pubbliche e alle disposizioni transitorie stabilite nell'intesa in sede di Conferenza unificata, ai sensi dell'articolo 8, comma 6, della legge 5 giugno 2003, n. 131, prevista dall'articolo 70, comma 5, del decreto legislativo 26 marzo 2010, n. 59 recante attuazione della direttiva 2006/123/CE del Parlamento europeo e del Consiglio del 12 dicembre 2006 relativa ai servizi nel mercato interno. In caso di revoca del titolo, ove non risulti possibile il trasferimento dell'attivita' commerciale in una collocazione alternativa potenzialmente equivalente, al titolare e' corrisposto da parte dell'amministrazione procedente l'indennizzo di cui all'articolo 21-quinquies, comma 1, terzo periodo, della legge 7 agosto 1990, n. 241, nel limite massimo della media dei ricavi annui dichiarati negli ultimi cinque anni di attivita', aumentabile del 50 per cento in caso di comprovati investimenti effettuati nello stesso periodo per adeguarsi alle nuove prescrizioni in materia emanate dagli enti locali. (25)

--------------- AGGIORNAMENTO (25) Successivamente la Corte Costituzionale, con sentenza 9 giugno - 9 luglio 2015, n. 140 (in G.U. 1ª s.s. 15/7/2015, n. 28), ha dichiarato l'illegittimita' costituzionale: - dell'art. 2-bis del D.L. 8 agosto 2013, n. 91, convertito con modificazioni dalla L. 7 ottobre 2013, n. 112 (che con la lettera a) ha introdotto il comma 1-bis al presente articolo e con la lettera b) ne ha modificato la rubrica), nella parte in cui non prevede l'intesa fra Stato e Regioni; - dell'art. 4-bis del D.L. 8 agosto 2013, n. 91, convertito con modificazioni dalla L. 7 ottobre 2013, n. 112 (che ha introdotto un ulteriore comma 1-bis al presente articolo), nella parte in cui non prevede l'intesa fra Stato e Regioni; - dell'art. 4, comma 1 del D.L. 31 maggio 2014, n. 83, convertito con modificazioni dalla L. 29 luglio 2014, n. 106 (che ha rinominato e modificato il comma 1-ter del presente articolo), nella parte in cui non prevede alcuno strumento idoneo a garantire una leale collaborazione fra Stato e Regioni.

## Capo IV - Circolazione in ambito nazionale

### Sezione I - Alienazione e altri modi di trasmissione

#### Articolo 53 - Beni del demanio culturale

1. I beni culturali appartenenti allo Stato, alle regioni e agli altri enti pubblici territoriali che rientrino nelle tipologie indicate all'articolo 822 del codice civile costituiscono il demanio culturale.

2. I beni del demanio culturale non possono essere alienati, ne' formare oggetto di diritti a favore di terzi, se non (( nei limiti e con le modalita )) previsti dal presente codice.

#### Articolo 54 - Beni inalienabili

1. Sono inalienabili i beni del demanio culturale di seguito indicati:

- a) gli immobili e le aree di interesse archeologico;
- b) gli immobili dichiarati monumenti nazionali a termini della normativa all'epoca vigente;
- c) le raccolte di musei, pinacoteche, gallerie e biblioteche;
- d) gli archivi.
- d-bis) gli immobili dichiarati di interesse particolarmente importante ai sensi dell'articolo 10, comma 3, lettera d);
- d-ter) le cose mobili che siano opera di autore vivente o la cui esecuzione non risalga ad oltre ((settanta)) anni, se incluse in raccolte appartenenti ai soggetti di cui all'articolo 53.

2. Sono altresi' inalienabili:

- a) le cose appartenenti ai soggetti indicati all'articolo 10, comma 1, che siano opera di autore non piu' vivente e la cui esecuzione risalga ad oltre ((settanta)) anni ((...)), fino alla conclusione del procedimento di verifica previsto dall'articolo 12. Se il procedimento si conclude con esito negativo, le cose medesime sono liberamente alienabili, ai fini del presente codice, ai sensi dell'articolo 12, commi 4, 5 e 6 ;
- b) LETTERA SOPPRESSA DAL D.LGS. 26 MARZO 2008 N. 62;
- c) i singoli documenti appartenenti ai soggetti di cui all'articolo 53, nonche' gli archivi e i singoli documenti di enti ed istituti pubblici diversi da quelli indicati al medesimo articolo 53;
- d) LETTERA SOPPRESSA DAL D.LGS. 26 MARZO 2008 N. 62.

3. I beni e le cose di cui ai commi 1 e 2 possono essere oggetto di trasferimento tra lo Stato, le regioni e gli altri enti pubblici territoriali. Qualora si tratti di beni o cose non in consegna al Ministero, del trasferimento e' data preventiva comunicazione al Ministero medesimo per le finalita' di cui agli articoli 18 e 19.

4. I beni e le cose indicati ai commi 1 e 2 possono essere utilizzati esclusivamente secondo le modalita' e per i fini previsti dal Titolo II della presente Parte.

#### Articolo 55 - Alienabilita' di immobili appartenenti al demanio culturale

1. I beni culturali immobili appartenenti al demanio culturale e non rientranti tra quelli elencati (( nell'articolo 54, comma 1, )) non possono essere alienati senza l'autorizzazione del Ministero.

((

2. La richiesta di autorizzazione ad alienare e' corredata:

- a) dalla indicazione della destinazione d'uso in atto;
- b) dal programma delle misure necessarie ad assicurare la conservazione del bene;
- c) dall'indicazione degli obiettivi di valorizzazione che si intendono perseguire con l'alienazione del bene e delle modalita' e dei tempi previsti per il loro conseguimento;
- d) dall'indicazione della destinazione d'uso prevista, anche in funzione degli obiettivi di valorizzazione da conseguire;
- e) dalle modalita' di fruizione pubblica del bene, anche in rapporto con la situazione conseguente alle precedenti destinazioni d'uso.

3. L'autorizzazione e' rilasciata su parere del soprintendente, sentita la regione e, per suo tramite, gli altri enti pubblici territoriali interessati. Il provvedimento, in particolare:

- a) detta prescrizioni e condizioni in ordine alle misure di conservazione programmate;
- b) stabilisce le condizioni di fruizione pubblica del bene, tenuto conto della situazione conseguente alle precedenti destinazioni d'uso;
- c) si pronuncia sulla congruita' delle modalita' e dei tempi previsti per il conseguimento degli obiettivi di valorizzazione indicati nella richiesta.

3-bis. L'autorizzazione non puo' essere rilasciata qualora la destinazione d'uso proposta sia suscettibile di arrecare pregiudizio alla conservazione e fruizione pubblica del bene o comunque risulti non compatibile con il carattere storico e artistico del bene medesimo. Il Ministero ha facolta' di indicare, nel provvedimento di diniego, destinazioni d'uso ritenute compatibili con il carattere del bene e con le esigenze della sua conservazione.

3-ter. Il Ministero ha altresi' facolta' di concordare con il soggetto interessato il contenuto del provvedimento richiesto, sulla base di una valutazione comparativa fra le proposte avanzate con la richiesta di autorizzazione ed altre possibili modalita' di valorizzazione del bene.

3-quater. Qualora l'alienazione riguardi immobili utilizzati a scopo abitativo o commerciale, la richiesta di autorizzazione e' corredata dai soli elementi di cui al comma 2, lettere a), b) ed e), e l'autorizzazione e' rilasciata con le indicazioni di cui al comma 3, lettere a) e b).

3-quinquies. L'autorizzazione ad alienare comporta la sdemanializzazione del bene cui essa si riferisce. Tale bene resta comunque sottoposto a tutte le disposizioni di tutela di cui al presente titolo.

3-sexies. L'esecuzione di lavori ed opere di qualunque genere sui beni alienati e' sottoposta a preventiva autorizzazione ai sensi dell'articolo 21, commi 4 e 5.

))

#### Articolo 55-bis - (( (Clausola risolutiva) ))

((

1. Le prescrizioni e condizioni contenute nell'autorizzazione di cui all'articolo 55 sono riportate nell'atto di alienazione, del quale costituiscono obbligazione ai sensi dell'articolo 1456 del codice civile ed oggetto di apposita clausola risolutiva espressa. Esse sono anche trascritte, su richiesta del soprintendente, nei registri immobiliari.

2. Il soprintendente, qualora verifichi l'inadempimento, da parte dell'acquirente, dell'obbligazione di cui al comma 1, fermo restando l'esercizio dei poteri di tutela, da' comunicazione delle accertate inadempienze alle amministrazioni alienanti ai fini della risoluzione di diritto dell'atto di alienazione.

))

#### Articolo 56 - Altre alienazioni soggette ad autorizzazione

1. E' altresi' soggetta ad autorizzazione da parte del Ministero:

- a) l'alienazione dei beni culturali appartenenti allo Stato, alle regioni e agli altri enti pubblici territoriali, e diversi da quelli indicati negli articoli 54, commi 1 e 2, e 55, comma 1.
- b) l'alienazione dei beni culturali appartenenti a soggetti pubblici diversi da quelli indicati alla lettera a) o a persone giuridiche private senza fine di lucro, (( ivi compresi gli enti ecclesiastici civilmente riconosciuti )).

((

2. L'autorizzazione e' richiesta inoltre:

- a) nel caso di vendita, anche parziale, da parte di soggetti di cui al comma 1, lettera b), di collezioni o serie di oggetti e di raccolte librarie;
- b) nel caso di vendita, da parte di persone giuridiche private senza fine di lucro, ivi compresi gli enti ecclesiastici civilmente riconosciuti, di archivi o di singoli documenti.

3. La richiesta di autorizzazione e' corredata dagli elementi di cui all'articolo 55, comma 2, lettere a), b) ed e), e l'autorizzazione e' rilasciata con le indicazioni di cui al comma 3, lettere a) e b) del medesimo articolo.

4. Relativamente ai beni di cui al comma 1, lettera a), l'autorizzazione puo' essere rilasciata a condizione che i beni medesimi non abbiano interesse per le raccolte pubbliche e dall'alienazione non derivi danno alla loro conservazione e non ne sia menomata la pubblica fruizione.

))

((

4-bis. Relativamente ai beni di cui al comma 1, lettera b), e al comma 2, l'autorizzazione puo' essere rilasciata a condizione che dalla alienazione non derivi danno alla conservazione e alla pubblica fruizione dei beni medesimi.

4-ter. Le prescrizioni e condizioni contenute nell'autorizzazione sono riportate nell'atto di alienazione e sono trascritte, su richiesta del soprintendente, nei registri immobiliari.

4-quater. L'esecuzione di lavori ed opere di qualunque genere sui beni alienati e' sottoposta a preventiva autorizzazione ai sensi dell'articolo 21, commi 4 e 5.

4-quinquies. La disciplina dettata ai commi precedenti si applica anche alle costituzioni di ipoteca e di pegno ed ai negozi giuridici che possono comportare l'alienazione dei beni culturali ivi indicati.

4-sexies. Non e' soggetta ad autorizzazione l'alienazione delle cose indicate all'articolo 54, comma 2, lettera a), secondo periodo.

4-septies. Rimane ferma l'inalienabilita' disposta dall'articolo 54, comma 1, lettera d-ter).

))

#### Articolo 57

(( (Cessione di beni culturali in favore dello Stato) )). ((

1. Gli atti che comportano alienazione di beni culturali a favore dello Stato, ivi comprese le cessioni in pagamento di obbligazioni tributarie, non sono soggetti ad autorizzazione.

#### Articolo 57-bis - (( (Procedure di trasferimento di immobili pubblici). ))

((

1. Le disposizioni di cui agli articoli 54, 55 e 56 si applicano ad ogni procedura di dismissione o di valorizzazione e utilizzazione, anche a fini economici, di beni immobili pubblici di interesse culturale, prevista dalla normativa vigente e attuata, rispettivamente, mediante l'alienazione ovvero la concessione in uso o la locazione degli immobili medesimi.

2. Qualora si proceda alla concessione in uso o alla locazione di immobili pubblici di interesse culturale per le finalita' di cui al comma 1, le prescrizioni e condizioni contenute nell'autorizzazione sono riportate nell'atto di concessione o nel contratto di locazione e sono trascritte, su richiesta del soprintendente, nei registri immobiliari. L'inosservanza, da parte del concessionario o del locatario, delle prescrizioni e condizioni medesime, comunicata dal soprintendente alle amministrazioni cui i beni pertengono, da' luogo, su richiesta delle stesse amministrazioni, alla revoca della concessione o alla risoluzione del contratto, senza indennizzo.

))

#### Articolo 58 - Autorizzazione alla permuta

1. Il Ministero puo' autorizzare la permuta dei beni indicati agli articoli 55 e 56 nonche' di singoli beni appartenenti alle pubbliche raccolte con altri appartenenti ad enti, istituti e privati, anche stranieri, qualora dalla permuta stessa derivi un incremento del patrimonio culturale nazionale ovvero l'arricchimento delle pubbliche raccolte.

#### Articolo 59 - Denuncia di trasferimento

1. Gli atti che trasferiscono, in tutto o in parte, a qualsiasi titolo, la proprieta' o (( , limitatamente ai beni mobili,)) la detenzione di beni culturali sono denunciati al Ministero.

2. La denuncia e' effettuata entro trenta giorni:

- a) dall'alienante o dal cedente la detenzione, in caso di alienazione a titolo oneroso o gratuito o di trasferimento della detenzione;
- b) dall'acquirente, in caso di trasferimento avvenuto nell'ambito di procedure di vendita forzata o fallimentare ovvero in forza di sentenza che produca gli effetti di un contratto di alienazione non concluso;
- c) dall'erede o dal legatario, in caso di successione a causa di morte. Per l'erede, il termine decorre dall'accettazione dell'eredita' o dalla presentazione della dichiarazione ai competenti uffici tributari; per il legatario, il termine decorre dalla comunicazione notarile prevista dall'articolo 623 del codice civile, salva rinuncia ai sensi delle disposizioni del codice civile.

3. La denuncia e' presentata al competente soprintendente del luogo ove si trovano i beni.

4. La denuncia contiene:

- a) i dati identificativi delle parti e la sottoscrizione delle medesime o dei loro rappresentanti legali;
- b) i dati identificativi dei beni;
- c) l'indicazione del luogo ove si trovano i beni;
- d) l'indicazione della natura e delle condizioni dell'atto di trasferimento;
- e) l'indicazione del domicilio in Italia delle parti ai fini delle eventuali comunicazioni previste dal presente Titolo.

5. Si considera non avvenuta la denuncia priva delle indicazioni previste dal comma 4 o con indicazioni incomplete o imprecise.

### Sezione II - Prelazione

#### Articolo 60 - Acquisto in via di prelazione

1. Il Ministero o, nel caso previsto dall'articolo 62, comma 3, la regione o (( gli altri enti pubblici territoriali interessati )), hanno facolta' di acquistare in via di prelazione i beni culturali alienati a titolo oneroso o conferiti in societa', rispettivamente, al medesimo prezzo stabilito nell'atto di alienazione o al medesimo valore attribuito nell'atto di conferimento .

2. Qualora il bene sia alienato con altri per un unico corrispettivo o sia ceduto senza previsione di un corrispettivo in denaro ovvero sia dato in permuta, il valore economico e' determinato d'ufficio dal soggetto che procede alla prelazione ai sensi del comma 1.

3. Ove l'alienante non ritenga di accettare la determinazione effettuata ai sensi del comma 2, il valore economico della cosa e' stabilito da un terzo, designato concordemente dall'alienante e dal soggetto che procede alla prelazione. Se le parti non si accordano per la nomina del terzo, ovvero per la sua sostituzione qualora il terzo nominato non voglia o non possa accettare l'incarico, la nomina e' effettuata, su richiesta di una delle parti, dal presidente del tribunale del luogo in cui e' stato concluso il contratto. Le spese relative sono anticipate dall'alienante.

4. La determinazione del terzo e' impugnabile in caso di errore o di manifesta iniquita'.

5. La prelazione puo' essere esercitata anche quando il bene sia a qualunque titolo dato in pagamento.

#### Articolo 61 - Condizioni della prelazione

1. La prelazione e' esercitata nel termine di sessanta giorni dalla data di ricezione della denuncia prevista dall'articolo 59.

2. Nel caso in cui la denuncia sia stata omessa o presentata tardivamente oppure risulti incompleta, la prelazione e' esercitata nel termine di centottanta giorni dal momento in cui il Ministero ha ricevuto la denuncia tardiva o ha comunque acquisito tutti gli elementi costitutivi della stessa ai sensi dell'articolo 59, comma 4.

3. Entro i termini indicati dai commi 1 e 2 il provvedimento di prelazione e' notificato all'alienante ed all'acquirente. La proprieta' passa allo Stato dalla data dell'ultima notifica.

4. In pendenza del termine prescritto dal comma 1 l'atto di alienazione rimane condizionato sospensivamente all'esercizio della prelazione e all'alienante e' vietato effettuare la consegna della cosa.

5. Le clausole del contratto di alienazione non vincolano lo Stato.

6. Nel caso in cui il Ministero eserciti la prelazione su parte delle cose alienate, l'acquirente ha facolta' di recedere dal contratto.

#### Articolo 62 - Procedimento per la prelazione

1. Il soprintendente, ricevuta la denuncia di un atto soggetto a prelazione, ne da' immediata comunicazione alla regione e agli altri enti pubblici territoriali nel cui ambito si trova il bene. Trattandosi di bene mobile, la regione ne da' notizia sul proprio Bollettino Ufficiale ed eventualmente mediante altri idonei mezzi di pubblicita' a livello nazionale, con la descrizione dell'opera e l'indicazione del prezzo.

2. La regione e gli altri enti pubblici territoriali, nel termine di venti giorni dalla denuncia, formulano al Ministero una proposta di prelazione, corredata dalla deliberazione dell'organo competente che predisponga, a valere sul bilancio dell'ente, la necessaria copertura finanziaria della spesa indicando le specifiche finalita' di valorizzazione culturale del bene. (4) (4a)

3. Il Ministero puo' rinunciare all'esercizio della prelazione, trasferendone la facolta' all'ente interessato entro venti giorni dalla ricezione della denuncia. Detto ente assume il relativo impegno di spesa, adotta il provvedimento di prelazione e lo notifica all'alienante ed all'acquirente entro e non oltre sessanta giorni dalla denuncia medesima. La proprieta' del bene passa all'ente che ha esercitato la prelazione dalla data dell'ultima notifica.

((4. Nei casi in cui la denuncia sia stata omessa o presentata tardivamente oppure risulti incompleta, il termine indicato al comma 2 e' di novanta giorni ed i termini stabiliti al comma 3, primo e secondo periodo, sono, rispettivamente, di centoventi e centottanta giorni. Essi decorrono dal momento in cui il Ministero ha ricevuto la denuncia tardiva o ha comunque acquisito tutti gli elementi costitutivi della stessa ai sensi dell'articolo 59, comma 4.))

--------------- AGGIORNAMENTO (4) Il D.Lgs. 24 marzo 2006, n. 156 ha disposto (con l'art. 2, comma 1, lettera bb), numero 1)) che all'articolo 62, al comma 2, la parola: "motivata" e' soppressa. --------------- AGGIORNAMENTO (4a) Il D.Lgs. 24 marzo 2006, n. 156, come modificato dall'avviso di rettifica in G.U. 24/5/2006, n. 119, non dispone piu' (con l'art. 2, comma 1, lettera bb), numero 1)) che all'articolo 62, al comma 2, la parola: "motivata" e' soppressa.

### Sezione III - Commercio

#### Articolo 63 - Obbligo di denuncia dell'attivita' commerciale e di tenuta del registro. Obbligo di denuncia della vendita o dell'acquisto di documenti

1. L'autorita' locale di pubblica sicurezza, abilitata, ai sensi della normativa in materia, a ricevere la dichiarazione preventiva di esercizio del commercio di cose antiche o usate, trasmette al soprintendente e alla regione copia della dichiarazione medesima, presentata da chi esercita il commercio di cose rientranti nelle categorie di cui alla lettera A dell'Allegato A del presente decreto legislativo, di seguito indicato come "Allegato A".

2. Coloro che esercitano il commercio delle cose indicate al comma 1 annotano giornalmente le operazioni eseguite nel registro prescritto dalla normativa in materia di pubblica sicurezza, descrivendo le caratteristiche delle cose medesime. ((Il registro e' tenuto in formato elettronico con caratteristiche tecniche tali da consentire la consultazione in tempo reale al soprintendente ed e' diviso in due elenchi: un primo elenco relativo alle cose per le quali occorre la presentazione all'ufficio di esportazione; un secondo elenco relativo alle cose per le quali l'attestato e' rilasciato in modalita' informatica senza necessita' di presentazione della cosa all'ufficio di esportazione, salva la facolta' del soprintendente di richiedere in ogni momento che taluna delle cose indicate nel secondo elenco gli sia presentata per un esame diretto)). Con decreto adottato dal Ministro di concerto con il Ministro dell'interno sono definiti i limiti di valore al di sopra dei quali e' obbligatoria una dettagliata descrizione delle cose oggetto delle operazioni commerciali.

3. Il soprintendente verifica l'adempimento dell'obbligo di cui al secondo periodo del comma 2 con ispezioni periodiche, effettuate anche a mezzo dei carabinieri preposti alla tutela del patrimonio culturale, da lui delegati. La verifica e' svolta da funzionari della regione nei casi di esercizio della tutela ai sensi dell'articolo 5, commi 3 e 4. Il verbale dell'ispezione e' notificato all'interessato ed alla locale autorita' di pubblica sicurezza.

4. Coloro che esercitano il commercio di documenti, i titolari delle case di vendita, nonche' i pubblici ufficiali preposti alle vendite mobiliari hanno l'obbligo di comunicare al soprintendente l'elenco dei documenti di interesse storico posti in vendita. Allo stesso obbligo sono soggetti i privati proprietari, possessori o detentori a qualsiasi titolo di archivi che acquisiscano documenti aventi il medesimo interesse, entro novanta giorni dall'acquisizione. Entro novanta giorni dalle comunicazioni di cui al presente comma dalla comunicazione il soprintendente puo' avviare il procedimento di cui all'articolo 13.

5. Il soprintendente puo' comunque accertare d'ufficio l'esistenza di archivi o di singoli documenti dei quali siano proprietari, possessori o detentori, a qualsiasi titolo, i privati e di cui sia presumibile l'interesse storico particolarmente importante.

#### Articolo 64 - Attestati di autenticita' e di provenienza

1. Chiunque esercita l'attivita' di vendita al pubblico, di esposizione a fini di commercio o di intermediazione finalizzata alla vendita di opere di pittura, di scultura, di grafica ovvero di oggetti d' antichita' o di interesse storico od archeologico, o comunque abitualmente vende le opere o gli oggetti medesimi, ha l'obbligo di consegnare all'acquirente la documentazione (( che ne attesti)) l'autenticita' o almeno la probabile attribuzione e la provenienza ((delle opere medesime)); ovvero, in mancanza, di rilasciare, con le modalita' previste dalle disposizioni legislative e regolamentari in materia di documentazione amministrativa, una dichiarazione recante tutte le informazioni disponibili sull'autenticita' o la probabile attribuzione e la provenienza. Tale dichiarazione, ove possibile in relazione alla natura dell'opera o dell'oggetto, e' apposta su copia fotografica degli stessi.

## Capo V - Circolazione in ambito internazionale

### Sezione I - ((Principi in materia di circolazione internazionale))

#### Articolo 64-bis - (( (Controllo sulla circolazione) ))

((

1. Il controllo sulla circolazione internazionale e' finalizzato a preservare l'integrita' del patrimonio culturale in tutte le sue componenti, quali individuate in base al presente codice ed alle norme previgenti.

2. Il controllo di cui al comma 1 e' esercitato ai sensi delle disposizioni del presente capo, nel rispetto degli indirizzi e dei vincoli fissati in ambito comunitario, nonche' degli impegni assunti mediante la stipula e la ratifica di Convenzioni internazionali. Detto controllo costituisce funzione di preminente interesse nazionale.

3. Con riferimento al regime della circolazione internazionale, i beni costituenti il patrimonio culturale non sono assimilabili a merci.

))

### ((Sezione Ibis Uscita dal territorio nazionale e ingresso nel territorio nazionale))

#### Articolo 65 - Uscita definitiva

1. E' vietata l'uscita definitiva dal territorio della Repubblica dei beni culturali mobili indicati nell'articolo 10, commi 1, 2 e 3.

2. E' vietata altresi' l'uscita:

- a) delle cose mobili appartenenti ai soggetti indicati all'articolo 10, comma 1, che siano opera di autore non piu' vivente e la cui esecuzione risalga ad oltre ((settanta)) anni, fino a quando non sia stata effettuata la verifica prevista dall'articolo 12.
- b) dei beni, a chiunque appartenenti, che rientrino nelle categorie indicate all'articolo 10, comma 3, e che il Ministero, sentito il competente organo consultivo, abbia preventivamente individuato e, per periodi temporali definiti, abbia escluso dall'uscita, perche' dannosa per il patrimonio culturale in relazione alle caratteristiche oggettive, alla provenienza o all'appartenenza dei beni medesimi.

3. Fuori dei casi previsti dai commi 1 e 2, e' soggetta ad autorizzazione, secondo le modalita' stabilite nella presente sezione e nella sezione II di questo Capo, l'uscita definitiva dal territorio della Repubblica:

- a) delle cose, a chiunque appartenenti, che presentino interesse culturale, siano opera di autore non piu' vivente e la cui esecuzione risalga ad oltre ((settanta)) anni ((, il cui valore, fatta eccezione per le cose di cui all'allegato A, lettera B, numero 1, sia superiore ad euro 13.500));
- b) degli archivi e dei singoli documenti, appartenenti a privati, che presentino interesse culturale;
- c) delle cose rientranti nelle categorie di cui all'articolo 11, comma 1, lettere f), g) ed h), a chiunque appartengano.

((

4. Non e' soggetta ad autorizzazione l'uscita:

- a) delle cose di cui all'articolo 11, comma 1, lettera d);
- b) delle cose che presentino interesse culturale, siano opera di autore non piu' vivente e la cui esecuzione risalga ad oltre settanta anni, il cui valore sia inferiore ad euro 13.500, fatta eccezione per le cose di cui all'allegato A, lettera B, numero 1.

4-bis. Nei casi di cui al comma 4, l'interessato ha l'onere di comprovare al competente ufficio di esportazione, mediante dichiarazione ai sensi del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, che le cose da trasferire all'estero rientrino nelle ipotesi per le quali non e' prevista l'autorizzazione, secondo le procedure e con le modalita' stabilite con decreto ministeriale. Il competente ufficio di esportazione, qualora reputi che le cose possano rientrare tra quelle di cui all'articolo 10, comma 3, lettera d-bis), avvia il procedimento di cui all'articolo 14, che si conclude entro sessanta giorni dalla data di presentazione della dichiarazione))

#### Articolo 66 - Uscita temporanea per manifestazioni

1. Puo' essere autorizzata l'uscita temporanea dal territorio della Repubblica delle cose e dei beni culturali indicati nell'articolo 65, commi 1, 2, lettera a), e 3, per manifestazioni, mostre o esposizioni d' arte di alto interesse culturale, sempre che ne siano garantite l'integrita' e la sicurezza.

2. Non possono comunque uscire:

- a) i beni suscettibili di subire danni nel trasporto o nella permanenza in condizioni ambientali sfavorevoli;
- b) i beni che costituiscono il fondo principale di una determinata ed organica sezione di un museo, pinacoteca, galleria, archivio o biblioteca o di una collezione artistica o bibliografica. ((7)) AGGIORNAMENTO (7) --------------- Il D.Lgs. 26 marzo 2008, n. 62 ha disposto (con l'art. 2, comma 1, lettera ss)) l'introduzione della Sezione i-bis - Uscita dal territorio nazionale e ingresso nel territorio nazionale, comprendente gli articoli da 65 a 72.

#### Articolo 67 - Altri casi di uscita temporanea

1. Le cose e i beni culturali indicati nell'articolo 65, commi 1, 2, lettera a), e 3 possono essere autorizzati ad uscire temporaneamente anche quando:

- a) costituiscano mobilio privato dei cittadini italiani che ricoprono, presso sedi diplomatiche o consolari, istituzioni comunitarie o organizzazioni internazionali, cariche che comportano il trasferimento all'estero degli interessati, per un periodo non superiore alla durata del loro mandato;
- b) costituiscano l'arredamento delle sedi diplomatiche e consolari all'estero; e) debbano essere sottoposti ad analisi, indagini o interventi di conservazione da eseguire necessariamente all'estero; d) la loro uscita sia richiesta in attuazione di accordi culturali con istituzioni museali straniere, in regime di reciprocita' e per la durata stabilita negli accordi medesimi, che non puo' essere ((...)) superiore a quattro anni ((, rinnovabili una sola volta)).

2. Non e' soggetta ad autorizzazione l'uscita temporanea dal territorio della Repubblica dei mezzi di trasporto aventi piu' di settantacinque anni per la partecipazione a mostre e raduni internazionali, salvo che sia per essi intervenuta la dichiarazione ai sensi dell'articolo 13. (7) AGGIORNAMENTO (7) --------------- Il D.Lgs. 26 marzo 2008, n. 62 ha disposto (con l'art. 2, comma 1, lettera ss)) l'introduzione della Sezione i-bis - Uscita dal territorio nazionale e ingresso nel territorio nazionale, comprendente gli articoli da 65 a 72.

#### Articolo 68 - Attestato di libera circolazione

1. Chi intende far uscire in via definitiva dal territorio della Repubblica le cose indicate nell'articolo 65, comma 3, deve farne denuncia e presentarle al competente ufficio di esportazione, indicando, contestualmente e per ciascuna di esse, il valore venale, al fine di ottenere l'attestato di libera circolazione.

2. L'ufficio di esportazione, entro tre giorni dall'avvenuta presentazione della cosa, ne da' notizia ai competenti uffici del Ministero, che segnalano ad esso, entro i successivi dieci giorni, ogni elemento conoscitivo utile in ordine agli oggetti presentati per l'uscita definitiva.

3. L'ufficio di esportazione, accertata la congruita' del valore indicato, rilascia o nega con motivato giudizio, anche sulla base delle segnalazioni ricevute, l'attestato di libera circolazione, dandone comunicazione all'interessato entro quaranta giorni dalla presentazione della cosa.

4. Nella valutazione circa il rilascio o il rifiuto dell'attestato di libera circolazione gli uffici di esportazione accertano se le cose presentate, in relazione alla loro natura o al contesto storico-culturale di cui fanno parte, presentano interesse artistico, storico, archeologico, etnoantropologico, bibliografico, documentale o archivistico, a termini dell'articolo 10. Nel compiere tale valutazione gli uffici di esportazione si attengono a indirizzi di carattere generale stabiliti ((con decreto del Ministro)), sentito il competente organo consultivo.

5. L'attestato di libera circolazione ha validita' ((quinquennale)) ed e' redatto in tre originali, uno dei quali e' depositato agli atti d'ufficio; un secondo e' consegnato all'interessato e deve accompagnare la circolazione dell'oggetto; un terzo e' trasmesso al Ministero per la formazione del registro ufficiale degli attestati.

6. Il diniego comporta l'avvio del procedimento di dichiarazione, ai sensi dell'articolo 14. A tal fine, contestualmente al diniego, sono comunicati all'interessato gli elementi di cui all'articolo 14, comma 2, e le cose sono sottoposte alla disposizione di cui al comma 4 del medesimo articolo.

7. Per le cose di proprieta' di enti sottoposti alla vigilanza regionale, l'ufficio di esportazione acquisisce il parere della regione, che e' reso nel termine perentorio di trenta giorni dalla data di ricezione della richiesta e, se negativo, e' vincolante.

#### Articolo 69 - Ricorso amministrativo avverso il diniego di attestato

1. Avverso il diniego dell'attestato e' ammesso, entro i successivi trenta giorni, ricorso al Ministero, per motivi di legittimita' e di merito.

2. Il Ministero, sentito il competente organo consultivo, decide sul ricorso entro il termine di novanta giorni dalla presentazione dello stesso.

3. Dalla data di presentazione del ricorso amministrativo e fino alla scadenza del termine di cui al comma 2, il procedimento di dichiarazione e' sospeso, ma (( le cose rimangono assoggettate ))alla disposizione di cui all'articolo 14, comma 4.

4. Qualora il Ministero accolga il ricorso, rimette gli atti all'ufficio di esportazione, che provvede in conformita' nei successivi venti giorni.

5. Si applicano le disposizioni del decreto del Presidente della Repubblica 24 novembre 1971, n. 1199.

#### Articolo 70 - Acquisto coattivo

1. Entro il termine indicato all'articolo 68, comma 3, l'ufficio di esportazione (( , qualora non abbia gia' provveduto al rilascio o al diniego dell'attestato di libera circolazione,)) puo' proporre al Ministero l'acquisto coattivo (( della cosa per la quale )) e' richiesto l'attestato di libera circolazione, dandone contestuale comunicazione alla regione e all'interessato, al quale dichiara altresi' che l'oggetto gravato dalla proposta di acquisto resta in custodia presso l'ufficio medesimo fino alla conclusione del relativo procedimento. In tal caso il termine per il rilascio dell'attestato e' prorogato di sessanta giorni.

2. Il Ministero ha la facolta' di acquistare la cosa (( . . . )) per il valore indicato nella denuncia. Il provvedimento di acquisto e' notificato all'interessato entro il termine perentorio di novanta giorni dalla denuncia. Fino a quando non sia intervenuta la notifica del provvedimento di acquisto, l'interessato puo' rinunciare all'uscita dell'oggetto e provvedere al ritiro del medesimo.

3. Qualora il Ministero non intenda procedere all'acquisto, ne da' comunicazione, entro sessanta giorni dalla denuncia, alla regione nel cui territorio si trova l'ufficio di esportazione proponente. La regione ha facolta' di acquistare la cosa ((. . . )) nel rispetto di quanto stabilito all'articolo 62, commi 2 e 3. Il relativo provvedimento e' notificato all'interessato entro il termine perentorio di novanta giorni dalla denuncia.

#### Articolo 71 - Attestato di circolazione temporanea

1. Chi intende far uscire in via temporanea dal territorio della Repubblica, ai sensi degli articoli 66 e 67, le cose e i beni ivi indicati, deve farne denuncia e presentarli al competente ufficio di esportazione, indicando, contestualmente e per ciascuno di essi, il valore venale e il responsabile della sua custodia all'estero, al fine di ottenere l'attestato di circolazione temporanea.

2. L'ufficio di esportazione, accertata la congruita' del valore indicato, rilascia o nega, con motivato giudizio, l'attestato di circolazione temporanea, dettando le prescrizioni necessarie e dandone comunicazione all'interessato entro quaranta giorni dalla presentazione della cosa o del bene. Avverso il provvedimento di diniego di uscita temporanea e' ammesso ricorso amministrativo nei modi previsti dall'articolo 69.

3. (( Qualora per l'uscita temporanea siano presentate cose che rivestano l'interesse indicato dall'articolo 10, )) contestualmente alla pronuncia positiva o negativa sono comunicati all'interessato, ai fini dell'avvio del procedimento di dichiarazione, gli elementi indicati all'articolo 14, comma 2, e l'oggetto e' sottoposto alle misure di cui all'articolo 14, comma 4.

4. Nella valutazione circa il rilascio o il rifiuto dell'attestato, gli uffici di esportazione si attengono ad indirizzi di carattere generale stabiliti dal Ministero, sentito il competente organo consultivo. Per i casi di uscita temporanea disciplinati dall'articolo 66 e dall'articolo 67, comma 1, lettere b) e c), il rilascio dell'attestato e' subordinato all'autorizzazione di cui all'articolo 48.

5. L'attestato indica anche il termine per il rientro delle cose o dei beni, che e' prorogabile su richiesta dell'interessato, ma non puo' essere comunque superiore a diciotto mesi dalla loro uscita dal territorio nazionale, salvo quanto disposto dal comma 8.

6. Il rilascio dell'attestato e' sempre subordinato all'assicurazione dei beni da parte dell'interessato per il valore indicato nella domanda. Per le mostre e le manifestazioni promosse all'estero dal Ministero o, con la partecipazione statale, da enti pubblici, dagli istituti italiani di cultura all'estero o da organismi sovranazionali, l'assicurazione puo' essere sostituita dall'assunzione dei relativi rischi da parte dello Stato, ai sensi dell'articolo 48, comma 5.

7. Per i beni culturali di cui all'articolo 65, comma 1, nonche' per le cose o i beni di cui al comma 3, l'uscita temporanea e' garantita mediante cauzione, costituita anche da polizza fidejussoria, emessa da un istituto bancario o da una societa' di assicurazione, per un importo superiore del dieci per cento al valore del bene o della cosa, come accertato in sede di rilascio dell'attestato. La cauzione e' incamerata dall'amministrazione ove gli oggetti ammessi alla temporanea esportazione non rientrino nel territorio nazionale nel termine stabilito. La cauzione non e' richiesta per i beni appartenenti allo Stato e alle amministrazioni pubbliche. Il Ministero puo' esonerare dall'obbligo della cauzione istituzioni di particolare importanza culturale.

8. Le disposizioni dei commi da 5 a 7 non si applicano ai casi di uscita temporanea previsti dall'articolo 67, comma 1.

#### Articolo 72 - Ingresso nel territorio nazionale

1. La spedizione in Italia da uno Stato membro dell'Unione europea o l'importazione da un Paese terzo delle cose o dei beni indicati nell'articolo 65, comma 3, sono certificati, a domanda, dall'ufficio di esportazione.

2. I certificati di avvenuta spedizione e di avvenuta importazione sono rilasciati sulla base di documentazione idonea ad identificare la cosa o il bene e a comprovarne la provenienza dal territorio dello Stato membro o del Paese terzo dai quali la cosa o il bene medesimi sono stati, rispettivamente, spediti o importati.(( Ai fini del rilascio dei detti certificati non e' ammessa la produzione, da parte degli interessati, di atti di notorieta' o di dichiarazioni sostitutive dei medesimi, rese ai sensi delle vigenti disposizioni legislative e regolamentari in materia di documentazione amministrativa. ))

3. I certificati di avvenuta spedizione e di avvenuta importazione hanno validita' quinquennale e possono essere prorogati su richiesta dell'interessato.

4. Con decreto ministeriale possono essere stabilite condizioni, modalita' e procedure per il rilascio e la proroga dei certificati, con particolare riguardo all'accertamento della provenienza della cosa o del bene spediti o importati.

### Sezione II - Esportazione dal territorio dell'Unione europea

#### Articolo 73 - Denominazioni

1. Nella presente sezione e nella sezione III di questo Capo si intendono: ((a) per «regolamento CE» il regolamento (CE) n. 116/2009 del 18 dicembre 2008 del Consiglio relativo all'esportazione di beni culturali;)) ((b) per «direttiva UE» la direttiva n. 2014/60/UE del 15 maggio 2014 del Parlamento europeo e del Consiglio relativa alla restituzione dei beni culturali usciti illecitamente dal territorio di uno Stato membro e che modifica il regolamento (UE) n. 1024/2012;)) e) per "Stato richiedente", lo Stato membro dell'Unione europea che promuove l'azione di restituzione a norma della sezione III.

#### Articolo 74 - Esportazione di beni culturali dal territorio dell'Unione europea

1. L'esportazione al di fuori del territorio dell'Unione europea degli oggetti indicati nell'allegato A e' disciplinata dal regolamento CE e dal presente articolo.

2. Ai fini di cui all'articolo 3 del regolamento CE, gli uffici di esportazione del Ministero sono autorita' competenti per il rilascio delle licenze di esportazione. Il Ministero redige l'elenco di detti uffici e lo comunica alla Commissione europea; segnala, altresi', ogni eventuale modifica dello stesso entro due mesi dalla relativa effettuazione.

3. La licenza di esportazione prevista dall'articolo 2 del regolamento CE e' rilasciata dall'ufficio di esportazione contestualmente all'attestato di libera circolazione, ed e' valida per ((un anno)). La detta licenza puo' essere rilasciata, dallo stesso ufficio che ha emesso l'attestato, anche non contestualmente all'attestato medesimo, ma non oltre ((quarantotto)) mesi dal rilascio di quest'ultimo.

4. Per gli oggetti indicati nell'allegato A, l'ufficio di esportazione puo' rilasciare, a richiesta, anche licenza di esportazione temporanea, alle condizioni e secondo le modalita' stabilite dagli articoli 66, 67 e 71.

5. Le disposizioni della sezione 1-bis del presente capo non si applicano agli oggetti entrati nel territorio dello Stato con licenza di esportazione rilasciata da altro Stato membro dell'Unione europea a norma dell'articolo 2 del regolamento CE, per la durata di validita' della licenza medesima.

### Sezione III - ((Disciplina in materia di restituzione, nell'ambito dell'Unione europea, di beni culturali illecitamente usciti dal territorio di uno Stato membro))

#### Articolo 75 - Restituzione

1. Nell'ambito dell'Unione europea, la restituzione dei beni culturali usciti illecitamente dal territorio di uno Stato membro dopo il 31 dicembre 1992 e' regolata dalle disposizioni della presente sezione, che recepiscono la ((direttiva UE)).

((

2. Ai fini della direttiva UE, si intende per bene culturale un bene che e' stato classificato o definito da uno Stato membro, prima o dopo essere illecitamente uscito dal territorio di tale Stato membro, tra i beni del patrimonio culturale dello Stato medesimo, ai sensi dell'articolo 36 del Trattato sul funzionamento dell'Unione europea.

))

3. ((COMMA ABROGATO DAL D.LGS. 7 GENNAIO 2016, N. 2)).

4. E' illecita l'uscita dei beni avvenuta dal territorio di uno Stato membro in violazione della legislazione di detto Stato in materia di protezione del patrimonio culturale nazionale o del ((regolamento CE)), ovvero determinata dal mancato rientro dei beni medesimi alla scadenza del termine fissato nel provvedimento di autorizzazione alla spedizione temporanea.

5. Si considerano illecitamente usciti anche i beni dei quali sia stata autorizzata la spedizione temporanea qualora siano violate le prescrizioni stabilite con il provvedimento di autorizzazione.

6. La restituzione e' ammessa se le condizioni indicate nei commi 4 e 5 sussistono al momento della proposizione della domanda.

#### Articolo 76 - Assistenza e collaborazione a favore degli Stati membri dell'Unione europea

1. L'autorita' centrale prevista ((dall'articolo 4 della direttiva UE)) e', per l'Italia, il Ministero. Esso si avvale, per i vari compiti indicati nella direttiva, dei suoi organi centrali e periferici, nonche' della cooperazione degli altri Ministeri, degli altri organi dello Stato, delle regioni e degli altri enti pubblici territoriali.

2. Per il ritrovamento e la restituzione dei beni culturali appartenenti al patrimonio di altro Stato membro dell'Unione europea, il Ministero:

- a) assicura la propria collaborazione alle autorita' competenti degli altri Stati membri;
- b) fa eseguire sul territorio nazionale ricerche volte alla localizzazione del bene e alla identificazione di chi lo possieda o comunque lo detenga. Le ricerche sono disposte su domanda dello Stato richiedente, corredata da ogni notizia e documento utili per agevolare le indagini, con particolare riguardo alla localizzazione del bene;
- c) notifica agli Stati membri interessati il ritrovamento nel territorio nazionale di un bene la cui illecita uscita da uno Stato membro possa presumersi per indizi precisi e concordanti;
- d) agevola le operazioni che lo Stato membro interessato esegue per verificare, in ordine al bene oggetto della notifica di cui alla lettera c), la sussistenza dei presupposti e delle condizioni indicati all'articolo 75, purche' tali operazioni vengano effettuate ((entro sei mesi)) dalla notifica stessa. Qualora la verifica non sia eseguita entro il prescritto termine, non sono applicabili le disposizioni contenute nella lettera e);
- e) dispone, ove necessario, la rimozione del bene e la sua temporanea custodia presso istituti pubblici nonche' ogni altra misura necessaria per assicurarne la conservazione ed impedirne la sottrazione alla procedura di restituzione;
- f) favorisce l'amichevole composizione, tra Stato richiedente e possessore o detentore a qualsiasi titolo del bene, di ogni controversia concernente la restituzione. A tal fine, tenuto conto della qualita' dei soggetti e della natura del bene, il Ministero puo' proporre allo Stato richiedente e ai soggetti possessori o detentori la definizione della controversia mediante arbitrato, da svolgersi secondo la legislazione italiana, e raccogliere, per l'effetto, il formale accordo di entrambe le parti.

((

2-bis. L'autorita' centrale, al fine di cooperare e consultarsi con gli altri Stati membri e per diffondere tutte le pertinenti informazioni correlate a casi relative ai beni culturali rubati o usciti illecitamente dal territorio nazionale, utilizza un modulo del sistema d'informazione del mercato interno, di seguito «IMI», stabilito dal regolamento (UE) n. 1024/2012, specificamente adattato per i beni culturali.

))

#### Articolo 77 - Azione di restituzione

1. Per i beni culturali usciti illecitamente dal loro territorio, gli Stati membri dell'Unione europea possono esercitare l'azione di restituzione davanti all'autorita' giudiziaria ordinaria, secondo quanto previsto dall'articolo 75.

2. L'azione e' proposta davanti al tribunale del luogo in cui il bene si trova.

3. Oltre ai requisiti previsti nell'articolo 163 del codice di procedura civile, l'atto di citazione deve contenere:

- a) un documento descrittivo del bene richiesto che ne certifichi la qualita' di bene culturale;
- b) la dichiarazione delle autorita' competenti dello Stato richiedente relativa all'uscita illecita del bene dal territorio nazionale.

4. L'atto di citazione e' notificato, oltre che al possessore o al detentore a qualsiasi titolo del bene, anche al Ministero per essere annotato nello speciale registro di trascrizione delle domande giudiziali di restituzione.

5. Il Ministero notifica immediatamente l'avvenuta trascrizione alle autorita' centrali degli altri Stati membri ((, utilizzando un modulo del sistema IMI stabilito dal regolamento (UE) n. 1024/2012, specificamente adattato per i beni culturali)).

#### Articolo 78 - Termini di decadenza e di prescrizione dell'azione

1. L'azione di restituzione e' promossa nel termine perentorio ((di tre anni)) a decorrere dal giorno in cui ((l'Autorita' centrale)) richiedente ha avuto conoscenza che il bene uscito illecitamente si trova in un determinato luogo e ne ha identificato il possessore o detentore a qualsiasi titolo.

2. L'azione di restituzione si prescrive in ogni caso entro il termine di trenta anni dal giorno dell'uscita illecita del bene dal territorio dello Stato richiedente.

3. L'azione di restituzione non si prescrive per i beni ((appartenenti a collezioni pubbliche museali, archivi, fondi di conservazione di biblioteche e istituzioni ecclesiastiche o altre istituzioni religiose)).

#### Articolo 79 - Indennizzo

1. Il tribunale, nel disporre la restituzione del bene, puo', su domanda della parte interessata, liquidare un indennizzo determinato in base a criteri equitativi.

2. Per ottenere l'indennizzo previsto dal comma 1, il soggetto interessato e' tenuto a dimostrare di aver usato, all'atto dell'acquisizione, la diligenza necessaria a seconda delle circostanze. ((Per determinare l'esercizio della diligenza richiesta da parte del possessore si tiene conto di tutte le circostanze dell'acquisizione, in particolare della documentazione sulla provenienza del bene, delle autorizzazioni di uscita prescritte dal diritto dello Stato membro richiedente, della qualita' delle parti, del prezzo pagato, del fatto che il possessore abbia consultato o meno i registri accessibili dei beni culturali rubati e ogni informazione pertinente che avrebbe potuto ragionevolmente ottenere o di qualsiasi altra pratica cui una persona ragionevole avrebbe fatto ricorso in circostanze analoghe.))

3. Il soggetto che abbia acquisito il possesso del bene per donazione, eredita' o legato non puo' beneficiare di una posizione piu' favorevole di quella del proprio dante causa.

4. Lo Stato richiedente che sia obbligato al pagamento dell'indennizzo puo' rivalersi nei confronti del soggetto responsabile dell'illecita circolazione ((...)).

#### Articolo 80 - Pagamento dell'indennizzo

1. L'indennizzo e' corrisposto da parte dello Stato richiedente contestualmente alla restituzione del bene.

2. Del pagamento e della consegna del bene e' redatto processo verbale a cura di un notaio, di un ufficiale giudiziario o di funzionari all'uopo designati dal Ministero, al quale e' rimessa copia del processo verbale medesimo.

3. Il processo verbale costituisce titolo idoneo per la cancellazione della trascrizione della domanda giudiziale.

#### Articolo 81 - Oneri per l'assistenza e la collaborazione

1. Sono a carico dello Stato richiedente le spese relative alla ricerca, rimozione o custodia temporanea del bene da restituire, le altre comunque conseguenti all'applicazione dell'articolo 76, nonche' quelle inerenti all'esecuzione della sentenza che dispone la restituzione.

#### Articolo 82 - Azione di restituzione a favore dell'Italia

1. L'azione di restituzione dei beni culturali usciti illecitamente dal territorio italiano e' esercitata dal Ministero, d'intesa con il Ministero degli affari esteri, davanti al giudice dello Stato membro dell'Unione europea in cui si trova il bene culturale.

2. Il Ministero si avvale dell'assistenza dell'Avvocatura generale dello Stato.

#### Articolo 83 - Destinazione del bene restituito

1. Qualora il bene culturale restituito non appartenga allo Stato, il Ministero provvede alla sua custodia fino alla consegna all'avente diritto.

2. La consegna del bene e' subordinata al rimborso allo Stato delle spese sostenute per il procedimento di restituzione e per la custodia del bene.

3. Quando non sia conosciuto chi abbia diritto alla consegna del bene, il Ministero da' notizia del provvedimento di restituzione mediante avviso pubblicato nella Gazzetta Ufficiale della Repubblica italiana e con altra forma di pubblicita'.

4. Qualora l'avente diritto non ne richieda la consegna entro cinque anni dalla data di pubblicazione nella Gazzetta Ufficiale dell'avviso previsto dal comma 3, il bene e' acquisito al demanio dello Stato. Il Ministero, sentiti il competente organo consultivo e le regioni interessate, dispone che il bene sia assegnato ad un museo, biblioteca o archivio dello Stato, di una regione o di altro ente pubblico territoriale, al fine di assicurarne la migliore tutela e la pubblica fruizione nel contesto culturale piu' opportuno.

#### Articolo 84 - Informazioni alla Commissione europea e al Parlamento nazionale

1. Il Ministro informa la Commissione europea delle misure adottate dall'Italia per assicurare l'esecuzione del regolamento CE e acquisisce le corrispondenti informazioni trasmesse alla Commissione dagli altri Stati membri.

2. Il Ministro trasmette annualmente al Parlamento ((, entro il termine di presentazione del disegno di legge di bilancio,)) una relazione sull'attuazione del presente Capo nonche' sull'attuazione della direttiva UE e del regolamento CE in Italia e negli altri Stati membri.

3. Il Ministro, sentito il competente organo consultivo, predispone ogni tre anni la relazione sull'applicazione del regolamento CE e ogni cinque anni la relazione sull'applicazione della direttiva UE per la Commissione indicata al comma 1. Le relazioni sono trasmesse al Parlamento. (27)

--------------- AGGIORNAMENTO (27) Il D.Lgs. 7 gennaio 2016, n. 2 ha disposto (con l'art. 1, comma 11) che "La relazione sull'applicazione della direttiva UE, di cuiall'articolo 84, comma 3, del decreto legislativo 22 gennaio 2004, n. 42, come sostituito dal comma 8, lettera c), del presente articolo, e' presentata, per la prima volta, entro il 18 dicembre 2020".

#### Articolo 85 - Banca dati dei beni culturali illecitamente sottratti

1. Presso il Ministero e' istituita la banca dati dei beni culturali illecitamente sottratti, secondo modalita' stabilite con decreto ministeriale.

#### Articolo 86 - Accordi con gli altri Stati membri dell'Unione europea

1. Al fine di sollecitare e favorire una reciproca, maggiore conoscenza del patrimonio culturale nonche' della legislazione e dell'organizzazione di tutela dei diversi Stati membri dell'Unione europea, il Ministero promuove gli opportuni accordi con le corrispondenti autorita' degli altri Stati membri.

### Sezione IV - ((Disciplina in materia di interdizione della illecita circolazione internazionale dei beni culturali))

#### Articolo 87 - (( (Convenzione UNIDROIT) ))

((

1. Resta ferma la disciplina dettata dalla Convenzione dell'UNIDROIT sul ritorno internazionale dei beni culturali rubati o illecitamente esportati, adottata a Roma il 24 giugno 1995, e dalle relative norme di ratifica ed esecuzione, con riferimento ai beni indicati nell'annesso alla Convenzione medesima.

))

#### Articolo 87-bis - (( (Convenzione UNESCO) ))

((

1. Resta ferma la disciplina dettata dalla Convenzione UNESCO sulla illecita importazione, esportazione e trasferimento dei beni culturali, adottata a Parigi il 14 novembre 1970, e dalle relative norme di ratifica ed esecuzione, con riferimento ai beni indicati nella Convenzione medesima.

))

## Capo VI - Ritrovamenti e scoperte

### Sezione I - Ricerche e rinvenimenti fortuiti nell'ambito del territorio nazionale

#### Articolo 88 - Attivita' di ricerca

1. Le ricerche archeologiche e, in genere, le opere per il ritrovamento delle cose indicate all'articolo 10 in qualunque parte del territorio nazionale sono riservate al Ministero.

2. Il Ministero puo' ordinare l'occupazione temporanea degli immobili ove devono eseguirsi le ricerche o le opere di cui al comma 1.

3. Il proprietario dell'immobile ha diritto ad un'indennita' per l'occupazione, determinata secondo le modalita' stabilite dalle disposizioni generali in materia di espropriazione per pubblica utilita'. L'indennita' puo' essere corrisposta in denaro o, a richiesta del proprietario, mediante rilascio delle cose ritrovate o di parte di esse, quando non interessino le raccolte dello Stato.

#### Articolo 89 - Concessione di ricerca

1. Il Ministero puo' dare in concessione a soggetti pubblici o privati l'esecuzione delle ricerche e delle opere indicate nell'articolo 88 ed emettere a favore del concessionario il decreto di occupazione degli immobili ove devono eseguirsi i lavori.

2. Il concessionario deve osservare, oltre alle prescrizioni imposte nell'atto di concessione, tutte le altre che il Ministero ritenga di impartire. In caso di inosservanza la concessione e' revocata.

3. La concessione puo' essere revocata anche quando il Ministero intenda sostituirsi nell'esecuzione o prosecuzione delle opere. In tal caso sono rimborsate al concessionario le spese occorse per le opere gia' eseguite ed il relativo importo e' fissato dal Ministero.

4. Ove il concessionario non ritenga di accettare la determinazione ministeriale, l'importo e' stabilito da un perito tecnico nominato dal presidente del tribunale. Le relative spese sono anticipate dal concessionario.

5. La concessione prevista al comma 1 puo' essere rilasciata anche al proprietario degli immobili ove devono eseguirsi i lavori.

6. Il Ministero puo' consentire, a richiesta, che le cose rinvenute rimangano, in tutto o in parte, presso la Regione od altro ente pubblico territoriale per fini espositivi, sempre che l'ente disponga di una sede idonea e possa garantire la conservazione e la custodia delle cose medesime.

#### Articolo 90 - Scoperte fortuite

1. Chi scopre fortuitamente cose immobili o mobili indicate nell'articolo 10 ne fa denuncia entro ventiquattro ore al soprintendente o al sindaco ovvero all'autorita' di pubblica sicurezza e provvede alla conservazione temporanea di esse, lasciandole nelle condizioni e nel luogo in cui sono state rinvenute. (( Della scoperta fortuita sono informati, a cura del soprintendente, anche i carabinieri preposti alla tutela del patrimonio culturale. ))

2. Ove si tratti di cose mobili delle quali non si possa altrimenti assicurare la custodia, lo scopritore ha facolta' di rimuoverle per meglio garantirne la sicurezza e la conservazione sino alla visita dell'autorita' competente e, ove occorra, di chiedere l'ausilio della forza pubblica.

3. Agli obblighi di conservazione e custodia previsti nei commi 1 e 2 e' soggetto ogni detentore di cose scoperte fortuitamente.

4. Le spese sostenute per la custodia e rimozione sono rimborsate dal Ministero.

#### Articolo 91 - Appartenenza e qualificazione delle cose ritrovate

1. Le cose indicate nell'articolo 10, da chiunque e in qualunque modo ritrovate nel sottosuolo o sui fondali marini, appartengono allo Stato e, a seconda che siano immobili o mobili, fanno parte del demanio o del patrimonio indisponibile, ai sensi degli articoli 822 e 826 del codice civile.

2. Qualora si proceda per conto dello Stato, delle regioni, degli altri enti pubblici territoriali o di altro ente o istituto pubblico alla demolizione di un immobile, tra i materiali di risulta che per contratto siano stati riservati all'impresa di demolizione non sono comprese le cose rinvenienti dall'abbattimento che abbiano l'interesse di cui all'articolo 10, comma 3, lettera a). E' nullo ogni patto contrario.

#### Articolo 92 - Premio per i ritrovamenti

1. Il Ministero corrisponde un premio non superiore al quarto del valore delle cose ritrovate:

- a) al proprietario dell'immobile dove e' avvenuto il ritrovamento;
- b) al concessionario dell'attivita' di ricerca, (( di cui all'articolo 89, qualora l'attivita' medesima non rientri tra i suoi scopi istituzionali o statutari;))
- c) allo scopritore fortuito che ha ottemperato agli obblighi previsti dall'articolo 90.

2. Il proprietario dell'immobile che abbia ottenuto la concessione prevista dall'articolo 89 ovvero sia scopritore della cosa, ha diritto ad un premio non superiore alla meta' del valore delle cose ritrovate.

3. Nessun premio spetta allo scopritore che si sia introdotto e abbia ricercato nel fondo altrui senza il consenso del proprietario o del possessore.

4. Il premio puo' essere corrisposto in denaro o mediante rilascio di parte delle cose ritrovate. In luogo del premio, l'interessato puo' ottenere, a richiesta, un credito di imposta di pari ammontare, secondo le modalita' e con i limiti stabiliti con decreto adottato dal Ministro dell'economia e delle finanze di concerto con il Ministro, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400.

#### Articolo 93 - Determinazione del premio

1. Il Ministero provvede alla determinazione del premio spettante agli aventi titolo ai sensi dell'articolo 92, previa stima delle cose ritrovate.

2. In corso di stima, a ciascuno degli aventi titolo e' corrisposto un acconto del premio in misura non superiore ad un quinto del valore, determinato in via provvisoria, delle cose ritrovate. L'accettazione dell'acconto non comporta acquiescenza alla stima definitiva.

3. Se gli aventi titolo non accettano la stima definitiva del Ministero, il valore delle cose ritrovate e' determinato da un terzo, designato concordemente dalle parti. Se esse non si accordano per la nomina del terzo ovvero per la sua sostituzione, qualora il terzo nominato non voglia o non possa accettare l'incarico, la nomina e' effettuata, su richiesta di una delle parti, dal presidente del tribunale del luogo in cui le cose sono state ritrovate. Le spese della perizia sono anticipate dagli aventi titolo al premio.

4. La determinazione del terzo e' impugnabile in caso di errore o di manifesta iniquita'.

### Sezione II - Ricerche e rinvenimenti fortuiti nella zona contigua al mare territoriale

#### Articolo 94 - (( Convenzione UNESCO sulla protezione del patrimonio culturale subacqueo ))

1. Gli oggetti archeologici e storici rinvenuti nei fondali della zona di mare estesa dodici miglia marine a partire dal limite esterno del mare territoriale sono tutelati ai sensi delle ((regole relative agli interventi sul patrimonio culturale subacqueo, )) allegate alla Convenzione UNESCO sulla protezione del patrimonio culturale subacqueo, adottata a Parigi il 2 novembre 2001.

## Capo VII - Espropriazione

### Articolo 95 - Espropriazione di beni culturali

1. I beni culturali immobili e mobili possono essere espropriati dal Ministero per causa di pubblica utilita', quando l'espropriazione risponda ad un importante interesse a migliorare le condizioni di tutela ai fini della fruizione pubblica dei beni medesimi.

2. Il Ministero puo' autorizzare, a richiesta, le regioni, gli altri enti pubblici territoriali nonche' ogni altro ente ed istituto pubblico ad effettuare l'espropriazione di cui al comma 1. In tal caso dichiara la pubblica utilita' ai fini dell'esproprio e rimette gli atti all'ente interessato per la prosecuzione del procedimento.

3. Il Ministero puo' anche disporre l'espropriazione a favore di persone giuridiche private senza fine di lucro, curando direttamente il relativo procedimento.

### Articolo 96 - Espropriazione per fini strumentali

1. Possono essere espropriati per causa di pubblica utilita' edifici ed aree quando cio' sia necessario per isolare o restaurare (( beni culturali immobili )), assicurarne la luce o la prospettiva, garantirne o accrescerne il decoro o il godimento da parte del pubblico, facilitarne l'accesso.

### Articolo 97 - Espropriazione per interesse archeologico

1. Il Ministero puo' procedere all'espropriazione di immobili al fine di eseguire interventi di interesse archeologico o ricerche per il ritrovamento delle cose indicate nell'articolo 10.

### Articolo 98 - Dichiarazione di pubblica utilita'

1. La pubblica utilita' e' dichiarata con decreto ministeriale o, nel caso dell'articolo 96, anche con provvedimento della regione comunicato al Ministero.

2. Nei casi di espropriazione previsti dagli articoli 96 e 97 l'approvazione del progetto equivale a dichiarazione di pubblica utilita'.

### Articolo 99 - Indennita' di esproprio per i beni culturali

1. Nel caso di espropriazione previsto dall'articolo 95 l'indennita' consiste nel giusto prezzo che il bene avrebbe in una libera contrattazione di compravendita all'interno dello Stato.

2. Il pagamento dell'indennita' e' effettuato secondo le modalita' stabilite dalle disposizioni generali in materia di espropriazione per pubblica utilita'.

### Articolo 100 - Rinvio a norme generali

1. Nei casi di espropriazione disciplinati dagli articoli 96 e 97 si applicano, in quanto compatibili, le disposizioni generali in materia di espropriazione per pubblica utilita'.

## TITOLO II Fruizione e valorizzazione Capo I Fruizione dei beni culturali

### Sezione I - Principi generali

#### Articolo 101 - Istituti e luoghi della cultura

1. Ai fini del presente codice sono istituti e luoghi della cultura i musei, le biblioteche e gli archivi, le aree e i parchi archeologici, i complessi monumentali.

2. Si intende per:

- a) "museo", una struttura permanente che acquisisce, (( cataloga, )) conserva, ordina ed espone beni culturali per finalita' di educazione e di studio;
- b) "biblioteca", una struttura permanente che raccoglie (( , cataloga )) e conserva un insieme organizzato di libri, materiali e informazioni, comunque editi o pubblicati su qualunque supporto, e ne assicura la consultazione al fine di promuovere la lettura e lo studio;
- c) "archivio", una struttura permanente che raccoglie, inventaria e conserva documenti originali di interesse storico e ne assicura la consultazione per finalita' di studio e di ricerca.
- d) "area archeologica", un sito caratterizzato dalla presenza di resti di natura fossile o di manufatti o strutture preistorici o di eta' antica;
- e) "parco archeologico", un ambito territoriale caratterizzato da importanti evidenze archeologiche e dalla compresenza di valori storici, paesaggistici o ambientali, attrezzato come museo all'aperto;
- f) "complesso monumentale", un insieme formato da una pluralita' di fabbricati edificati anche in epoche diverse, che con il tempo hanno acquisito, come insieme, una autonoma rilevanza artistica, storica o etnoantropologica.

3. Gli istituti ed i luoghi di cui al comma 1 che appartengono a soggetti pubblici sono destinati alla pubblica fruizione ed espletano un servizio pubblico.

4. Le strutture espositive e di consultazione nonche' i luoghi di cui al comma 1 che appartengono a soggetti privati e sono aperti al pubblico espletano un servizio privato di utilita' sociale.

#### Articolo 102 - Fruizione degli istituti e dei luoghi della cultura di appartenenza pubblica

1. Lo Stato, le regioni, gli altri enti pubblici territoriali ed ogni altro ente ed istituto pubblico, assicurano la fruizione dei beni presenti negli istituti e nei luoghi indicati all'articolo 101, nel rispetto dei principi fondamentali fissati dal presente codice.

2. Nel rispetto dei principi richiamati al comma 1, la legislazione regionale disciplina la fruizione dei beni presenti negli istituti e nei luoghi della cultura non appartenenti allo Stato o dei quali lo Stato abbia trasferito la disponibilita' sulla base della normativa vigente.

3. La fruizione dei beni culturali pubblici al di fuori degli istituti e dei luoghi di cui all'articolo 101 e' assicurata, secondo le disposizioni del presente Titolo, compatibilmente con lo svolgimento degli scopi istituzionali cui detti beni sono destinati.

4. Al fine di coordinare, armonizzare ed integrare la fruizione relativamente agli istituti ed ai luoghi della cultura di appartenenza pubblica lo Stato, e per esso il Ministero, le regioni e gli altri enti pubblici territoriali definiscono accordi nell'ambito e con le procedure dell'articolo 112. In assenza di accordo, ciascun soggetto pubblico e' tenuto a garantire la fruizione dei beni di cui ha comunque la disponibilita'.

5. Mediante gli accordi di cui al comma 4 il Ministero puo' altresi' trasferire alle regioni e agli altri enti pubblici territoriali, in base ai principi di sussidiarieta', differenziazione ed adeguatezza, la disponibilita' di istituti e luoghi della cultura, al fine di assicurare un'adeguata fruizione e valorizzazione dei beni ivi presenti.

#### Articolo 103 - Accesso agli istituti ed ai luoghi della cultura

1. L'accesso agli istituti ed ai luoghi pubblici della cultura puo' essere gratuito o a pagamento. Il Ministero, le regioni e gli altri enti pubblici territoriali possono stipulare intese per coordinare l'accesso ad essi.

2. L'accesso alle biblioteche ed agli archivi pubblici per finalita' di lettura, studio e ricerca e' gratuito.

3. Nei casi di accesso a pagamento, il Ministero, le regioni e gli altri enti pubblici territoriali determinano:

- a) i casi di libero accesso e di ingresso gratuito;
- b) le categorie di biglietti e i criteri per la determinazione del relativo prezzo. Il prezzo del biglietto include gli oneri derivanti dalla stipula delle convenzioni previste alla lettera c);
- c) le modalita' di emissione, distribuzione e vendita del biglietto d'ingresso e di riscossione del corrispettivo, anche mediante convenzioni con soggetti pubblici e privati. Per la gestione dei biglietti d'ingresso possono essere impiegate nuove tecnologie informatiche, con possibilita' di prevendita e vendita presso terzi convenzionati.
- d) l'eventuale percentuale dei proventi dei biglietti da assegnare all'Ente nazionale di assistenza e previdenza per i pittori, scultori, musicisti, scrittori ed autori drammatici.

4. Eventuali agevolazioni per l'accesso devono essere regolate in modo da non creare discriminazioni ingiustificate nei confronti dei cittadini degli altri Stati membri dell'Unione europea.

#### Articolo 104 - Fruizione di beni culturali di proprieta' privata

1. Possono essere assoggettati a visita da parte del pubblico per scopi culturali:

- a) i beni culturali immobili indicati all'articolo 10, comma 3, lettere a) e d), che rivestono interesse eccezionale;
- b) le collezioni dichiarate ai sensi dell'articolo 13.

2. L'interesse eccezionale degli immobili indicati al comma 1, lettera a), e' dichiarato con atto del Ministero, sentito il proprietario.

3. Le modalita' di visita sono concordate tra il proprietario e il soprintendente, che ne da' comunicazione (( al comune e alla citta' metropolitana )) nel cui territorio si trovano i beni.

4. Sono fatte salve le disposizioni di cui all'articolo 38.

#### Articolo 105 - Diritti di uso e godimento pubblico

1. Il Ministero e le regioni vigilano, nell'ambito delle rispettive competenze, affinche' siano rispettati i diritti di uso e godimento che il pubblico abbia acquisito sulle cose e i beni soggetti alle disposizioni della presente Parte.

### Sezione II - Uso dei beni culturali

#### Articolo 106 - Uso individuale di beni culturali

1. Lo Stato, le regioni e gli altri enti pubblici territoriali possono concedere l'uso dei beni culturali che abbiano in consegna, per finalita' compatibili con la loro destinazione culturale, a singoli richiedenti.

2. Per i beni in consegna al Ministero, il ((Ministero)) determina il canone dovuto e adotta il relativo provvedimento.

2-bis. Per i beni diversi da quelli indicati al comma 2, la concessione in uso e' subordinata all'autorizzazione del Ministero, rilasciata a condizione che il conferimento garantisca la conservazione e la fruizione pubblica del bene e sia assicurata la compatibilita' della destinazione d'uso con il carattere storico-artistico del bene medesimo. Con l'autorizzazione possono essere dettate prescrizioni per la migliore conservazione del bene.

#### Articolo 107 - Uso strumentale e precario e riproduzione di beni culturali

1. Il Ministero, le regioni e gli altri enti pubblici territoriali possono consentire la riproduzione nonche' l'uso strumentale e precario dei beni culturali che abbiano in consegna, fatte salve le disposizioni di cui al comma 2 e quelle in materia di diritto d' autore.

((

2. E' di regola vietata la riproduzione di beni culturali che consista nel trarre calchi, per contatto, dagli originali di sculture e di opere a rilievo in genere, di qualunque materiale tali beni siano fatti. Tale riproduzione e' consentita solo in via eccezionale e nel rispetto delle modalita' stabilite con apposito decreto ministeriale. Sono invece consentiti, previa autorizzazione del soprintendente, i calchi da copie degli originali gia' esistenti nonche' quelli ottenuti con tecniche che escludano il contatto diretto con l'originale.

))

#### Articolo 108 - Canoni di concessione, corrispettivi di riproduzione, cauzione

1. I canoni di concessione ed i corrispettivi connessi alle riproduzioni di beni culturali sono determinati dall'autorita' che ha in consegna i beni tenendo anche conto:

- a) del carattere delle attivita' cui si riferiscono le concessioni d'uso;
- b) dei mezzi e delle modalita' di esecuzione delle riproduzioni;
- c) del tipo e del tempo di utilizzazione degli spazi e dei beni;
- d) dell'uso e della destinazione delle riproduzioni, nonche' dei benefici economici che ne derivano al richiedente.

2. I canoni e i corrispettivi sono corrisposti, di regola, in via anticipata.

3. Nessun canone e' dovuto per le riproduzioni richieste ((o eseguite)) da privati per uso personale o per motivi di studio, ovvero da soggetti pubblici o privati per finalita' di valorizzazione, purche' attuate senza scopo di lucro. I richiedenti sono comunque tenuti al rimborso delle spese sostenute dall'amministrazione concedente.

3-bis. Sono in ogni caso libere le seguenti attivita', svolte senza scopo di lucro, per finalita' di studio, ricerca, libera manifestazione del pensiero o espressione creativa, promozione della conoscenza del patrimonio culturale: 1) la riproduzione di beni culturali diversi dai beni ((...)) archivistici ((sottoposti a restrizioni di consultabilita' ai sensi del capo III del presente titolo,)) attuata ((nel rispetto delle disposizioni che tutelano il diritto di autore e)) con modalita' che non comportino alcun contatto fisico con il bene, ne' l'esposizione dello stesso a sorgenti luminose, ne' , all'interno degli istituti della cultura, l'uso di stativi o treppiedi; 2) la divulgazione con qualsiasi mezzo delle immagini di beni culturali, legittimamente acquisite, in modo da non poter essere ulteriormente riprodotte a scopo di lucro ((...)).

4. Nei casi in cui dall'attivita' in concessione possa derivare un pregiudizio ai beni culturali, l'autorita' che ha in consegna i beni determina l'importo della cauzione, costituita anche mediante fideiussione bancaria o assicurativa. Per gli stessi motivi, la cauzione e' dovuta anche nei casi di esenzione dal pagamento dei canoni e corrispettivi.

5. La cauzione e' restituita quando sia stato accertato che i beni in concessione non hanno subito danni e le spese sostenute sono state rimborsate.

6. Gli importi minimi dei canoni e dei corrispettivi per l'uso e la riproduzione dei beni sono fissati con provvedimento dell'amministrazione concedente.

#### Articolo 109 - Catalogo di immagini fotografiche e di riprese di beni culturali

1. Qualora la concessione abbia ad oggetto la riproduzione di beni culturali per fini di raccolta e catalogo di immagini fotografiche e di riprese in genere, il provvedimento concessorio prescrive:

- a) il deposito del doppio originale di ogni ripresa o fotografia;
- b) la restituzione, dopo l'uso, del fotocolor originale con relativo codice.

#### Articolo 110 - Incasso e riparto di proventi

1. Nei casi previsti dall'articolo 115, comma 2, i proventi derivanti dalla vendita dei biglietti di ingresso agli istituti ed ai luoghi della cultura, nonche' dai canoni di concessione e dai corrispettivi per la riproduzione dei beni culturali, sono versati ai soggetti pubblici cui gli istituti, i luoghi o i singoli beni appartengono o sono in consegna, in conformita' alle rispettive disposizioni di contabilita' pubblica.

2. Ove si tratti di istituti, luoghi o beni appartenenti o in consegna allo Stato, i proventi di cui al comma 1 sono versati alla sezione di tesoreria provinciale dello Stato, anche mediante versamento in conto corrente postale intestato alla tesoreria medesima, ovvero sul conto corrente bancario aperto da ciascun responsabile di istituto o luogo della cultura presso un istituto di credito. In tale ultima ipotesi l'istituto bancario provvede, non oltre cinque giorni dalla riscossione, al versamento delle somme affluite alla sezione di tesoreria provinciale dello Stato. Il Ministro dell'economia e delle finanze riassegna le somme incassate alle competenti unita' previsionali di base dello stato di previsione della spesa del Ministero, secondo i criteri e nella misura fissati dal Ministero medesimo.

3. I proventi derivanti dalla vendita dei biglietti d'ingresso agli istituti ed ai luoghi appartenenti o in consegna allo Stato sono destinati alla realizzazione di interventi per la sicurezza e la conservazione ((, al funzionamento, alla fruizione e alla valorizzazione)) degli istituti e dei luoghi della cultura appartenenti o in consegna allo Stato, ai sensi dell'articolo 29, nonche' all'espropriazione e all'acquisto di beni culturali, anche mediante esercizio della prelazione.

4. I proventi derivanti dalla vendita dei biglietti d'ingresso agli istituti ed ai luoghi appartenenti o in consegna ad altri soggetti pubblici sono destinati all'incremento ed alla valorizzazione del patrimonio culturale. (21)

------------- AGGIORNAMENTO (21) Il D.L. 8 agosto 2013, n. 91, convertito con modificazioni dalla L. 7 ottobre 2013, n. 112, ha disposto (con l'art. 3, comma 1) che "I proventi di cui all'articolo 110 del predetto decreto legislativo n. 42 del 2004 sono riassegnati a decorrere dall'anno 2014, con decreto del Ministro dell'economia e delle finanze, allo stato di previsione della spesa dell'esercizio in corso del Ministero dei beni e delle attivita' culturali e del turismo".

## Capo II - Principi della valorizzazione dei beni culturali

### Articolo 111 - Attivita' di valorizzazione

1. Le attivita' di valorizzazione dei beni culturali consistono nella costituzione ed organizzazione stabile di risorse, strutture o reti, ovvero nella messa a disposizione di competenze tecniche o risorse finanziarie o strumentali, finalizzate all'esercizio delle funzioni ed al perseguimento delle finalita' indicate all'articolo 6. A tali attivita' possono concorrere, cooperare o partecipare soggetti privati.

2. La valorizzazione e' ad iniziativa pubblica o privata.

3. La valorizzazione ad iniziativa pubblica si conforma ai principi di liberta' di partecipazione, pluralita' dei soggetti, continuita' di esercizio, parita' di trattamento, economicita' e trasparenza della gestione.

4. La valorizzazione ad iniziativa privata e' attivita' socialmente utile e ne e' riconosciuta la finalita' di solidarieta' sociale.

### Articolo 112 - (Valorizzazione dei beni culturali di appartenenza pubblica)

1. Lo Stato, le regioni e gli altri enti pubblici territoriali assicurano la valorizzazione dei beni presenti negli istituti e nei luoghi indicati all'articolo 101, nel rispetto dei principi fondamentali fissati dal presente codice.

2. Nel rispetto dei principi richiamati al comma 1, la legislazione regionale disciplina le funzioni e le attivita' di valorizzazione dei beni presenti negli istituti e nei luoghi della cultura non appartenenti allo Stato o dei quali lo Stato abbia trasferito la disponibilita' sulla base della normativa vigente.

3. La valorizzazione dei beni culturali pubblici al di fuori degli istituti e dei luoghi di cui all'articolo 101 e' assicurata, secondo le disposizioni del presente Titolo, compatibilmente con lo svolgimento degli scopi istituzionali cui detti beni sono destinati.

4. Lo Stato, le regioni e gli altri enti pubblici territoriali stipulano accordi per definire strategie ed obiettivi comuni di valorizzazione, nonche' per elaborare i conseguenti piani strategici di sviluppo culturale e i programmi, relativamente ai beni culturali di pertinenza pubblica. Gli accordi possono essere conclusi su base regionale o subregionale, in rapporto ad ambiti territoriali definiti, e promuovono altresi' l'integrazione, nel processo di valorizzazione concordato, delle infrastrutture e dei settori produttivi collegati. Gli accordi medesimi possono riguardare anche beni di proprieta' privata, previo consenso degli interessati. Lo Stato stipula gli accordi per il tramite del Ministero, che opera direttamente ovvero d'intesa con le altre amministrazioni statali eventualmente competenti.

5. Lo Stato, per il tramite del Ministero e delle altre amministrazioni statali eventualmente competenti, le regioni e gli altri enti pubblici territoriali possono costituire, nel rispetto delle vigenti disposizioni, appositi soggetti giuridici cui affidare l'elaborazione e lo sviluppo dei piani di cui al comma 4.

6. In assenza degli accordi di cui al comma 4, ciascun soggetto pubblico e' tenuto a garantire la valorizzazione dei beni di cui ha comunque la disponibilita'.

7. Con decreto del Ministro sono definiti modalita' e criteri in base ai quali il Ministero costituisce i soggetti giuridici indicati al comma 5 o vi partecipa.

8. Ai soggetti di cui al comma 5 possono partecipare privati proprietari di beni culturali suscettibili di essere oggetto di valorizzazione, nonche' persone giuridiche private senza fine di lucro, anche quando non dispongano di beni culturali che siano oggetto della valorizzazione, a condizione che l'intervento in tale settore di attivita' sia per esse previsto dalla legge o dallo statuto.

9. Anche indipendentemente dagli accordi di cui al comma 4, possono essere stipulati accordi tra lo Stato, per il tramite del Ministero e delle altre amministrazioni statali eventualmente competenti, le regioni, gli altri enti pubblici territoriali e i privati interessati, per regolare servizi strumentali comuni destinati alla fruizione e alla valorizzazione di beni culturali. Con gli accordi medesimi possono essere anche istituite forme consortili non imprenditoriali per la gestione di uffici comuni. (( Per le stesse finalita' di cui al primo periodo, ulteriori accordi possono essere stipulati dal Ministero, dalle regioni, dagli altri enti pubblici territoriali, da ogni altro ente pubblico nonche' dai soggetti costituiti ai sensi del comma 5, con le associazioni culturali o di volontariato, dotate di adeguati requisiti, che abbiano per statuto finalita' di promozione e diffusione della conoscenza dei beni culturali. )) All'attuazione del presente comma si provvede nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica.

### Articolo 113 - Valorizzazione dei beni culturali di proprieta' privata

1. Le attivita' e le strutture di valorizzazione, ad iniziativa privata, di beni culturali di proprieta' privata possono beneficiare del sostegno pubblico da parte dello Stato, delle regioni e degli altri enti pubblici territoriali.

2. Le misure di sostegno sono adottate tenendo conto della rilevanza dei beni culturali ai quali si riferiscono.

3. Le modalita' della valorizzazione sono stabilite con accordo da stipularsi con il proprietario, possessore o detentore del bene in sede di adozione della misura di sostegno.

4. La regione e gli altri enti pubblici territoriali possono anche concorrere alla valorizzazione dei beni di cui all'articolo 104, comma 1, partecipando agli accordi ivi previsti al comma 3.

### Articolo 114 - Livelli di qualita' della valorizzazione

((

1. Il Ministero, le regioni e gli altri enti pubblici territoriali, anche con il concorso delle universita', fissano i livelli minimi uniformi di qualita' delle attivita' di valorizzazione su beni di pertinenza pubblica e ne curano l'aggiornamento periodico.

))

2. I livelli di cui al comma 1 sono adottati con decreto del Ministro previa intesa in sede di Conferenza unificata.

3. I soggetti che, ai sensi dell'articolo 115, hanno la gestione delle attivita' di valorizzazione sono tenuti ad assicurare il rispetto dei livelli adottati.

### Articolo 115 - (Forme di gestione)

1. Le attivita' di valorizzazione dei beni culturali di appartenenza pubblica sono gestite in forma diretta o indiretta.

2. La gestione diretta e' svolta per mezzo di strutture organizzative interne alle amministrazioni, dotate di adeguata autonomia scientifica, organizzativa, finanziaria e contabile, e provviste di idoneo personale tecnico. Le amministrazioni medesime possono attuare la gestione diretta anche in forma consortile pubblica.

3. La gestione indiretta e' attuata tramite concessione a terzi ((ovvero mediante l'affidamento di appalti pubblici di servizi)), anche in forma congiunta e integrata, da parte delle amministrazioni cui i beni pertengono o dei soggetti giuridici costituiti ai sensi dell'articolo 112, comma 5, qualora siano conferitari dei beni ai sensi del comma 7, mediante procedure di evidenza pubblica, sulla base della valutazione comparativa di specifici progetti. I privati che eventualmente partecipano ai soggetti indicati all'articolo 112, comma 5, non possono comunque essere individuati quali concessionari delle attivita' di valorizzazione.

4. Lo Stato, le regioni e gli altri enti pubblici territoriali ricorrono alla gestione indiretta al fine di assicurare un miglior livello di valorizzazione dei beni culturali. La scelta tra le due forme di gestione indicate ai commi 2 e 3 e' attuata mediante valutazione comparativa in termini di sostenibilita' economico-finanziaria e di efficacia, sulla base di obbiettivi previamente definiti. La gestione in forma indiretta e' attuata nel rispetto dei parametri di cui all'articolo 114 ((, ferma restando la possibilita' per le amministrazioni di progettare i servizi e i relativi contenuti, anche di dettaglio, mantenendo comunque il rischio operativo a carico del concessionario e l'equilibrio economico e finanziario della gestione)).

5. Le amministrazioni cui i beni pertengono e, ove conferitari dei beni, i soggetti giuridici costituiti ai sensi dell'articolo 112, comma 5, regolano i rapporti con i concessionari delle attivita' di valorizzazione mediante contratto di servizio, nel quale sono determinati, tra l'altro, i contenuti del progetto di gestione delle attivita' di valorizzazione ed i relativi tempi di attuazione, i livelli qualitativi delle attivita' da assicurare e dei servizi da erogare, nonche' le professionalita' degli addetti. Nel contratto di servizio sono indicati i servizi essenziali che devono essere comunque garantiti per la pubblica fruizione del bene.

6. Nel caso in cui la concessione a terzi delle attivita' di valorizzazione sia attuata dai soggetti giuridici di cui all'articolo 112, comma 5, in quanto conferitari dei beni oggetto della valorizzazione, la vigilanza sul rapporto concessorio e' esercitata anche dalle amministrazioni cui i beni pertengono. L'inadempimento, da parte del concessionario, degli obblighi derivanti dalla concessione e dal contratto di servizio, oltre alle conseguenze convenzionalmente stabilite, determina anche, a richiesta delle amministrazioni cui i beni pertengono, la risoluzione del rapporto concessorio e la cessazione, senza indennizzo, degli effetti del conferimento in uso dei beni.

7. Le amministrazioni possono partecipare al patrimonio dei soggetti di cui all'articolo 112, comma 5, anche con il conferimento in uso dei beni culturali che ad esse pertengono e che siano oggetto della valorizzazione. Al di fuori dell'ipotesi prevista al comma 6, gli effetti del conferimento si esauriscono, senza indennizzo, in tutti i casi di cessazione dalla partecipazione ai soggetti di cui al primo periodo o di estinzione dei medesimi. I beni conferiti in uso non sono assoggettati a garanzia patrimoniale specifica se non in ragione del loro controvalore economico.

8. Alla concessione delle attivita' di valorizzazione puo' essere collegata la concessione in uso degli spazi necessari all'esercizio delle attivita' medesime, previamente individuati nel capitolato d'oneri. La concessione in uso perde efficacia, senza indennizzo, in qualsiasi caso di cessazione della concessione delle attivita'.

9. Alle funzioni ed ai compiti derivanti dalle disposizioni del presente articolo il Ministero provvede nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica.

### Articolo 116 - (( (Tutela dei beni culturali conferiti o concessi in uso) ))

((

1. I beni culturali che siano stati conferiti o concessi in uso ai sensi dell'articolo 115, commi 7 e 8, restano a tutti gli effetti assoggettati al regime giuridico loro proprio. Le funzioni di tutela sono esercitate dal Ministero in conformita' alle disposizioni del presente codice. Gli organi istituzionalmente preposti alla tutela non partecipano agli organismi di gestione dei soggetti giuridici indicati all'articolo 112, comma 5.

))

### Articolo 117 - Servizi per il pubblico

1. Negli istituti e nei luoghi della cultura indicati all'articolo 101 possono essere istituiti servizi di assistenza culturale e di ospitalita' per il pubblico.

2. Rientrano tra i servizi di cui al comma 1:

- a) il servizio editoriale e di vendita riguardante i cataloghi e i sussidi catalografici, audiovisivi e informatici, ogni altro materiale informativo, e le riproduzioni di beni culturali;
- b) i servizi riguardanti beni librari e archivistici per la fornitura di riproduzioni e il recapito del prestito bibliotecario;
- c) la gestione di raccolte discografiche, di diapoteche e biblioteche museali;
- d) la gestione dei punti vendita e l'utilizzazione commerciale delle riproduzioni dei beni;
- e) i servizi di accoglienza, ivi inclusi quelli di assistenza e di intrattenimento per l'infanzia, i servizi di informazione, di guida e assistenza didattica, i centri di incontro;
- f) i servizi di caffetteria, di ristorazione, di guardaroba;
- g) l'organizzazione di mostre e manifestazioni culturali, nonche' di iniziative promozionali.

3. I servizi di cui al comma 1 possono essere gestiti in forma integrata con i servizi di pulizia, di vigilanza e di biglietteria. ((Qualora l'affidamento dei servizi integrati abbia ad oggetto una concessione di servizi ai sensi dell'articolo 3, comma 1, lettera vv), del decreto legislativo 18 aprile 2016, n. 50, l'integrazione puo' essere realizzata anche indipendentemente dal rispettivo valore economico dei servizi considerati. E' ammessa la stipulazione di contratti di appalto pubblico aventi ad oggetto uno o piu' servizi tra quelli di cui al comma 1 e uno o piu' tra i servizi di pulizia, di vigilanza e di biglietteria)).

4. La gestione dei servizi medesimi e' attuata nelle forme previste dall'articolo 115.

5. I canoni di concessione dei servizi sono incassati e ripartiti ai sensi dell'articolo 110. (13)

------------- AGGIORNAMENTO (13) Il D.L. 30 dicembre 2009, n. 194, convertito con modificazioni dalla L. 26 febbraio 2010, n. 25, ha disposto (con l'art. 7, comma 5) che "Al fine di assicurare la continuita' nell'erogazione dei servizi di assistenza culturale e di ospitalita' per il pubblico istituiti presso gli istituti ed i luoghi della cultura ai sensi dell'articolo 117 del codice dei beni culturali e del paesaggio di cui al decreto legislativo 22 gennaio 2004, n. 42, e successive modificazioni, e di consentire il completamento della relativa attivita' istruttoria e progettuale avviata dal Ministero per i beni e le attivita' culturali, i rapporti comunque in atto relativi ai medesimi servizi restano efficaci fino alla loro naturale scadenza ovvero, se scaduti, fino all'aggiudicazione delle gare da bandirsi entro il 30 giugno 2010".

### Articolo 118 - Promozione di attivita' di studio e ricerca

1. Il Ministero, le regioni e gli altri enti pubblici territoriali, anche con il concorso delle universita' e di altri soggetti pubblici e privati, realizzano, promuovono e sostengono, anche congiuntamente, ricerche, studi ed altre attivita' conoscitive aventi ad oggetto il patrimonio culturale.

2. Al fine di garantire la raccolta e la diffusione sistematica dei risultati degli studi, delle ricerche e delle altre attivita' di cui al comma 1, ivi compresa la catalogazione, il Ministero e le regioni possono stipulare accordi per istituire, a livello regionale o interregionale, centri permanenti di studio e documentazione del patrimonio culturale, prevedendo il concorso delle universita' e di altri soggetti pubblici e privati.

### Articolo 119 - (( (Diffusione della conoscenza del patrimonio culturale) ))

((

1. Il Ministero puo' concludere accordi con i Ministeri della pubblica istruzione e dell'universita' e della ricerca, le regioni e gli altri enti pubblici territoriali interessati, per diffondere la conoscenza del patrimonio culturale e favorirne la fruizione.

2. Sulla base degli accordi previsti al comma 1, i responsabili degli istituti e dei luoghi della cultura di cui all'articolo 101 possono stipulare apposite convenzioni con le universita', le scuole di ogni ordine e grado, appartenenti al sistema nazionale di istruzione, nonche' con ogni altro istituto di formazione, per l'elaborazione e l'attuazione di progetti formativi e di aggiornamento, dei connessi percorsi didattici e per la predisposizione di materiali e sussidi audiovisivi, destinati ai docenti ed agli operatori didattici. I percorsi, i materiali e i sussidi tengono conto della specificita' dell'istituto di formazione e delle eventuali particolari esigenze determinate dalla presenza di persone con disabilita'.

))

### Articolo 120 - Sponsorizzazione di beni culturali

((

1. E' sponsorizzazione di beni culturali ogni contributo, anche in beni o servizi, erogato per la progettazione o l'attuazione di iniziative in ordine alla tutela ovvero alla valorizzazione del patrimonio culturale, con lo scopo di promuovere il nome, il marchio, l'immagine, l'attivita' o il prodotto dell'attivita' del soggetto erogante. Possono essere oggetto di sponsorizzazione iniziative del Ministero, delle regioni, degli altri enti pubblici territoriali nonche' di altri soggetti pubblici o di persone giuridiche private senza fine di lucro, ovvero iniziative di soggetti privati su beni culturali di loro proprieta'. La verifica della compatibilita' di dette iniziative con le esigenze della tutela e' effettuata dal Ministero in conformita' alle disposizioni del presente codice.

))

2. La promozione di cui al comma 1 avviene attraverso l'associazione del nome, del marchio, dell'immagine, dell'attivita' o del prodotto all'iniziativa oggetto del contributo, in forme compatibili con il carattere artistico o storico, l'aspetto e il decoro del bene culturale da tutelare o valorizzare, da stabilirsi con il contratto di sponsorizzazione.

3. Con il contratto di sponsorizzazione sono altresi' definite le modalita' di erogazione del contributo nonche' le forme del controllo, da parte del soggetto erogante, sulla realizzazione dell'iniziativa cui il contributo si riferisce.

### Articolo 121 - Accordi con le fondazioni bancarie

1. Il Ministero, le regioni e gli altri enti pubblici territoriali, ciascuno nel proprio ambito, possono stipulare, anche congiuntamente, protocolli di intesa con le fondazioni conferenti di cui alle disposizioni in materia di ristrutturazione e disciplina del gruppo creditizio, che statutariamente perseguano scopi di utilita' sociale nel settore dell'arte e delle attivita' e beni culturali, al fine di coordinare gli interventi di valorizzazione sul patrimonio culturale e, in tale contesto, garantire l'equilibrato impiego delle risorse finanziarie messe a disposizione. La parte pubblica puo' concorrere, con proprie risorse finanziarie, per garantire il perseguimento degli obiettivi dei protocolli di intesa.

## Capo III - Consultabilita' dei documenti degli archivi e tutela della riservatezza

### Articolo 122 - Archivi di Stato e archivi storici degli enti pubblici: consultabilita' dei documenti

1. I documenti conservati negli archivi di Stato e negli archivi storici delle regioni, degli altri enti pubblici territoriali nonche' di ogni altro ente ed istituto pubblico sono liberamente consultabili, ad eccezione:

- a) di quelli dichiarati di carattere riservato, ai sensi dell'articolo 125, relativi alla politica estera o interna dello Stato, che diventano consultabili cinquanta anni dopo la loro data;
- b) di quelli contenenti i dati sensibili nonche' i dati relativi a provvedimenti di natura penale espressamente indicati dalla normativa in materia di trattamento dei dati personali, che diventano consultabili quaranta anni dopo la loro data. Il termine e' di settanta anni se i dati sono idonei a rivelare lo stato di salute, la vita sessuale o rapporti riservati di tipo familiare.
- b-bis) ((LETTERA ABROGATA DAL D.L. 31 MAGGIO 2014, N. 83, CONVERTITO CON MODIFICAZIONI DALLA L. 29 LUGLIO 2014, N. 106)).

2. Anteriormente al decorso dei termini indicati nel comma 1, i documenti restano accessibili ai sensi della disciplina sull'accesso ai documenti amministrativi. Sull'istanza di accesso provvede l'amministrazione che deteneva il documento prima del versamento o del deposito , ove ancora operante, ovvero quella che ad essa e' subentrata nell'esercizio delle relative competenze.

3. Alle disposizioni del comma 1 sono assoggettati anche gli archivi e i documenti di proprieta' privata depositati negli archivi di Stato e negli archivi storici degli enti pubblici, o agli archivi medesimi donati o venduti o lasciati in eredita' o legato. I depositanti e coloro che donano o vendono o lasciano in eredita' o legato i documenti possono anche stabilire la condizione della non consultabilita' di tutti o di parte dei documenti dell'ultimo settantennio. Tale limitazione, cosi' come quella generale stabilita dal comma 1, lettera b), non opera nei riguardi dei depositanti, dei donanti, dei venditori e di qualsiasi altra persona da essi designata; detta limitazione e' altresi' inoperante nei confronti degli aventi causa dai depositanti, donanti e venditori, quando si tratti di documenti concernenti oggetti patrimoniali, ai quali essi siano interessati per il titolo di acquisto.

### Articolo 123 - Archivi di Stato e archivi storici degli enti pubblici: consultabilita' dei documenti riservati

1. Il Ministro dell'interno, previo parere del direttore dell'Archivio di Stato competente e udita la commissione per le questioni inerenti alla consultabilita' degli atti di archivio riservati, istituita presso il Ministero dell'interno, puo' autorizzare la consultazione per scopi storici di documenti di carattere riservato conservati negli archivi di Stato anche prima della scadenza dei termini indicati nell'articolo 122, comma 1. L'autorizzazione e' rilasciata, a parita' di condizioni, ad ogni richiedente.

2. I documenti per i quali e' autorizzata la consultazione ai sensi del comma 1 conservano il loro carattere riservato e non possono essere (( ulteriormente utilizzati da altri soggetti senza la relativa autorizzazione )).

3. Alle disposizioni dei commi 1 e 2 e' assoggettata anche la consultazione per scopi storici di documenti di carattere riservato conservati negli archivi storici delle regioni, degli altri enti pubblici territoriali nonche' di ogni altro ente ed istituto pubblico. Il parere di cui al comma 1 e' reso dal soprintendente archivistico.

### Articolo 124 - Consultabilita' a scopi storici degli archivi correnti

1. Salvo quanto disposto dalla vigente normativa in materia di accesso agli atti della pubblica amministrazione, lo Stato, le regioni e gli altri enti pubblici territoriali disciplinano la consultazione a scopi storici dei propri archivi correnti e di deposito.

2. La consultazione ai fini del comma 1 degli archivi correnti e di deposito degli altri enti ed istituti pubblici, e' regolata dagli enti ed istituti medesimi, sulla base di indirizzi generali stabiliti dal Ministero.

### Articolo 125 - Declaratoria di riservatezza

1. L'accertamento dell'esistenza e della natura degli atti non liberamente consultabili indicati agli articoli 122 e 127 e' effettuato dal Ministero dell'interno, d'intesa con il Ministero.

### Articolo 126 - Protezione di dati personali

1. Qualora il titolare di dati personali abbia esercitato i diritti a lui riconosciuti dalla normativa che ne disciplina il trattamento, i documenti degli archivi storici sono conservati e consultabili unitamente alla documentazione relativa all'esercizio degli stessi diritti.

2. Su richiesta del titolare medesimo, puo' essere disposto il blocco dei dati personali che non siano di rilevante interesse pubblico, qualora il loro trattamento comporti un concreto pericolo di lesione della dignita', della riservatezza o dell'identita' personale dell'interessato.

3. La consultazione per scopi storici dei documenti contenenti dati personali e' assoggettata anche alle disposizioni del codice di deontologia e di buona condotta previsto dalla normativa in materia di trattamento dei dati personali.

### Articolo 127 - Consultabilita' degli archivi privati

1. I privati proprietari, possessori o detentori a qualsiasi titolo di archivi o di singoli documenti dichiarati ai sensi dell'articolo 13 hanno l'obbligo di permettere agli studiosi, che ne facciano motivata richiesta tramite il soprintendente archivistico, la consultazione dei documenti secondo modalita' concordate tra i privati stessi e il soprintendente. Le relative spese sono a carico dello studioso.

2. Sono esclusi dalla consultazione i singoli documenti dichiarati di carattere riservato ai sensi dell'articolo 125. Possono essere esclusi dalla consultazione anche i documenti per i quali sia stata posta la condizione di non consultabilita' ai sensi dell'articolo 122, comma 3.

3. Agli archivi privati utilizzati per scopi storici, anche se non dichiarati a norma dell'articolo 13, si applicano le disposizioni di cui agli articoli 123, comma 3, e 126, comma 3.

## TITOLO III Norme transitorie e finali

### Articolo 128 - Notifiche effettuate a norma della legislazione precedente

1. I beni culturali di cui all'articolo 10, comma 3, per i quali non sono state rinnovate e trascritte le notifiche effettuate a norma delle leggi 20 giugno 1909, n. 364 e 11 giugno 1922, n. 778, sono sottoposti al procedimento di cui all'articolo 14. Fino alla conclusione del procedimento medesimo, dette notifiche restano comunque valide agli effetti di questa Parte.

2. Conservano altresi' efficacia le notifiche effettuate a norma (( dell'articolo 22 della legge 22 dicembre 1939, n. 2006, )) degli articoli 2, 3, 5 e 21 della legge 1 giugno 1939, n. 1089 e le dichiarazioni adottate e notificate a norma dell'articolo 36 del decreto del Presidente della Repubblica 30 settembre 1963, n. 1409 e degli articoli 6, 7, 8 e 49 del decreto legislativo 29 ottobre 1999, n. 490.

3. In presenza di elementi di fatto sopravvenuti ovvero precedentemente non conosciuti o non valutati, il Ministero puo' rinnovare, d'ufficio o a richiesta del proprietario, possessore o detentore interessati, il procedimento di dichiarazione dei beni che sono stati oggetto delle notifiche di cui al comma 2, al fine di verificare la perdurante sussistenza dei presupposti per l'assoggettamento dei beni medesimi alle disposizioni di tutela.

4. Avverso il provvedimento di rigetto dell'istanza di rinnovo del procedimento di dichiarazione, prodotta ai sensi del comma 3, ovvero avverso la dichiarazione conclusiva del procedimento medesimo, anche quando esso sia stato avviato d'ufficio, e' ammesso ricorso amministrativo ai sensi dell'articolo 16.

### Articolo 129 - Provvedimenti legislativi particolari

1. Sono fatte salve le leggi aventi ad oggetto singole citta' o parti di esse, complessi architettonici, monumenti nazionali, siti od aree di interesse storico, artistico od archeologico.

2. Restano altresi' salve le disposizioni relative alle raccolte artistiche ex-fidecommissarie, impartite con legge 28 giugno 1871, n. 286, legge 8 luglio 1883, n. 1461, regio decreto 23 novembre 1891, n. 653 e legge 7 febbraio 1892, n. 31.

### Articolo 130 - Disposizioni regolamentari precedenti

1. Fino all'emanazione dei decreti e dei regolamenti previsti dal presente codice, restano in vigore, in quanto applicabili, le disposizioni dei regolamenti approvati con regi decreti 2 ottobre 1911, n. 1163 e 30 gennaio 1913, n. 363, e ogni altra disposizione regolamentare attinente alle norme contenute in questa Parte.

## Beni paesaggistici - - TITOLO I Tutela e valorizzazione Capo I Disposizioni generali

### Articolo 131 - (Paesaggio)

1. Per paesaggio si intende il territorio espressivo di identita', il cui carattere deriva dall'azione di fattori naturali, umani e dalle loro interrelazioni.

2. Il presente Codice tutela il paesaggio relativamente a quegli aspetti e caratteri che costituiscono rappresentazione materiale e visibile dell'identita' nazionale, in quanto espressione di valori culturali.

3. Salva la potesta' esclusiva dello Stato di tutela del paesaggio quale limite all'esercizio delle attribuzioni delle regioni e delle province autonome di Trento e di Bolzano sul territorio, le norme del presente Codice definiscono i principi e la disciplina di tutela dei beni paesaggistici.((11))

4. La tutela del paesaggio, ai fini del presente Codice, e' volta a riconoscere, salvaguardare e, ove necessario, recuperare i valori culturali che esso esprime. I soggetti indicati al comma 6, qualora intervengano sul paesaggio, assicurano la conservazione dei suoi aspetti e caratteri peculiari.

5. La valorizzazione del paesaggio concorre a promuovere lo sviluppo della cultura. A tale fine le amministrazioni pubbliche promuovono e sostengono, per quanto di rispettiva competenza, apposite attivita' di conoscenza, informazione e formazione, riqualificazione e fruizione del paesaggio nonche', ove possibile, la realizzazione di nuovi valori paesaggistici coerenti ed integrati. La valorizzazione e' attuata nel rispetto delle esigenze della tutela.

6. Lo Stato, le regioni, gli altri enti pubblici territoriali nonche' tutti i soggetti che, nell'esercizio di pubbliche funzioni, intervengono sul territorio nazionale, informano la loro attivita' ai principi di uso consapevole del territorio e di salvaguardia delle caratteristiche paesaggistiche e di realizzazione di nuovi valori paesaggistici integrati e coerenti, rispondenti a criteri di qualita' e sostenibilita'.

--------------- AGGIORNAMENTO (11) La Corte costituzionale, con sentenza 14 - 22 luglio 2009, n. 226 (in G.U. 1a s.s. 29/07/2009, n. 30) ha dichiarato l'illegittimita' costituzionale del comma 3 del presente articolo "nella parte in cui include le Province autonome di Trento e di Bolzano tra gli enti territoriali soggetti al limite della potesta' legislativa esclusiva statale di cui all'art. 117, secondo comma, lettera s), della Costituzione".

### Articolo 132 - (( (Convenzioni internazionali ) ))

((

1. La Repubblica si conforma agli obblighi ed ai principi di cooperazione tra gli Stati fissati dalle convenzioni internazionali in materia di conservazione e valorizzazione del paesaggio.

2. La ripartizione delle competenze in materia di paesaggio e' stabilita in conformita' ai principi costituzionali, anche con riguardo all'applicazione della Convenzione europea sul paesaggio, adottata a Firenze il 20 ottobre 2000, e delle relative norme di ratifica ed esecuzione.

))

### Articolo 133 - (( (Cooperazione tra amministrazioni pubbliche per la conservazione e la valorizzazione del paesaggio) ))

((

1. Il Ministero e le regioni definiscono d'intesa le politiche per la conservazione e la valorizzazione del paesaggio tenendo conto anche degli studi, delle analisi e delle proposte formulati dall'Osservatorio nazionale per la qualita' del paesaggio, istituito con decreto del Ministro, nonche' dagli Osservatori istituiti in ogni regione con le medesime finalita'.

2. Il Ministero e le regioni cooperano, altresi', per la definizione di indirizzi e criteri riguardanti l'attivita' di pianificazione territoriale, nonche' la gestione dei conseguenti interventi, al fine di assicurare la conservazione, il recupero e la valorizzazione degli aspetti e caratteri del paesaggio indicati all'articolo 131, comma 1. Nel rispetto delle esigenze della tutela, i detti indirizzi e criteri considerano anche finalita' di sviluppo territoriale sostenibile.

3. Gli altri enti pubblici territoriali conformano la loro attivita' di pianificazione agli indirizzi e ai criteri di cui al comma 2 e, nell'immediato, adeguano gli strumenti vigenti.

))

### Articolo 134 - Beni paesaggistici

1. Sono beni paesaggistici:

- a) gli immobili e le aree ((di cui)) all'articolo 136, individuati ai sensi degli articoli da 138 a 141;
- b) le aree ((di cui)) all'articolo 142;
- c) ((gli ulteriori immobili ed aree specificamente individuati a termini dell'articolo 136 e)) sottoposti a tutela dai piani paesaggistici previsti dagli articoli 143 e 156.

### Articolo 135 - (( (Pianificazione paesaggistica) ))

((

1. Lo Stato e le regioni assicurano che tutto il territorio sia adeguatamente conosciuto, salvaguardato, pianificato e gestito in ragione dei differenti valori espressi dai diversi contesti che lo costituiscono. A tale fine le regioni sottopongono a specifica normativa d'uso il territorio mediante piani paesaggistici, ovvero piani urbanistico-territoriali con specifica considerazione dei valori paesaggistici, entrambi di seguito denominati: "piani paesaggistici". L'elaborazione dei piani paesaggistici avviene congiuntamente tra Ministero e regioni, limitatamente ai beni paesaggistici di cui all'articolo 143, comma 1, lettere b), c) e d), nelle forme previste dal medesimo articolo 143.

2. I piani paesaggistici, con riferimento al territorio considerato, ne riconoscono gli aspetti e i caratteri peculiari, nonche' le caratteristiche paesaggistiche, e ne delimitano i relativi ambiti.

3. In riferimento a ciascun ambito, i piani predispongono specifiche normative d'uso, per le finalita' indicate negli articoli 131 e 133, ed attribuiscono adeguati obiettivi di qualita'.

4. Per ciascun ambito i piani paesaggistici definiscono apposite prescrizioni e previsioni ordinate in particolare:

- a) alla conservazione degli elementi costitutivi e delle morfologie dei beni paesaggistici sottoposti a tutela, tenuto conto anche delle tipologie architettoniche, delle tecniche e dei materiali costruttivi, nonche' delle esigenze di ripristino dei valori paesaggistici;
- b) alla riqualificazione delle aree compromesse o degradate;
- c) alla salvaguardia delle caratteristiche paesaggistiche degli altri ambiti territoriali, assicurando, al contempo, il minor consumo del territorio;
- d) alla individuazione delle linee di sviluppo urbanistico ed edilizio, in funzione della loro compatibilita' con i diversi valori paesaggistici riconosciuti e tutelati, con particolare attenzione alla salvaguardia dei paesaggi rurali e dei siti inseriti nella lista del patrimonio mondiale dell'UNESCO.

))

## Capo II - Individuazione dei beni paesaggistici

### Articolo 136 - Immobili ed aree di notevole interesse pubblico

1. Sono soggetti alle disposizioni di questo Titolo per il loro notevole interesse pubblico:

- a) le cose immobili che hanno cospicui caratteri di bellezza naturale (( , singolarita' geologica o memoria storica, ivi compresi gli alberi monumentali ));
- b) le ville, i giardini e i parchi, non tutelati dalle disposizioni della Parte seconda del presente codice, che si distinguono per la loro non comune bellezza;
- c) i complessi di cose immobili che compongono un caratteristico aspetto avente valore estetico e tradizionale , (( inclusi i centri ed i nuclei storici ));
- d) le bellezze panoramiche ((. . . )) e cosi' pure quei punti di vista o di belvedere, accessibili al pubblico, dai quali si goda lo spettacolo di quelle bellezze.

### Articolo 137 - (Commissioni regionali)

1. (( Le regioni istituiscono apposite commissioni, ))con il compito di formulare proposte per la dichiarazione di notevole interesse pubblico degli immobili indicati alle lettere a) e b) del comma 1 dell'articolo 136 e delle aree indicate alle lettere c) e d) del comma 1 del medesimo articolo 136.

2. Di ciascuna commissione fanno parte di diritto il direttore regionale, il soprintendente per i beni architettonici e per il paesaggio ed il soprintendente per i beni archeologici competenti per territorio, (( nonche' due responsabili )) preposti agli uffici regionali competenti in materia di paesaggio. I restanti membri, in numero non superiore a quattro, sono nominati dalla regione tra soggetti con qualificata, pluriennale e documentata professionalita' ed esperienza nella tutela del paesaggio, (( di norma )) scelti nell'ambito di terne designate, rispettivamente, dalle universita' aventi sede nella regione, dalle fondazioni aventi per statuto finalita' di promozione e tutela del patrimonio culturale e dalle associazioni portatrici di interessi diffusi (( individuate ai sensi delle vigenti disposizioni di legge in materia di ambiente e danno ambientale. La commissione e' integrata dal rappresentante del competente comando regionale del Corpo forestale dello Stato nei casi in cui la proposta riguardi filari, alberate ed alberi monumentali )). Decorsi infruttuosamente sessanta giorni dalla richiesta di designazione, la regione procede comunque alle nomine.

3. Fino all'istituzione delle commissioni di cui ai commi 1 e 2, le relative funzioni sono esercitate dalle commissioni istituite ai sensi della normativa previgente per l'esercizio di competenze analoghe.

### Articolo 138 - (( (Avvio del procedimento di dichiarazione di notevole interesse pubblico) ))

((

1. Le commissioni di cui all'articolo 137, su iniziativa dei componenti di parte ministeriale o regionale, ovvero su iniziativa di altri enti pubblici territoriali interessati, acquisite le necessarie informazioni attraverso le soprintendenze e i competenti uffici regionali e provinciali e consultati i comuni interessati nonche', ove opportuno, esperti della materia, valutano la sussistenza del notevole interesse pubblico, ai sensi dell'articolo 136, degli immobili e delle aree per i quali e' stata avviata l'iniziativa e propongono alla regione l'adozione della relativa dichiarazione. La proposta e' formulata con riferimento ai valori storici, culturali, naturali, morfologici, estetici espressi dagli aspetti e caratteri peculiari degli immobili o delle aree considerati ed alla loro valenza identitaria in rapporto al territorio in cui ricadono, e contiene proposte per le prescrizioni d'uso intese ad assicurare la conservazione dei valori espressi.

2. La commissione decide se dare ulteriore seguito all'atto di iniziativa entro sessanta giorni dalla data di presentazione dell'atto medesimo. Decorso infruttuosamente il predetto termine, entro i successivi trenta giorni il componente della commissione o l'ente pubblico territoriale che ha assunto l'iniziativa puo' formulare la proposta di dichiarazione direttamente alla regione.

3. E' fatto salvo il potere del Ministero, su proposta motivata del soprintendente, previo parere della regione interessata che deve essere motivatamente espresso entro e non oltre trenta giorni dalla richiesta, di dichiarare il notevole interesse pubblico degli immobili e delle aree di cui all'articolo 136.

))

### Articolo 139

( (( Procedimento ))di dichiarazione di notevole interesse pubblico)

1. (( La proposta di dichiarazione di notevole interesse pubblico di cui all'articolo 138, corredata di planimetria redatta in scala idonea alla puntuale individuazione degli immobili e delle aree che ne costituiscono oggetto, )) e' pubblicata per novanta giorni all'albo pretorio e depositata a disposizione del pubblico presso gli uffici dei comuni interessati. La proposta e' altresi' comunicata alla citta' metropolitana e alla provincia ((interessate)).

2. Dell'avvenuta proposta e relativa pubblicazione e' data senza indugio notizia su almeno due quotidiani diffusi nella regione ((. . . )) interessata, nonche' su un quotidiano a diffusione nazionale e sui siti informatici della regione e degli altri enti pubblici territoriali nel cui ambito ricadono gli immobili o le aree da assoggettare a tutela. Dal primo giorno di pubblicazione decorrono gli effetti di cui all'articolo 146, comma 1. Alle medesime forme di pubblicita' e' sottoposta la determinazione negativa della commissione.

3. Per gli immobili indicati alle lettere a) e b) del comma 1 dell'articolo 136, viene altresi' data comunicazione dell'avvio del procedimento di dichiarazione al proprietario, possessore o detentore del bene.

4. La comunicazione di cui al comma 3 contiene gli elementi, anche catastali, identificativi dell'immobile e la proposta formulata dalla commissione. Dalla data di ricevimento della comunicazione decorrono gli effetti di cui all'articolo 146, comma 1.

5. Entro i trenta giorni successivi al periodo di pubblicazione di cui al comma 1, i comuni, le citta' metropolitane, le province, le associazioni portatrici di interessi diffusi individuate (( ai sensi delle vigenti disposizioni di legge in materia di ambiente e danno ambientale, )) e gli altri soggetti interessati possono presentare osservazioni e documenti alla regione, che ha altresi' facolta' di indire un'inchiesta pubblica. I proprietari, possessori o detentori del bene possono presentare osservazioni e documenti entro i trenta giorni successivi alla comunicazione individuale di cui al comma 3.

### Articolo 140 - (Dichiarazione di notevole interesse pubblico e relative misure di conoscenza)

1. La regione, sulla base della proposta della commissione, esaminati le osservazioni e i documenti e tenuto conto dell'esito dell'eventuale inchiesta pubblica, entro ((. . . )) sessanta giorni dalla data di scadenza dei termini di cui all'articolo 139, comma 5, emana il provvedimento relativo alla dichiarazione di notevole interesse pubblico ((. . .)) ((degli immobili e delle aree indicati, rispettivamente, alle lettere a) e b) e alle lettere c) e d) del comma 1 dell'articolo 136 )).

((

2. La dichiarazione di notevole interesse pubblico detta la specifica disciplina intesa ad assicurare la conservazione dei valori espressi dagli aspetti e caratteri peculiari del territorio considerato. Essa costituisce parte integrante del piano paesaggistico e non e' suscettibile di rimozioni o modifiche nel corso del procedimento di redazione o revisione del piano medesimo.

3. La dichiarazione di notevole interesse pubblico, quando ha ad oggetto gli immobili indicati alle lettere a) e b) dell'articolo 136, comma 1, e' notificata al proprietario, possessore o detentore, depositata presso ogni comune interessato e trascritta, a cura della regione, nei registri immobiliari. Ogni dichiarazione di notevole interesse pubblico e' pubblicata nella Gazzetta Ufficiale della Repubblica italiana e nel Bollettino ufficiale della regione.

4. Copia della Gazzetta Ufficiale e' affissa per novanta giorni all'albo pretorio di tutti i comuni interessati. Copia della dichiarazione e delle relative planimetrie resta depositata a disposizione del pubblico presso gli uffici dei comuni interessati.

))

5. (( COMMA ABROGATO DAL D.LGS. 26 MARZO 2008 N. 63 )).

### Articolo 141 - (( (Provvedimenti ministeriali) ))

((

1. Le disposizioni di cui agli articoli 139 e 140 si applicano anche ai procedimenti di dichiarazione di notevole interesse pubblico di cui all'articolo 138, comma 3. In tale caso i comuni interessati, ricevuta la proposta di dichiarazione formulata dal soprintendente, provvedono agli adempimenti indicati all'articolo 139, comma 1, mentre agli adempimenti indicati ai commi 2, 3 e 4 del medesimo articolo 139 provvede direttamente il soprintendente.

2. Il Ministero, valutate le eventuali osservazioni presentate ai sensi del detto articolo 139, comma 5, e sentito il competente Comitato tecnico-scientifico, adotta la dichiarazione di notevole interesse pubblico, a termini dell'articolo 140, commi 1 e 2, e ne cura la pubblicazione nella Gazzetta Ufficiale della Repubblica italiana e nel Bollettino ufficiale della regione.

3. Il soprintendente provvede alla notifica della dichiarazione, al suo deposito presso i comuni interessati e alla sua trascrizione nei registri immobiliari, ai sensi dell'articolo 140, comma 3.

4. La trasmissione ai comuni del numero della Gazzetta Ufficiale contenente la dichiarazione, come pure la trasmissione delle relative planimetrie, e' fatta dal Ministero, per il tramite della soprintendenza, entro dieci giorni dalla data di pubblicazione del numero predetto. La soprintendenza vigila sull'adempimento, da parte di ogni comune interessato, di quanto prescritto dall'articolo 140, comma 4, e ne da' comunicazione al Ministero.

5. Se il provvedimento ministeriale di dichiarazione non e' adottato nei termini di cui all'articolo 140, comma 1, allo scadere dei detti termini, per le aree e gli immobili oggetto della proposta di dichiarazione, cessano gli effetti di cui all'articolo 146, comma 1.

))

### Articolo 141-bis - (( (Integrazione del contenuto delle dichiarazioni di notevole interesse pubblico) ))

((

1. Il Ministero e le regioni provvedono ad integrare le dichiarazioni di notevole interesse pubblico rispettivamente adottate con la specifica disciplina di cui all'articolo 140, comma 2.

2. Qualora le regioni non provvedano alle integrazioni di loro competenza entro il 31 dicembre 2009, il Ministero provvede in via sostitutiva. La procedura di sostituzione e' avviata dalla soprintendenza ed il provvedimento finale e' adottato dal Ministero, sentito il competente Comitato tecnico-scientifico.

3. I provvedimenti integrativi adottati ai sensi dei commi 1 e 2 producono gli effetti previsti dal secondo periodo del comma 2 dell'articolo 140 e sono sottoposti al regime di pubblicita' stabilito dai commi 3 e 4 del medesimo articolo.

))

### Articolo 142 - (Aree tutelate per legge)

1. Sono comunque di interesse paesaggistico e sono sottoposti alle disposizioni di questo Titolo:

- a) i territori costieri compresi in una fascia della profondita' di 300 metri dalla linea di battigia, anche per i terreni elevati sul mare;
- b) i territori contermini ai laghi compresi in una fascia della profondita' di 300 metri dalla linea di battigia, anche per i territori elevati sui laghi;
- c) i fiumi, i torrenti, i corsi d'acqua iscritti negli elenchi previsti dal testo unico delle disposizioni di legge sulle acque ed impianti elettrici, approvato con regio decreto 11 dicembre 1933, n. 1775, e le relative sponde o piedi degli argini per una fascia di 150 metri ciascuna;
- d) le montagne per la parte eccedente 1.600 metri sul livello del mare per la catena alpina e 1.200 metri sul livello del mare per la catena appenninica e per le isole;
- e) i ghiacciai e i circhi glaciali;
- f) i parchi e le riserve nazionali o regionali, nonche' i territori di protezione esterna dei parchi;
- g) i territori coperti da foreste e da boschi, ancorche' percorsi o danneggiati dal fuoco, e quelli sottoposti a vincolo di rimboschimento, come definiti dall'articolo 2, commi 2 e 6, del decreto legislativo 18 maggio 2001, n. 227;
- h) le aree assegnate alle universita' agrarie e le zone gravate da usi civici;
- i) le zone umide incluse nell'elenco previsto dal decreto del Presidente della Repubblica 13 marzo 1976, n. 448;
- l) i vulcani;
- m) le zone di interesse archeologico ((. . . )).

2. (( La disposizione di cui al comma 1, lettere a), b), c), d), e), g), h), l), m), non si applica alle aree ))che alla data del 6 settembre 1985:

- a) erano delimitate negli strumenti urbanistici ((, ai sensi del decreto ministeriale 2 aprile 1968, n. 1444, come zone territoriali omogenee A e B));
- b) erano delimitate negli strumenti urbanistici ai sensi del decreto ministeriale 2 aprile 1968, n. 1444, (( come zone territoriali omogenee diverse dalle zone A e B, limitatamente alle parti di esse ricomprese )) in piani pluriennali di attuazione, a condizione che le relative previsioni siano state concretamente realizzate;
- c) nei comuni sprovvisti di tali strumenti, ricadevano nei centri edificati perimetrati ai sensi dell'articolo 18 della legge 22 ottobre 1971, n. 865.

3. (( La disposizione del comma 1 non si applica, altresi', ai beni ivi indicati alla lettera c) che la regione abbia ritenuto in tutto o in parte )) irrilevanti ai fini paesaggistici includendoli in apposito elenco reso pubblico e comunicato al Ministero. Il Ministero, con provvedimento motivato, puo' confermare la rilevanza paesaggistica dei suddetti beni. Il provvedimento di conferma e' sottoposto alle forme di pubblicita' previste dall'articolo 140, (( comma 4)).

4. Resta in ogni caso ferma la disciplina derivante dagli atti e dai provvedimenti indicati all'articolo 157.

## Capo III - Pianificazione paesaggistica

### Articolo 143 - (( (Piano paesaggistico) ))

((

1. L'elaborazione del piano paesaggistico comprende almeno:

- a) ricognizione del territorio oggetto di pianificazione, mediante l'analisi delle sue caratteristiche paesaggistiche, impresse dalla natura, dalla storia e dalle loro interrelazioni, ai sensi degli articoli 131 e 135;
- b) ricognizione degli immobili e delle aree dichiarati di notevole interesse pubblico ai sensi dell'articolo 136, loro delimitazione e rappresentazione in scala idonea alla identificazione, nonche' determinazione delle specifiche prescrizioni d'uso, a termini dell'articolo 138, comma 1, fatto salvo il disposto di cui agli articoli 140, comma 2, e 141-bis;
- c) ricognizione delle aree di cui al comma 1 dell'articolo 142, loro delimitazione e rappresentazione in scala idonea alla identificazione, nonche' determinazione di prescrizioni d'uso intese ad assicurare la conservazione dei caratteri distintivi di dette aree e, compatibilmente con essi, la valorizzazione;
- d) eventuale individuazione di ulteriori immobili od aree, di notevole interesse pubblico a termini dell'articolo 134, comma 1, lettera c), loro delimitazione e rappresentazione in scala idonea alla identificazione, nonche' determinazione delle specifiche prescrizioni d'uso, a termini dell'articolo 138, comma 1;
- e) individuazione di eventuali, ulteriori contesti, diversi da quelli indicati all'articolo 134, da sottoporre a specifiche misure di salvaguardia e di utilizzazione;
- f) analisi delle dinamiche di trasformazione del territorio ai fini dell'individuazione dei fattori di rischio e degli elementi di vulnerabilita' del paesaggio, nonche' comparazione con gli altri atti di programmazione, di pianificazione e di difesa del suolo;
- g) individuazione degli interventi di recupero e riqualificazione delle aree significativamente compromesse o degradate e degli altri interventi di valorizzazione compatibili con le esigenze della tutela;
- h) individuazione delle misure necessarie per il corretto inserimento, nel contesto paesaggistico, degli interventi di trasformazione del territorio, al fine di realizzare uno sviluppo sostenibile delle aree interessate;
- i) individuazione dei diversi ambiti e dei relativi obiettivi di qualita', a termini dell'articolo 135, comma 3.

2. Le regioni, il Ministero ed il Ministero dell'ambiente e della tutela del territorio e del mare possono stipulare intese per la definizione delle modalita' di elaborazione congiunta dei piani paesaggistici, salvo quanto previsto dall'articolo 135, comma 1, terzo periodo. Nell'intesa e' stabilito il termine entro il quale deve essere completata l'elaborazione del piano. Il piano e' oggetto di apposito accordo fra pubbliche amministrazioni, ai sensi dell'articolo 15 della legge 7 agosto 1990, n. 241. L'accordo stabilisce altresi' i presupposti, le modalita' ed i tempi per la revisione del piano, con particolare riferimento all'eventuale sopravvenienza di dichiarazioni emanate ai sensi degli articoli 140 e 141 o di integrazioni disposte ai sensi dell'articolo 141-bis. Il piano e' approvato con provvedimento regionale entro il termine fissato nell'accordo. Decorso inutilmente tale termine, il piano, limitatamente ai beni paesaggistici di cui alle lettere b), c) e d) del comma 1, e' approvato in via sostitutiva con decreto del Ministro, sentito il Ministro dell'ambiente e della tutela del territorio e del mare.

3. Approvato il piano paesaggistico, il parere reso dal soprintendente nel procedimento autorizzatorio di cui agli articoli 146 e 147 e' vincolante in relazione agli interventi da eseguirsi nell'ambito dei beni paesaggistici di cui alle lettere b), c) e d) del comma 1, salvo quanto disposto al comma 4, nonche' quanto previsto dall'articolo 146, comma 5.

4. Il piano puo' prevedere:

- a) la individuazione di aree soggette a tutela ai sensi dell'articolo 142 e non interessate da specifici procedimenti o provvedimenti ai sensi degli articoli 136, 138, 139, 140, 141 e 157, nelle quali la realizzazione di interventi puo' avvenire previo accertamento, nell'ambito del procedimento ordinato al rilascio del titolo edilizio, della conformita' degli interventi medesimi alle previsioni del piano paesaggistico e dello strumento urbanistico comunale;
- b) la individuazione delle aree gravemente compromesse o degradate nelle quali la realizzazione degli interventi effettivamente volti al recupero ed alla riqualificazione non richiede il rilascio dell'autorizzazione di cui all'articolo 146.

5. L'entrata in vigore delle disposizioni di cui al comma 4 e' subordinata all'approvazione degli strumenti urbanistici adeguati al piano paesaggistico, ai sensi dell'articolo 145, commi 3 e 4.

6. Il piano puo' anche subordinare l'entrata in vigore delle disposizioni che consentono la realizzazione di interventi senza autorizzazione paesaggistica, ai sensi del comma 4, all'esito positivo di un periodo di monitoraggio che verifichi l'effettiva conformita' alle previsioni vigenti delle trasformazioni del territorio realizzate.

7. Il piano prevede comunque che nelle aree di cui al comma 4, lettera a), siano effettuati controlli a campione sugli interventi realizzati e che l'accertamento di significative violazioni delle previsioni vigenti determini la reintroduzione dell'obbligo dell'autorizzazione di cui agli articoli 146 e 147, relativamente ai comuni nei quali si sono rilevate le violazioni.

8. Il piano paesaggistico puo' individuare anche linee-guida prioritarie per progetti di conservazione, recupero, riqualificazione, valorizzazione e gestione di aree regionali, indicandone gli strumenti di attuazione, comprese le misure incentivanti.

9. A far data dall'adozione del piano paesaggistico non sono consentiti, sugli immobili e nelle aree di cui all'articolo 134, interventi in contrasto con le prescrizioni di tutela previste nel piano stesso. A far data dalla approvazione del piano le relative previsioni e prescrizioni sono immediatamente cogenti e prevalenti sulle previsioni dei piani territoriali ed urbanistici.

))

### Articolo 144 - Pubblicita' e partecipazione

1. Nei procedimenti di approvazione dei piani paesaggistici sono assicurate la concertazione istituzionale, la partecipazione dei soggetti interessati e delle (( associazioni portatrici di interessi diffusi, individuate ai sensi delle vigenti disposizioni in materia di ambiente e danno ambientale, )) e ampie forme di pubblicita'. ((A tale fine le regioni disciplinano mediante apposite norme di legge i procedimenti di pianificazione paesaggistica, anche in riferimento ad ulteriori forme di partecipazione, informazione e comunicazione. ))

2. Fatto salvo quanto disposto (( all'articolo 143, comma 9)), il piano paesaggistico diviene efficace il giorno successivo a quello della sua pubblicazione nel Bollettino ufficiale della regione.

### Articolo 145 - Coordinamento della pianificazione paesaggistica con altri strumenti di pianificazione

1. (( La individuazione, da parte del Ministero, delle )) linee fondamentali dell'assetto del territorio nazionale per quanto riguarda la tutela del paesaggio, con finalita' di indirizzo della pianificazione ((, costituisce compito di rilievo nazionale, ai sensi delle vigenti disposizioni in materia di principi e criteri direttivi per il conferimento di funzioni e compiti alle regioni ed enti locali )).

2. I piani paesaggistici (( possono prevedere)) misure di coordinamento con gli strumenti di pianificazione territoriale e di settore, nonche' con i piani, programmi e progetti nazionali e regionali di sviluppo economico.

3. Le previsioni dei piani paesaggistici di cui agli articoli 143 e 156 (( non sono derogabili da parte di piani, programmi e progetti nazionali o regionali di sviluppo economico, )) sono cogenti per gli strumenti urbanistici dei comuni, delle citta' metropolitane e delle province, sono immediatamente prevalenti sulle disposizioni difformi eventualmente contenute negli strumenti urbanistici, stabiliscono norme di salvaguardia applicabili in attesa dell'adeguamento degli strumenti urbanistici e sono altresi' vincolanti per gli interventi settoriali. Per quanto attiene alla tutela del paesaggio, le disposizioni dei piani paesaggistici sono comunque prevalenti sulle disposizioni contenute negli atti di pianificazione ad incidenza territoriale previsti dalle normative di settore, ivi compresi quelli degli enti gestori delle aree naturali protette.

((

4. I comuni, le citta' metropolitane, le province e gli enti gestori delle aree naturali protette conformano o adeguano gli strumenti di pianificazione urbanistica e territoriale alle previsioni dei piani paesaggistici, secondo le procedure previste dalla legge regionale, entro i termini stabiliti dai piani medesimi e comunque non oltre due anni dalla loro approvazione. I limiti alla proprieta' derivanti da tali previsioni non sono oggetto di indennizzo.

))

5. La regione disciplina il procedimento di conformazione ed adeguamento degli strumenti urbanistici alle previsioni della pianificazione paesaggistica, assicurando la partecipazione degli organi ministeriali al procedimento medesimo.

## Capo IV - Controllo e gestione dei beni soggetti a tutela

### Articolo 146 - (Autorizzazione)

1. I proprietari, possessori o detentori a qualsiasi titolo di immobili ed aree di interesse paesaggistico, tutelati dalla legge, a termini dell'articolo 142, o in base alla legge, a termini degli articoli 136, 143, comma 1, lettera d), e 157, non possono distruggerli, ne' introdurvi modificazioni che rechino pregiudizio ai valori paesaggistici oggetto di protezione.

2. I soggetti di cui al comma 1 hanno l'obbligo di presentare alle amministrazioni competenti il progetto degli interventi che intendano intraprendere, corredato della prescritta documentazione, ed astenersi dall'avviare i lavori fino a quando non ne abbiano ottenuta l'autorizzazione.

3. La documentazione a corredo del progetto e' preordinata alla verifica della compatibilita' fra interesse paesaggistico tutelato ed intervento progettato. Essa e' individuata, su proposta del Ministro, con decreto del Presidente del Consiglio dei Ministri, d'intesa con la Conferenza Stato-regioni, e puo' essere aggiornata o integrata con il medesimo procedimento.

4. L'autorizzazione paesaggistica costituisce atto autonomo e presupposto rispetto al permesso di costruire o agli altri titoli legittimanti l'intervento urbanistico-edilizio. Fuori dai casi di cui all'articolo 167, commi 4 e 5, l'autorizzazione non puo' essere rilasciata in sanatoria successivamente alla realizzazione, anche parziale, degli interventi. L'autorizzazione e' efficace per un periodo di cinque anni, scaduto il quale l'esecuzione dei progettati lavori deve essere sottoposta a nuova autorizzazione. I lavori iniziati nel corso del quinquennio di efficacia dell'autorizzazione possono essere conclusi entro e non oltre l'anno successivo la scadenza del quinquennio medesimo. Il termine di efficacia dell'autorizzazione decorre dal giorno in cui acquista efficacia il titolo edilizio eventualmente necessario per la realizzazione dell'intervento, a meno che il ritardo in ordine al rilascio e alla conseguente efficacia di quest'ultimo non sia dipeso da circostanze imputabili all'interessato.

5. Sull'istanza di autorizzazione paesaggistica si pronuncia la regione, dopo avere acquisito il parere vincolante del soprintendente in relazione agli interventi da eseguirsi su immobili ed aree sottoposti a tutela dalla legge o in base alla legge, ai sensi del comma 1, salvo quanto disposto all'articolo 143, commi 4 e 5. Il parere del soprintendente, all'esito dell'approvazione delle prescrizioni d'uso dei beni paesaggistici tutelati, predisposte ai sensi degli articoli 140, comma 2, 141, comma 1, 141-bis e 143, comma 1, lettere b), c) e d), nonche' della positiva verifica da parte del Ministero, su richiesta della regione interessata, dell'avvenuto adeguamento degli strumenti urbanistici, assume natura obbligatoria non vincolante ed e' reso nel rispetto delle previsioni e delle prescrizioni del piano paesaggistico, entro il termine di quarantacinque giorni dalla ricezione degli atti, decorsi i quali l'amministrazione competente provvede sulla domanda di autorizzazione.

6. La regione esercita la funzione autorizzatoria in materia di paesaggio avvalendosi di propri uffici dotati di adeguate competenze tecnico-scientifiche e idonee risorse strumentali. Puo' tuttavia delegarne l'esercizio, per i rispettivi territori, a province, a forme associative e di cooperazione fra enti locali come definite dalle vigenti disposizioni sull'ordinamento degli enti locali,agli enti parco, ovvero a comuni, purche' gli enti destinatari della delega dispongano di strutture in grado di assicurare un adeguato livello di competenze tecnico-scientifiche nonche' di garantire la differenziazione tra attivita' di tutela paesaggistica ed esercizio di funzioni amministrative in materia urbanistico-edilizia.

7. L'amministrazione competente al rilascio dell'autorizzazione paesaggistica, ricevuta l'istanza dell'interessato, verifica se ricorrono i presupposti per l'applicazione dell'articolo 149, comma 1, alla stregua dei criteri fissati ai sensi degli articoli 140, comma 2, 141, comma 1, 141-bis e 143, comma 1, lettere b), c) e d). Qualora detti presupposti non ricorrano, l'amministrazione verifica se l'istanza stessa sia corredata della documentazione di cui al comma 3, provvedendo, ove necessario, a richiedere le opportune integrazioni e a svolgere gli accertamenti del caso. Entro quaranta giorni dalla ricezione dell'istanza, l'amministrazione effettua gli accertamenti circa la conformita' dell'intervento proposto con le prescrizioni contenute nei provvedimenti di dichiarazione di interesse pubblico e nei piani paesaggistici e trasmette al soprintendente la documentazione presentata dall'interessato, accompagnandola con una relazione tecnica illustrativa nonche' con una proposta di provvedimento, e da' comunicazione all'interessato dell'inizio del procedimento e dell'avvenuta trasmissione degli atti al soprintendente, ai sensi delle vigenti disposizioni di legge in materia di procedimento amministrativo.

8. Il soprintendente rende il parere di cui al comma 5, limitatamente alla compatibilita' paesaggistica del progettato intervento nel suo complesso ed alla conformita' dello stesso alle disposizioni contenute nel piano paesaggistico ovvero alla specifica disciplina di cui all'articolo 140, comma 2, entro il termine di quarantacinque giorni dalla ricezione degli atti. Il soprintendente, in caso di parere negativo, comunica agli interessati il preavviso di provvedimento negativo ai sensi dell'articolo 10-bis della legge 7 agosto 1990, n. 241. Entro venti giorni dalla ricezione del parere, l'amministrazione provvede in conformita'.

9. ((PERIODO SOPPRESSO DAL D.L. 12 SETTEMBRE 2014, N. 133, CONVERTITO CON MODIFCAZIONI DALLA L. 11 NOVEMBRE 2014, N. 164)). ((PERIODO SOPPRESSO DAL D.L. 12 SETTEMBRE 2014, N. 133, CONVERTITO CON MODIFCAZIONI DALLA L. 11 NOVEMBRE 2014, N. 164)). ((Decorsi inutilmente sessanta giorni dalla ricezione degli atti da parte del soprintendente senza che questi abbia reso il prescritto parere, l'amministrazione competente provvede comunque sulla domanda di autorizzazione.)) Con regolamento da emanarsi ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, entro il 31 dicembre 2008, su proposta del Ministro d'intesa con la Conferenza unificata, salvo quanto previsto dall'articolo 3 del decreto legislativo 28 agosto 1997, n. 281, sono stabilite procedure semplificate per il rilascio dell'autorizzazione in relazione ad interventi di lieve entita' in base a criteri di snellimento e concentrazione dei procedimenti, ferme, comunque, le esclusioni di cui agli articoli 19, comma 1 e 20, comma 4 della legge 7 agosto 1990, n. 241 e successive modificazioni.

10. Decorso inutilmente il termine indicato all'ultimo periodo del comma 8 senza che l'amministrazione si sia pronunciata, l'interessato puo' richiedere l'autorizzazione in via sostitutiva alla regione, che vi provvede, anche mediante un commissario ad acta, entro sessanta giorni dal ricevimento della richiesta. Qualora la regione non abbia delegato gli enti indicati al comma 6 al rilascio dell'autorizzazione paesaggistica, e sia essa stessa inadempiente, la richiesta del rilascio in via sostitutiva e' presentata al soprintendente.

11. L'autorizzazione paesaggistica e' trasmessa, senza indugio, alla soprintendenza che ha reso il parere nel corso del procedimento, nonche', unitamente allo stesso parere, alla regione ovvero agli altri enti pubblici territoriali interessati e, ove esistente, all'ente parco nel cui territorio si trova l'immobile o l'area sottoposti al vincolo.

12. L'autorizzazione paesaggistica e' impugnabile, con ricorso al tribunale amministrativo regionale o con ricorso straordinario al Presidente della Repubblica, dalle associazioni portatrici di interessi diffusi individuate ai sensi delle vigenti disposizioni di legge in materia di ambiente e danno ambientale, e da qualsiasi altro soggetto pubblico o privato che ne abbia interesse. Le sentenze e le ordinanze del Tribunale amministrativo regionale possono essere appellate dai medesimi soggetti, anche se non abbiano proposto ricorso di primo grado.

13. Presso ogni amministrazione competente al rilascio dell'autorizzazione paesaggistica e' istituito un elenco delle autorizzazioni rilasciate, aggiornato almeno ogni trenta giorni e liberamente consultabile, anche per via telematica, in cui e' indicata la data di rilascio di ciascuna autorizzazione, con la annotazione sintetica del relativo oggetto. Copia dell'elenco e' trasmessa trimestralmente alla regione e alla soprintendenza, ai fini dell'esercizio delle funzioni di vigilanza.

14. Le disposizioni dei commi da 1 a 13 si applicano anche alle istanze concernenti le attivita' di coltivazione di cave e torbiere nonche' per le attivita' minerarie di ricerca ed estrazione incidenti sui beni di cui all'articolo 134.

15. COMMA ABROGATO DAL D.L. 13 MAGGIO 2011, N. 70, CONVERTITO CON MODIFICAZIONI DALLA L. 12 LUGLIO 2011, N. 106.

16. Dall'attuazione del presente articolo non devono derivare nuovi o maggiori oneri a carico della finanza pubblica. ((24))

-------------- AGGIORNAMENTO (24) Il D.L. 12 settembre 2014, n. 133 convertito con modificazioni dalla L. 11 novembre 2014, n. 164 ha disposto (con l'art. 6, comma 4) che "In deroga all'articolo 146 del codice dei beni culturali e del paesaggio, di cui al decreto legislativo 22 gennaio 2004, n. 42, e successive modificazioni, non sono soggette ad autorizzazione paesaggistica l'installazione o la modifica di impianti delle reti di comunicazione elettronica o di impianti radioelettrici, da eseguire su edifici e tralicci preesistenti, che comportino la realizzazione di pali di supporto per antenne di altezza non superiore a 1,5 metri e superficie delle medesime antenne non superiore a 0,5 metri quadrati. Resta ferma l'applicazione degli articoli 20 e seguenti del codice di cui al citato decreto legislativo n. 42 del 2004, e successive modificazioni".

### Articolo 147 - Autorizzazione per opere da eseguirsi da parte di amministrazioni statali

1. Qualora la richiesta di autorizzazione prevista dall'articolo 146 riguardi opere da eseguirsi da parte di amministrazioni statali, ivi compresi gli alloggi di servizio per il personale militare, l'autorizzazione viene rilasciata in esito ad una (( conferenza di servizi indetta ai sensi delle vigenti disposizioni di legge in materia di procedimento amministrativo. ))

2. Per i progetti di opere comunque soggetti a valutazione di impatto ambientale a norma (( delle vigenti disposizioni di legge in materia di ambiente e danno ambientale )) e da eseguirsi da parte di amministrazioni statali, si applica l'articolo 26 . ((I progetti sono corredati della documentazione prevista dal comma 3 dell'articolo 146. ))

3. Entro sei mesi dalla data di entrata in vigore del presente codice, con decreto del Presidente del Consiglio dei ministri, su proposta del Ministero, d'intesa con il Ministero della difesa e con le altre amministrazioni statali interessate, sono individuate le modalita' di valutazione congiunta e preventiva della localizzazione delle opere di difesa nazionale che incidano su immobili o aree sottoposti a tutela paesaggistica.

### Articolo 148 - (Commissioni locali per il paesaggio)

1. (( Le regioni ))promuovono l'istituzione e disciplinano il funzionamento delle commissioni per il paesaggio di supporto ai soggetti ai quali sono delegate le competenze in materia di autorizzazione paesaggistica, ai sensi dell'articolo 146, (( comma 6)).

2. Le commissioni((. . . )) sono composte da soggetti con particolare, pluriennale e qualificata esperienza nella tutela del paesaggio.

3. Le commissioni esprimono (( pareri nel corso dei procedimenti autorizzatori previsti ))dagli articoli 146, ((comma 7, )) 147 e 159.

4. ((COMMA SOPPRESSO DAL D.LGS. 26 MARZO 2008, N. 63 )).

### Articolo 149 - Interventi non soggetti ad autorizzazione

1. Fatta salva l'applicazione dell'articolo 143, comma 4, lettera a) , non e' comunque richiesta l'autorizzazione prescritta dall'articolo 146, dall'articolo 147 e dall'articolo 159:

- a) per gli interventi di manutenzione ordinaria, straordinaria, di consolidamento statico e di restauro conservativo che non alterino lo stato dei luoghi e l'aspetto esteriore degli edifici;
- b) per gli interventi inerenti l'esercizio dell'attivita' agro-silvo-pastorale che non comportino alterazione permanente dello stato dei luoghi con costruzioni edilizie ed altre opere civili, e sempre che si tratti di attivita' ed opere che non alterino l'assetto idrogeologico del territorio;
- c) per il taglio colturale, la forestazione, la riforestazione, le opere di bonifica, antincendio e di conservazione da eseguirsi nei boschi e nelle foreste (( indicati agli articoli 136 e 142, comma 1, lettera g) )), purche' previsti ed autorizzati in base alla normativa in materia.

### Articolo 150 - Inibizione o sospensione dei lavori

1. Indipendentemente dall'avvenuta pubblicazione all'albo pretorio prevista dagli articoli 139 e 141, ovvero dall'avvenuta comunicazione prescritta dall'articolo 139, comma 3 , la regione o il Ministero ((hanno)) facolta' di:

- a) inibire che si eseguano lavori senza autorizzazione o comunque capaci di recare pregiudizio al paesaggio ;
- b) ordinare, anche quando non sia intervenuta la diffida prevista alla lettera a), la sospensione di lavori iniziati.

2. ((L'inibizione o sospensione dei lavori disposta ai sensi del comma 1)) cessa di avere efficacia se entro il termine di novanta giorni non sia stata effettuata la pubblicazione all'albo pretorio della proposta (( di dichiarazione di notevole interesse pubblico )) di cui all'articolo 138 o all'articolo 141, ovvero non sia stata ricevuta dagli interessati la comunicazione prevista dall'articolo 139, comma 3.

3. ((COMMA ABROGATO DAL D.LGS. 26 MARZO 2008, N.63)).

4. I provvedimenti indicati ai commi precedenti sono comunicati anche al comune interessato.

### Articolo 151 - Rimborso spese a seguito della sospensione dei lavori

1. (( Qualora sia stata ordinata, senza la intimazione della preventiva diffida prevista dall'articolo 150, comma 1, lettera a), la sospensione di lavori su immobili ed aree di cui non sia stato in precedenza dichiarato il notevole interesse pubblico, ai sensi degli articoli 136, 143, comma 1, lettera d), e 157, l'interessato puo' ottenere il rimborso delle spese sostenute sino al momento della notificata sospensione. )) Le opere gia' eseguite sono demolite a spese dell'autorita' che ha disposto la sospensione.

### Articolo 152 - Interventi soggetti a particolari prescrizioni

1. Nel caso di aperture di strade e di cave, di posa di condotte per impianti industriali e civili e di palificazioni nell'ambito e in vista delle aree indicate alle lettere c) e d) del comma 1 dell' articolo 136 ovvero in prossimita' degli immobili indicati alle lettere a) e b) del comma 1 dello stesso articolo, (( l'amministrazione competente, su parere vincolante, salvo quanto previsto dall'articolo 146, comma 5, del soprintendente, o il Ministero, tenuto conto della funzione )) economica delle opere gia' realizzate o da realizzare, ((hanno)) facolta' di prescrivere le distanze, le misure e le varianti ai progetti in corso d'esecuzione, idonee (( comunque ad assicurare la conservazione dei valori espressi dai beni protetti ai sensi delle disposizioni del presente Titolo. Decorsi inutilmente i termini previsti dall'articolo 146, comma 8, senza che sia stato reso il prescritto parere, l'amministrazione competente procede ai sensi del comma 9 del medesimo articolo 146.)) ((PERIODO SOPPRESSO DAL D.LGS. 26 MARZO 2008, N. 63)).

2. ((COMMA SOPPRESSO DAL D.LGS. 26 MARZO 2008, N. 63)).

### Articolo 153 - Cartelli pubblicitari

1. Nell'ambito e in prossimita' dei beni paesaggistici indicati nell'articolo 134 (( e' vietata la posa in opera di cartelli o )) altri mezzi pubblicitari se non previa autorizzazione dell'amministrazione competente (( , che provvede su parere vincolante, salvo quanto previsto dall'articolo 146, comma 5, del soprintendente. Decorsi inutilmente i termini previsti dall'articolo 146, comma 8, senza che sia stato reso il prescritto parere, l'amministrazione competente procede ai sensi del comma 9 del medesimo articolo 146. ))

2. Lungo le strade site nell'ambito e in prossimita' dei beni indicati nel comma 1 ((e' vietata la posa in opera di cartelli)) o altri mezzi pubblicitari, salvo autorizzazione rilasciata ((ai sensi della normativa in materia di circolazione stradale e di pubblicita' sulle strade e sui veicoli)), previo parere favorevole (( del soprintendente )) sulla compatibilita' della collocazione o della tipologia del mezzo pubblicitario con i valori paesaggistici degli immobili o delle aree soggetti a tutela.

### Articolo 154 - (( (Colore delle facciate dei fabbricati) ))

((

1. Qualora la tinteggiatura delle facciate dei fabbricati siti nelle aree contemplate dalle lettere c) e d) dell'articolo 136, comma 1, o dalla lettera m) dell'articolo 142, comma 1, sia sottoposta all'obbligo della preventiva autorizzazione, in base alle disposizioni degli articoli 146 e 149, comma 1, lettera a), l'amministrazione competente, su parere vincolante, salvo quanto previsto dall'articolo 146, comma 5, del soprintendente, o il Ministero, possono ordinare che alle facciate medesime sia dato un colore che armonizzi con la bellezza d'insieme.

2. Qualora i proprietari, possessori o detentori degli immobili di cui al comma 1 non ottemperino, entro i termini stabiliti, alle prescrizioni loro impartite, l'amministrazione competente, o il soprintendente, provvede all'esecuzione d'ufficio.

3. Nei confronti degli immobili di cui all'articolo 10, comma 3, lettere a) e d), dichiarati di interesse culturale ai sensi dell'articolo 13, e degli immobili di cui al comma 1 del medesimo articolo 10 valgono le disposizioni della Parte seconda del presente codice.

))

### Articolo 155 - Vigilanza

1. Le funzioni di vigilanza sui beni paesaggistici tutelati da questo Titolo sono esercitate dal Ministero e dalle regioni.

2. Le regioni vigilano sull'ottemperanza alle disposizioni contenute nel presente decreto legislativo da parte delle amministrazioni da loro individuate per l'esercizio delle competenze in materia di paesaggio. L'inottemperanza o la persistente inerzia nell'esercizio di tali competenze comporta l'attivazione dei poteri sostitutivi da parte del Ministero .

((

2-bis. Tutti gli atti di pianificazione urbanistica o territoriale si conformano ai principi di uso consapevole del territorio e di salvaguardia delle caratteristiche paesaggistiche dei vari contesti.

2-ter. Gli atti di pianificazione urbanistica o territoriale che ricomprendano beni paesaggistici sono impugnabili, ai fini del presente codice, ai sensi dell'articolo 146, comma 12.

))

## Capo V - Disposizioni di prima applicazione e transitorie

### Articolo 156 - (Verifica e adeguamento dei piani paesaggistici)

1. Entro il (( 31 dicembre 2009 )), le regioni che hanno redatto (( piani paesaggistici)) verificano la conformita' tra le disposizioni dei predetti piani e le previsioni dell'articolo 143 e provvedono ai necessari adeguamenti. Decorso inutilmente il termine sopraindicato il Ministero provvede in via sostitutiva ai sensi dell'articolo 5, comma 7.

2. Entro centottanta giorni dalla data di entrata in vigore del presente codice, il Ministero, d'intesa con la Conferenza Stato-regioni, predispone uno schema generale di convenzione con le regioni in cui vengono stabilite le metodologie e le procedure di ricognizione, analisi, censimento e catalogazione degli immobili e delle aree oggetto di tutela, ivi comprese le tecniche per la loro rappresentazione cartografica e le caratteristiche atte ad assicurare la interoperabilita' dei sistemi informativi.

3. Le regioni e il Ministero, in conformita' a quanto stabilito (( dall'articolo 135, possono stipulare intese, ai sensi dell'articolo 143, comma 2, )) per disciplinare lo svolgimento congiunto della verifica e dell'adeguamento dei piani paesaggistici. Nell'intesa e' stabilito il termine entro il quale devono essere completati la verifica e l'adeguamento, nonche' il termine entro il quale la regione approva il piano adeguato. (( Il piano adeguato e' oggetto di accordo fra il Ministero e la regione, ai sensi dell'articolo 15 della legge 7 agosto 1990, n. 241, e dalla data della sua adozione vigono le misure di salvaguardia di cui all'articolo 143, comma 9. Qualora all'adozione del piano non consegua la sua approvazione da parte della regione, entro i termini stabiliti dall'accordo, il piano medesimo e' approvato in via sostitutiva con decreto del Ministro. ))

4. Qualora l'intesa di cui al comma 3 non venga stipulata, ovvero ad essa non segua l'accordo procedimentale sul contenuto del piano adeguato, non trova applicazione quanto previsto dai commi 4 e 5 dell'articolo 143.

### Articolo 157 - Notifiche eseguite, elenchi compilati, provvedimenti e atti emessi ai sensi della normativa previgente

1. (( Conservano efficacia a tutti gli effetti: ))

- a) ((le dichiarazioni)) di importante interesse pubblico delle bellezze naturali o panoramiche, (( notificate )) in base alla legge 11 giugno 1922,n. 778;
- b) gli elenchi compilati ai sensi della legge 29 giugno 1939, n. 1497;
- c) (( le dichiarazioni )) di notevole interesse pubblico ((notificate)) ai sensi della legge 29 giugno 1939, n. 1497;
- d) i provvedimenti di riconoscimento delle zone di interesse archeologico emessi ai sensi dell'articolo 82, quinto comma, del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, aggiunto dall'articolo 1 del decreto legge 27 giugno 1985, n. 312, convertito con modificazioni nella legge 8 agosto 1985, n. 431;
- d-bis) gli elenchi compilati ovvero integrati ai sensi del decreto legislativo 29 ottobre 1999, n. 490;
- e) (( le dichiarazioni ))di notevole interesse pubblico (( notificate )) ai sensi del decreto legislativo 29 ottobre 1999, n. 490;
- f) i provvedimenti di riconoscimento delle zone di interesse archeologico emessi ai sensi del decreto legislativo 29 ottobre 1999, n. 490.
- f-bis) i provvedimenti emanati ai sensi dell'articolo 1-ter del decreto-legge 27 giugno 1985, n. 312, convertito, con modificazioni, dalla legge 8 agosto 1985, n. 431.

2. Le disposizioni della presente Parte si applicano anche agli immobili ed alle aree in ordine ai quali, alla data di entrata in vigore del presente codice, sia stata formulata la proposta ovvero definita la perimetrazione ai fini della dichiarazione di notevole interesse pubblico o del riconoscimento quali zone di interesse archeologico.

### Articolo 158 - Disposizioni regionali di attuazione

1. Fino all'emanazione di apposite disposizioni regionali di attuazione del presente codice restano in vigore, in quanto applicabili, le disposizioni del regolamento approvato con regio decreto 3 giugno 1940, n. 1357.

### Art. 159. - (Regime transitorio in materia di autorizzazione paesaggistica)

1. Fino al (( 31 dicembre 2009 ))il procedimento rivolto al rilascio dell'autorizzazione paesaggistica e' disciplinato secondo il regime transitorio di cui al presente articolo. La disciplina dettata al capo IV si applica anche ai procedimenti di rilascio dell'autorizzazione paesaggistica che alla data del (( 31 dicembre 2009 )) non si siano ancora conclusi con l'emanazione della relativa autorizzazione o approvazione. Entro tale data le regioni provvedono a verificare la sussistenza, nei soggetti delegati all'esercizio della funzione autorizzatoria in materia di paesaggio, dei requisiti di organizzazione e di competenza tecnico-scientifica stabiliti dall'articolo 146, comma 6, apportando le eventuali necessarie modificazioni all'assetto della funzione delegata. Il mancato adempimento, da parte delle regioni, di quanto prescritto al precedente periodo determina la decadenza delle deleghe in essere alla data del (( 31 dicembre 2009 )).

2. L'amministrazione competente al rilascio dell'autorizzazione da' immediata comunicazione alla soprintendenza delle autorizzazioni rilasciate, trasmettendo la documentazione prodotta dall'interessato nonche' le risultanze degli accertamenti eventualmente esperiti. La comunicazione e' inviata contestualmente agli interessati, per i quali costituisce avviso di inizio di procedimento, ai sensi e per gli effetti della legge 7 agosto 1990, n. 241. Nella comunicazione alla soprintendenza l'Autorita' competente al rilascio dell'autorizzazione attesta di avere eseguito il contestuale invio agli interessati. L'autorizzazione e' rilasciata o negata entro il termine perentorio di sessanta giorni dalla relativa richiesta e costituisce comunque atto autonomo e presupposto della concessione edilizia o degli altri titoli legittimanti l'intervento edilizio. I lavori non possono essere iniziati in difetto di essa. In caso di richiesta di integrazione documentale o di accertamenti il termine e' sospeso per una sola volta fino alla data di ricezione della documentazione richiesta ovvero fino alla data di effettuazione degli accertamenti.

3. La soprintendenza, se ritiene l'autorizzazione non conforme alle prescrizioni di tutela del paesaggio, dettate ai sensi del presente titolo, puo' annullarla, con provvedimento motivato, entro i sessanta giorni successivi alla ricezione della relativa, completa documentazione. Si applicano le disposizioni di cui all'articolo 6, comma 6-bis, del regolamento di cui al decreto del Ministro per i beni culturali e ambientali 13 giugno 1994, n. 495.

4. Decorso il termine di sessanta giorni dalla richiesta di autorizzazione e' data facolta' agli interessati di richiedere l'autorizzazione stessa alla soprintendenza, che si pronuncia entro il termine di sessanta giorni dalla data di ricevimento. La richiesta, corredata dalla documentazione prescritta, e' presentata alla soprintendenza e ne e' data comunicazione alla amministrazione competente. In caso di richiesta di integrazione documentale o di accertamenti, il termine e' sospeso per una sola volta fino alla data di ricezione della documentazione richiesta ovvero fino alla data di effettuazione degli accertamenti.

5. Si applicano le disposizioni di cui all'articolo 146, commi 1, 2 e 4.

6. I procedimenti di conformazione ed adeguamento degli strumenti urbanistici alle previsioni della pianificazione paesaggistica redatta a termini dell'articolo 143 o adeguata a termini dell'articolo 156, che alla data del 1° giugno 2008 non si siano ancora conclusi, sono regolati ai sensi dell'articolo 145, commi 3, 4 e 5.

7. Per i beni che alla data del 1° giugno 2008 siano oggetto di provvedimenti adottati ai sensi dell'articolo 1-quinquies del decreto-legge 27 giugno 1985, n. 312, convertito, con modificazioni, dalla legge 8 agosto 1985, n. 431, e pubblicati nella Gazzetta Ufficiale in data anteriore al 6 settembre 1985, l'autorizzazione puo' essere concessa solo dopo l'adozione dei provvedimenti integrativi di cui all'articolo 141-bis.

8. Sono fatti salvi gli atti, anche endoprocedimentali, ed i provvedimenti adottati dalla data di entrata in vigore del decreto legislativo 26 marzo 2008, n. 63, fino alla data di entrata in vigore della presente disposizione, in applicazione dell'articolo 159 del presente codice, nel testo vigente anteriormente alla data di entrata in vigore del decreto legislativo 26 marzo 2008, n. 63.

9. Nei confronti delle autorizzazioni paesaggistiche adottate dopo la data di entrata in vigore del decreto legislativo 26 marzo 2008, n. 63, e prima della data di entrata in vigore della presente disposizione, la soprintendenza, qualora non abbia gia' esercitato il potere di annullamento, puo' esercitare detto potere, ai sensi dei precedenti commi 2 e 3, entro i trenta giorni decorrenti dalla data di entrata in vigore della presente disposizione; qualora l'autorizzazione, corredata dalla relativa documentazione, sia stata rinviata dalla soprintendenza all'Autorita' competente al rilascio dell'autorizzazione ai fini dell'applicazione dell'articolo 146, il predetto termine decorre dalla data in cui viene nuovamente trasmessa alla soprintendenza.

## Sanzioni - - TITOLO I Sanzioni amministrative Capo I Sanzioni relative alla Parte seconda

### Articolo 160 - Ordine di reintegrazione

1. Se per effetto della violazione degli obblighi di protezione e conservazione stabiliti dalle disposizioni del Capo III del Titolo I della Parte seconda il bene culturale subisce un danno, il Ministero ordina al responsabile l'esecuzione a sue spese delle opere necessarie alla reintegrazione.

2. Qualora le opere da disporre ai sensi del comma 1 abbiano rilievo urbanistico-edilizio l'avvio del procedimento e il provvedimento finale sono comunicati anche alla citta' metropolitana o al comune interessati.

3. In caso di inottemperanza all'ordine impartito ai sensi del comma 1, il Ministero provvede all'esecuzione d'ufficio a spese dell'obbligato. Al recupero delle somme relative si provvede nelle forme previste dalla normativa in materia di riscossione coattiva delle entrate patrimoniali dello Stato.

4. Quando la reintegrazione non sia possibile il responsabile e' tenuto a corrispondere allo Stato una somma pari al valore della cosa perduta o alla diminuzione di valore subita dalla cosa.

5. Se la determinazione della somma, fatta dal Ministero, non e' accettata dall'obbligato, la somma stessa e' determinata da una commissione composta di tre membri da nominarsi uno dal Ministero, uno dall'obbligato e un terzo dal presidente del tribunale. Le spese relative sono anticipate dall'obbligato.

### Articolo 161 - Danno a cose ritrovate

1. Le misure previste nell'articolo 160 si applicano anche a chi cagiona un danno alle cose di cui all'articolo 91, trasgredendo agli obblighi indicati agli articoli 89 e 90.

### Articolo 162 - Violazioni in materia di affissione

1. Chiunque colloca cartelli o altri mezzi pubblicitari in violazione delle disposizioni di cui all'articolo 49 e' punito con le sanzioni previste dall'articolo 23 del decreto legislativo 30 aprile 1992, n. 285 e successive modificazioni e integrazioni.

### Articolo 163 - Perdita di beni culturali

1. Se, per effetto della violazione degli obblighi stabiliti dalle disposizioni della sezione I del Capo IV e della sezione I del Capo V (( del Titolo I della Parte seconda )), il bene culturale non sia piu' rintracciabile o risulti uscito dal territorio nazionale, il trasgressore e' tenuto a corrispondere allo Stato una somma pari al valore del bene.

2. Se il fatto e' imputabile a piu' persone queste sono tenute in solido al pagamento della somma.

3. Se la determinazione della somma fatta dal Ministero non e' accettata dall'obbligato, la somma stessa e' determinata da una commissione composta di tre membri da nominarsi uno dal Ministero, uno dall'obbligato e un terzo dal presidente del tribunale. Le spese relative sono anticipate dall'obbligato.

4. La determinazione della commissione e' impugnabile in caso di errore o di manifesta iniquita'.

### Articolo 164 - Violazioni in atti giuridici

1. Le alienazioni, le convenzioni e gli atti giuridici in genere, compiuti contro i divieti stabiliti dalle disposizioni del Titolo I della Parte seconda, o senza l'osservanza delle condizioni e modalita' da esse prescritte, sono nulli.

2. Resta salva la facolta' del Ministero di esercitare la prelazione ai sensi dell'articolo 61, comma 2.

### Articolo 165 - Violazione di disposizioni in materia di circolazione internazionale

1. Fuori dei casi di concorso nel delitto previsto dall'articolo 174, comma 1, chiunque trasferisce all'estero le cose o i beni indicati nell'articolo 10, in violazione delle disposizioni di cui alle sezioni I e II del Capo V del Titolo I della Parte seconda, e' punito con la sanzione amministrativa del pagamento di una somma da euro 77,50 a euro 465.

### Articolo 166 - Omessa restituzione di documenti per l'esportazione

1. Chi effettuata l'esportazione di un bene culturale al di fuori del territorio dell'Unione europea ai sensi del ((regolamento CE)), non rende al competente ufficio di esportazione l'esemplare n. 3 del formulario previsto dal ((regolamento (CE) n. 1081/2012 della Commissione, del 9 novembre 2012,recante disposizioni d'applicazione)) del ((regolamento CE)), e' punito con la sanzione amministrativa del pagamento di una somma da euro 103,50 a euro 620.

## Capo II - Sanzioni relative alla Parte terza

### Articolo 167 - (Ordine di remissione in pristino o di versamento di indennita' pecuniaria)

1. In caso di violazione degli obblighi e degli ordini previsti dal Titolo I della Parte terza, il trasgressore e' sempre tenuto alla rimessione in pristino a proprie spese, fatto salvo quanto previsto al comma 4.

2. Con l'ordine di rimessione in pristino e' assegnato al trasgressore un termine per provvedere.

3. In caso di inottemperanza, l'autorita' amministrativa preposta alla tutela paesaggistica provvede d'ufficio per mezzo del prefetto e rende esecutoria la nota delle spese. Laddove l'autorita' amministrativa preposta alla tutela paesaggistica non provveda d'ufficio, il direttore regionale competente, su richiesta della medesima autorita' amministrativa ovvero, decorsi centottanta giorni dall'accertamento dell'illecito, previa diffida alla suddetta autorita' competente a provvedervi nei successivi trenta giorni, (( procede alla demolizione avvalendosi dell'apposito servizio tecnico-operativo del Ministero, ovvero delle modalita)) previste dall'articolo 41 del decreto del Presidente della Repubblica 6 giugno 2001, n. 380, a seguito di apposita convenzione che puo' essere stipulata d'intesa tra il (( Ministero )) e il Ministero della difesa.

4. L'autorita' amministrativa competente accerta la compatibilita' paesaggistica, secondo le procedure di cui al comma 5, nei seguenti casi:

- a) per i lavori, realizzati in assenza o difformita' dall'autorizzazione paesaggistica, che non abbiano determinato creazione di superfici utili o volumi ovvero aumento di quelli legittimamente realizzati;
- b) per l'impiego di materiali in difformita' dall'autorizzazione paesaggistica;
- c) per i lavori comunque configurabili quali interventi di manutenzione ordinaria o straordinaria ai sensi dell'articolo 3 del decreto del Presidente della Repubblica 6 giugno 2001, n. 380.

5. Il proprietario, possessore o detentore a qualsiasi titolo dell'immobile o dell'area interessati dagli interventi di cui al comma 4 presenta apposita domanda all'autorita' preposta alla gestione del vincolo ai fini dell'accertamento della compatibilita' paesaggistica degli interventi medesimi. L'autorita' competente si pronuncia sulla domanda entro il termine perentorio di centottanta giorni, previo parere vincolante della soprintendenza da rendersi entro il termine perentorio di novanta giorni. Qualora venga accertata la compatibilita' paesaggistica, il trasgressore e' tenuto al pagamento di una somma equivalente al maggiore importo tra il danno arrecato e il profitto conseguito mediante la trasgressione. L'importo della sanzione pecuniaria e' determinato previa perizia di stima. In caso di rigetto della domanda si applica la sanzione demolitoria di cui al comma 1. La domanda di accertamento della compatibilita' paesaggistica presentata ai sensi dell'articolo 181, comma 1-quater, si intende presentata anche ai sensi e per gli effetti di cui al presente comma.

6. Le somme riscosse per effetto dell'applicazione del comma 5, nonche' per effetto dell'articolo 1, comma 37, lettera b), n. 1), della legge 15 dicembre 2004, n. 308, sono utilizzate, oltre che per l'esecuzione delle rimessioni in pristino di cui al comma 1, anche per finalita' di salvaguardia nonche' per interventi di recupero dei valori paesaggistici e di riqualificazione degli immobili e delle aree degradati o interessati dalle rimessioni in pristino. Per le medesime finalita' possono essere utilizzate anche le somme derivanti dal recupero delle spese sostenute dall'amministrazione per l'esecuzione della rimessione in pristino in danno dei soggetti obbligati, ovvero altre somme a cio' destinate dalle amministrazioni competenti.

### Articolo 168 - Violazione in materia di affissione

1. Chiunque colloca cartelli o altri mezzi pubblicitari in violazione delle disposizioni di cui all'articolo 153 e' punito con le sanzioni previste dall'articolo 23 del decreto legislativo 30 aprile 1992, n. 285 e successive modificazioni.

## TITOLO II Sanzioni penali Capo I Sanzioni relative alla Parte seconda

### Articolo 169 - Opere illecite

1. E' punito con l'arresto da sei mesi ad un anno e con l'ammenda da euro 775 a euro 38.734,50:

- a) chiunque senza autorizzazione demolisce, rimuove, modifica, restaura ovvero esegue opere di qualunque genere sui beni culturali indicati nell'articolo 10;
- b) chiunque, senza l'autorizzazione del soprintendente, procede al distacco di affreschi, stemmi, graffiti, iscrizioni, tabernacoli ed altri ornamenti di edifici, esposti o non alla pubblica vista, anche se non vi sia stata la dichiarazione prevista dall'articolo 13;
- c) chiunque esegue, in casi di assoluta urgenza, lavori provvisori indispensabili per evitare danni notevoli ai beni indicati nell'articolo 10, senza darne immediata comunicazione alla soprintendenza ovvero senza inviare, nel piu' breve tempo, i progetti dei lavori definitivi per 1' autorizzazione.

2. La stessa pena prevista dal comma 1 si applica in caso di inosservanza dell'ordine di sospensione dei lavori impartito dal soprintendente ai sensi dell'articolo 28.

### Articolo 170

((ARTICOLO ABROGATO DALLA L. 9 MARZO 2022, N. 22))

### Articolo 171 - Collocazione e rimozione illecita

1. E' punito con l'arresto da sei mesi ad un anno e con l'ammenda da euro 775 a euro 38.734,50 chiunque omette di fissare al luogo di loro destinazione, nel modo indicato dal soprintendente, beni culturali appartenenti ai soggetti di cui all'articolo 10, comma 1.

2. Alla stessa pena soggiace il detentore che omette di dare notizia alla competente soprintendenza dello spostamento di beni culturali, dipendente dal mutamento di dimora, ovvero non osserva le prescrizioni date dalla soprintendenza affinche' i beni medesimi non subiscano danno dal trasporto.

### Articolo 172 - Inosservanza delle prescrizioni di tutela indiretta

1. E' punito con l'arresto da sei mesi ad un anno e con l'ammenda da euro 775 a euro 38,734,50 chiunque non osserva le prescrizioni date dal Ministero ai sensi dell'articolo 45, comma 1.

2. L'inosservanza delle misure cautelari contenute nell'atto di cui all'articolo 46, comma 4, e' punita ai sensi dell'articolo 180.

### Articolo 173

((ARTICOLO ABROGATO DALLA L. 9 MARZO 2022, N. 22))

### Articolo 174

((ARTICOLO ABROGATO DALLA L. 9 MARZO 2022, N. 22))

### Articolo 175 - Violazioni in materia di ricerche archeologiche

1. E' punito con l'arresto fino ad un anno e l'ammenda da euro 310 a euro 3.099:

- a) chiunque esegue ricerche archeologiche o, in genere, opere per il ritrovamento di cose indicate all'articolo 10 senza concessione, ovvero non osserva le prescrizioni date dall'amministrazione;
- b) chiunque, essendovi tenuto, non denuncia nel termine prescritto dall'articolo 90, comma 1, le cose indicate nell'articolo 10 rinvenute fortuitamente o non provvede alla loro conservazione temporanea.

### Articolo 176

((ARTICOLO ABROGATO DALLA L. 9 MARZO 2022, N. 22))

### Articolo 177

((ARTICOLO ABROGATO DALLA L. 9 MARZO 2022, N. 22))

### Articolo 178

((ARTICOLO ABROGATO DALLA L. 9 MARZO 2022, N. 22))

### Articolo 179

((ARTICOLO ABROGATO DALLA L. 9 MARZO 2022, N. 22))

### Articolo 180 - Inosservanza dei provvedimenti amministrativi

1. Salvo che il fatto non costituisca piu' grave reato, chiunque non ottempera ad un ordine impartito dall'autorita' preposta alla tutela dei beni culturali in conformita' del presente Titolo e' punito con le pene previste dall'articolo 650 del codice penale.

## Capo II - Sanzioni relative alla Parte terza

### Articolo 181 - Opere eseguite in assenza di autorizzazione o in difformita' da essa

1. Chiunque, senza la prescritta autorizzazione o in difformita' di essa, esegue lavori di qualsiasi genere su beni paesaggistici e' punito con le pene previste dall'articolo 44, lettera c), del decreto del Presidente della Repubblica 6 giugno 2001, n. 380.

1-bis. La pena e' della reclusione da uno a quattro anni qualora i lavori di cui al comma 1:

- a) ricadano su immobili od aree che, per le loro caratteristiche paesaggistiche siano stati dichiarati di notevole interesse pubblico con apposito provvedimento emanato in epoca antecedente alla realizzazione dei lavori; ((28))
- b) ricadano su immobili od aree tutelati per legge ai sensi dell'articolo 142 ed abbiano comportato un aumento dei manufatti superiore al trenta per cento della volumetria della costruzione originaria o, in alternativa, un ampliamento della medesima superiore a settecentocinquanta metri cubi, ovvero ancora abbiano comportato una nuova costruzione con una volumetria superiore ai mille metri cubi. ((28))

1-ter. Ferma restando l'applicazione delle sanzioni amministrative pecuniarie di cui all'articolo 167, qualora l'autorita' amministrativa competente accerti la compatibilita' paesaggistica secondo le procedure di cui al comma 1-quater, la disposizione di cui al comma 1 non si applica:

- a) per i lavori, realizzati in assenza o difformita' dall'autorizzazione paesaggistica, che non abbiano determinato creazione di superfici utili o volumi ovvero aumento di quelli legittimamente realizzati;
- b) per l'impiego di materiali in difformita' dall'autorizzazione paesaggistica;
- c) per i lavori configurabili quali interventi di manutenzione ordinaria o straordinaria ai sensi dell'articolo 3 del decreto del Presidente della Repubblica 6 giugno 2001, n. 380.

1-quater. Il proprietario, possessore o detentore a qualsiasi titolo dell'immobile o dell'area interessati dagli interventi di cui al comma 1-ter presenta apposita domanda all'autorita' preposta alla gestione del vincolo ai fini dell'accertamento della compatibilita' paesaggistica degli interventi medesimi. L'autorita' competente si pronuncia sulla domanda entro il termine perentorio di centottanta giorni, previo parere vincolante della soprintendenza da rendersi entro il termine perentorio di novanta giorni.

1-quinquies. La rimessione in pristino delle aree o degli immobili soggetti a vincoli paesaggistici' da parte del trasgressore, prima che venga disposta d'ufficio dall'autorita' amministrativa, e comunque prima che intervenga la condanna, estingue il reato di cui al comma 1.

2. Con la sentenza di condanna viene ordinata la rimessione in pristino dello stato dei luoghi a spese del condannato. Copia della sentenza e' trasmessa alla regione ed al comune nel cui territorio e' stata commessa la violazione.

--------------- AGGIORNAMENTO (28) La Corte Costituzionale, con sentenza 11 gennaio - 23 marzo 2016, n. 56 (in G.U. 1ª s.s. 30/3/2016, n. 13), ha dichiarato "l'illegittimita' costituzionale dell'art. 181, comma 1-bis, del decreto legislativo 22 gennaio 2004, n. 42 (Codice dei beni culturali e del paesaggio, ai sensi dell'articolo 10 della legge 6 luglio 2002, n. 137), nella parte in cui prevede «: a) ricadano su immobili od aree che, per le loro caratteristiche paesaggistiche siano stati dichiarati di notevole interesse pubblico con apposito provvedimento emanato in epoca antecedente alla realizzazione dei lavori; b) ricadano su immobili od aree tutelati per legge ai sensi dell'articolo 142 ed»".

## Disposizioni transitorie, abrogazioni ed entrata in vigore - - - -

### Art. 182. - Disposizioni transitorie

1. In via transitoria, agli effetti indicati all'articolo 29, comma 9-bis, acquisisce la qualifica di restauratore di beni culturali, per il settore o i settori specifici richiesti tra quelli indicati nell'allegato B, colui il quale abbia maturato una adeguata competenza professionale nell'ambito del restauro dei beni culturali mobili e delle superfici decorate dei beni architettonici.

1-bis. La qualifica di restauratore di beni culturali e' attribuita, in esito ad apposita procedura di selezione pubblica da concludere entro il 30 giugno 2015, con provvedimenti del Ministero che danno luogo all'inserimento in un apposito elenco suddiviso per settori di competenza e reso accessibile a tutti gli interessati. Alla tenuta dell'elenco provvede il Ministero medesimo, nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica. Gli elenchi vengono tempestivamente aggiornati, anche mediante inserimento dei nominativi di coloro i quali conseguono la qualifica ai sensi dell'articolo 29, commi 7, 8 e 9.

1-ter. La procedura di selezione pubblica, indetta entro il 31 dicembre 2012, consiste nella valutazione dei titoli e delle attivita', e nella attribuzione dei punteggi, indicati nell'allegato B del presente codice. Entro lo stesso termine con decreto del Ministro sono definite le linee guida per l'espletamento della procedura di selezione pubblica, nel rispetto di quanto previsto dal presente articolo, sentite le organizzazioni imprenditoriali e sindacali piu' rappresentative. La qualifica di restauratore di beni culturali e' acquisita con un punteggio pari al numero dei crediti formativi indicati nell'articolo 1 del regolamento di cui al decreto del Ministro 26 maggio 2009, n. 87. Il punteggio previsto dalla tabella 1 dell'allegato B spetta per i titoli di studio conseguiti alla data del 30 giugno 2012, nonche' per quelli conseguiti entro la data del 31 dicembre 2014 da coloro i quali risultino iscritti ai relativi corsi alla data del 30 giugno 2012. Il punteggio previsto dalla tabella 2 dell'allegato B spetta per la posizione di inquadramento formalizzata entro la data del 30 giugno 2012. Il punteggio previsto dalla tabella 3 dell'allegato B spetta per l'attivita' di restauro presa in carico alla data di entrata in vigore della presente disposizione e conclusasi entro il 31 dicembre 2014.

1-quater. Ai fini dell'attribuzione dei punteggi indicati nella tabella 3 dell'allegato B:

- a) e' considerata attivita' di restauro di beni culturali mobili e superfici decorate di beni architettonici l'attivita' caratterizzante il profilo di competenza del restauratore di beni culturali, secondo quanto previsto nell'allegato A del regolamento di cui al decreto del Ministro 26 maggio 2009, n. 86;
- b) e' riconosciuta soltanto l'attivita' di restauro effettivamente svolta dall'interessato, direttamente e in proprio ovvero direttamente e in rapporto di lavoro dipendente o di collaborazione coordinata e continuativa o a progetto, ovvero nell'ambito di rapporti di lavoro alle dipendenze di amministrazioni pubbliche preposte alla tutela dei beni culturali, con regolare esecuzione certificata nell'ambito della procedura di selezione pubblica;
- c) l'attivita' svolta deve risultare da atti di data certa emanati, ricevuti o anche custoditi dall'autorita' preposta alla tutela del bene oggetto dei lavori o dagli istituti di cui all'articolo 9 del decreto legislativo 20 ottobre 1998, n. 368, formati in occasione dell'affidamento dell'appalto, in corso d'opera o al momento della conclusione dell'appalto, ivi compresi atti concernenti l'organizzazione ed i rapporti di lavoro dell'impresa appaltatrice;
- d) la durata dell'attivita' di restauro e' documentata dai termini di consegna e di completamento dei lavori, con possibilita' di cumulare la durata di piu' lavori eseguiti nello stesso periodo.

1-quinquies. Puo' altresi' acquisire la qualifica di restauratore di beni culturali, ai medesimi effetti indicati all'articolo 29, comma 9-bis, previo superamento di una prova di idoneita' con valore di esame di Stato abilitante, secondo le modalita' stabilite con decreto del Ministro di concerto con il Ministro dell'istruzione, dell'universita' e della ricerca da emanare, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, entro il 31 dicembre 2012, colui il quale abbia acquisito la qualifica di collaboratore restauratore di beni culturali ai sensi del comma 1-sexies del presente articolo. Con il medesimo decreto sono stabilite le modalita' per lo svolgimento di una distinta prova di idoneita' con valore di esame di Stato abilitante, finalizzata al conseguimento della qualifica di restauratore di beni culturali, ai medesimi effetti indicati all'articolo 29, comma 9-bis, cui possono accedere coloro i quali, entro il termine e nel rispetto della condizione previsti dal comma 1-ter del presente articolo, abbiano conseguito la laurea o il diploma accademico di primo livello in Restauro delle accademie di belle arti, nonche' la laurea specialistica o magistrale ovvero il diploma accademico di secondo livello in Restauro delle accademie di belle arti, corrispondenti ai titoli previsti nella tabella 1 dell'allegato B, attraverso un percorso di studi della durata complessiva di almeno cinque anni. La predetta prova si svolge presso le istituzioni dove si sono tenuti i corsi di secondo livello, che vi provvedono con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica.

1-sexies. Nelle more dell'attuazione dell'articolo 29, comma 10, acquisisce la qualifica di collaboratore restauratore di beni culturali, in esito ad apposita procedura di selezione pubblica indetta entro il 31 dicembre 2012, colui il quale, alla data di pubblicazione del bando, sia in possesso di uno dei seguenti requisiti:

- a) abbia conseguito la laurea specialistica in Conservazione e restauro del patrimonio storico-artistico (12/S) ovvero la laurea magistrale in Conservazione e restauro dei beni culturali (LM11), ovvero il diploma di laurea in Conservazione dei beni culturali, se equiparato dalle universita' alle summenzionate classi, ai sensi dell'articolo 2 del decreto del Ministro dell'istruzione, dell'universita' e della ricerca 9 luglio 2009, pubblicato nella Gazzetta Ufficiale n. 233 del 7 ottobre 2009;
- b) abbia conseguito la laurea in Beni culturali (L1) ovvero in Tecnologie per la conservazione e il restauro dei beni culturali (L43);
- c) abbia conseguito un diploma in Restauro presso accademie di belle arti con insegnamento almeno triennale;
- d) abbia conseguito un diploma presso una scuola di restauro statale ovvero un attestato di qualifica professionale presso una scuola di restauro regionale ai sensi dell'articolo 14 della legge 21 dicembre 1978, n. 845, con insegnamento non inferiore a due anni;
- e) risulti inquadrato nei ruoli delle amministrazioni pubbliche preposte alla tutela dei beni culturali a seguito del superamento di un pubblico concorso relativo al profilo di assistente tecnico restauratore;
- f) abbia svolto attivita' di restauro di beni culturali mobili e superfici decorate di beni architettonici, per non meno di quattro anni, con regolare esecuzione certificata nell'ambito della procedura di selezione pubblica. L'attivita' svolta e' dimostrata mediante dichiarazione del datore di lavoro, ovvero autocertificazione dell'interessato ai sensi del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445.

1-septies. Puo' altresi' acquisire la qualifica di collaboratore restauratore di beni culturali, previo superamento di una prova di idoneita', secondo le modalita' stabilite con decreto del Ministro da emanare, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, entro il 30 giugno 2014, colui il quale abbia conseguito i requisiti previsti dal comma 1-sexies del presente articolo nel periodo compreso tra il 31 ottobre 2012 e il 30 giugno 2014.

1-octies. La qualifica di collaboratore restauratore di beni culturali e' attribuita con provvedimenti del Ministero che danno luogo all'inserimento in un apposito elenco reso accessibile a tutti gli interessati. Alla tenuta dell'elenco provvede il Ministero medesimo, nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri per la finanza pubblica.

((1-novies. I titoli di studio di cui alla sezione I, tabella 1, dell'allegato B consentono l'iscrizione nell'elenco, di cui al comma 1, relativamente ai settori di competenza, di cui alla sezione II dell'allegato B, cui si riferiscono gli insegnamenti di restauro impartiti. Le posizioni di inquadramento di cui alla sezione I, tabella 2, dell'allegato B consentono l'iscrizione nell'elenco relativamente ai settori di competenza cui si riferiscono le attivita' lavorative svolte a seguito dell'inquadramento. L'esperienza professionale di cui alla sezione I, tabella 3, dell'allegato B consente l'iscrizione nell'elenco relativamente al settore di competenza cui si riferiscono le attivita' di restauro svolte in via prevalente, nonche' agli eventuali altri settori cui si riferiscono attivita' di restauro svolte per la durata di almeno due anni))

2. In deroga a quanto previsto dall'articolo 29, comma 11, ed in attesa della emanazione dei decreti di cui ai commi 8 e 9 del medesimo articolo, con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, di concerto con il Ministro, la Fondazione "Centro per la conservazione ed il restauro dei beni culturali La Venaria Reale" e' autorizzata ad istituire ed attivare, in via sperimentale, per un ciclo formativo, in convenzione con l'Universita' di Torino e il Politecnico di Torino, un corso di laurea magistrale a ciclo unico per la formazione di restauratori dei beni culturali ai sensi del comma 6 e seguenti dello stesso articolo 29. Il decreto predetto definisce l'ordinamento didattico del corso, sulla base dello specifico progetto approvato dai competenti organi della Fondazione e delle universita', senza nuovi o maggiori oneri a carico della finanza pubblica.

3. Entro sessanta giorni dall'entrata in vigore del presente codice, le regioni e gli altri enti pubblici territoriali adottano le necessarie disposizioni di adeguamento alla prescrizione di cui all'articolo 103, comma 4. In caso di inadempienza, il Ministero procede in via sostitutiva, ai sensi dell'articolo 117, quinto comma, della Costituzione.

3-bis. In deroga al divieto di cui all'articolo 146, comma 4, secondo periodo, sono conclusi dall'autorita' competente alla gestione del vincolo paesaggistico i procedimenti relativi alle domande di autorizzazione paesaggistica in sanatoria presentate entro il 30 aprile 2004 non ancora definiti alla data di entrata in vigore del presente comma, ovvero definiti con determinazione di improcedibilita' della domanda per il sopravvenuto divieto, senza pronuncia nel merito della compatibilita' paesaggistica dell'intervento. In tale ultimo caso l'autorita' competente e' obbligata, su istanza della parte interessata, a riaprire il procedimento ed a concluderlo con atto motivato nei termini di legge. Si applicano le sanzioni previste dall'articolo 167, comma 5.

3-ter. Le disposizioni del comma 3-bis si applicano anche alle domande di sanatoria presentate nei termini ai sensi dell'articolo 1, commi 37 e 39, della legge 15 dicembre 2004, n. 308, ferma restando la quantificazione della sanzione pecuniaria ivi stabilita. Il parere della soprintendenza di cui all'articolo 1, comma 39, della legge 15 dicembre 2004, n. 308, si intende vincolante.

3-quater. Agli accertamenti della compatibilita' paesaggistica effettuati, alla data di entrata in vigore della presente disposizione, ai sensi dell'articolo 181, comma 1-quater, si applicano le sanzioni di cui all'articolo 167, comma 5.

### Articolo 183 - Disposizioni finali

1. I provvedimenti di cui agli articoli 13, 45, 141, 143, comma 10, e 156, comma 3, non sono soggetti a controllo preventivo ai sensi dell'articolo 3, comma 1, della legge 14 gennaio 1994, n. 20.

2. Dall'attuazione (( degli articoli 5, 44 e 182, commi 1, 1-quater e 2, )) non derivano nuovi o maggiori oneri per la finanza pubblica.

((

3. La partecipazione alle commissioni previste dal presente codice e' assicurata nell'ambito dei compiti istituzionali delle amministrazioni interessate, non da' luogo alla corresponsione di alcun compenso e, comunque, da essa non derivano nuovi o maggiori oneri a carico della finanza pubblica.

))

4. Gli oneri derivanti dall'esercizio da parte del Ministero delle facolta' previste agli articoli 34, 35 e 37 sono assunti nei limiti degli stanziamenti di bilancio relativi agli appositi capitoli di spesa.

5. Le garanzie prestate dallo Stato in attuazione (( degli articoli 44, comma 4 e )) dell'articolo 48, comma 5, sono elencate in allegato allo stato di previsione del Ministero dell'economia e delle finanze, ai sensi dell'articolo 13 della legge 5 agosto 1978, n. 468. In caso di escussione di dette garanzie il Ministero trasmette al Parlamento apposita relazione.

6. Le leggi della Repubblica non possono introdurre deroghe ai principi del presente decreto legislativo se non mediante espressa modificazione delle sue disposizioni.

7. Il presente codice entra in vigore il giorno 1 maggio 2004.

### Articolo 184 - (( Norme abrogate e interpretative ))

1. Sono abrogate le seguenti disposizioni: - legge 1 giugno 1939, n. 1089, articolo 40, nel testo da ultimo sostituito dall'articolo 9 della legge 12 luglio 1999, n. 237; - decreto del Presidente della Repubblica 30 settembre 1963, n. 1409, limitatamente: all'articolo 21, commi 1 e 3, e comma 2, nel testo, rispettivamente, modificato e sostituito dall'articolo 8 del decreto legislativo 30 luglio 1999, n. 281; agli articoli 21-bis e 22, comma 1, nel testo, rispettivamente, aggiunto e modificato dall'articolo 9 del medesimo decreto legislativo; - decreto del Presidente della Repubblica 14 gennaio 1972, n. 3, limitatamente all'articolo 9; - decreto legislativo 30 aprile 1992, n. 285, limitatamente all'articolo 23, comma 3 e primo periodo del comma 13-ter, aggiunto dall'articolo 30 della legge 7 dicembre 1999, n. 472; - legge 15 maggio 1997, n. 127, limitatamente all'articolo 12, comma 5, nel testo modificato dall'articolo 19, comma 9, della legge 23 dicembre 1998, n. 448; e comma 6, primo periodo; - legge 8 ottobre 1997, n. 352, limitatamente all'articolo 7, come modificato dagli articoli 3 e 4 della legge 12 luglio 1999, n. 237 e dall'articolo 4 della legge 21 dicembre 1999, n. 513; - decreto legislativo 31 marzo 1998, n. 112, limitatamente agli articoli 148, 150, 152 e 153; - legge 12 luglio 1999, n. 237, limitatamente all'articolo 9; - decreto legislativo 30 luglio 1999, n. 281, limitatamente agli articoli 8, comma 2, e 9; - decreto legislativo 29 ottobre 1999, n. 490 e successive modificazioni e integrazioni; - decreto del Presidente della Repubblica 7 settembre 2000, n. 283; - decreto legislativo 30 giugno 2003, n. 196, limitatamente all'articolo 179, comma 4; - legge 8 luglio 2003, n. 172, limitatamente all'articolo 7.

(( 1-bis. Con l'espressione "servizi aggiuntivi" riportata in leggi o regolamenti si intendono i "servizi per il pubblico" di cui all'articolo 117. ))

